@@ -30,6 +30,7 @@ import org.apache.iceberg.PartitionSpec;
 import org.apache.iceberg.Schema;
 import org.apache.iceberg.relocated.com.google.common.collect.Lists;
 import org.apache.iceberg.types.Types;
+import org.apache.iceberg.util.DateTimeUtil;
 import org.assertj.core.api.Assertions;
 import org.junit.Assert;
 import org.junit.Test;
@@ -314,14 +315,17 @@ public class TestExpressionUtil {
 
   @Test
   public void testSanitizeTime() {
+    long micros = DateTimeUtil.microsFromTimestamptz(OffsetDateTime.now()) / 1000000;
+    String currentTime = DateTimeUtil.microsToIsoTime(micros);
+
     assertEquals(
         Expressions.equal("test", "(time)"),
-        ExpressionUtil.sanitize(Expressions.equal("test", "23:49:51")));
+        ExpressionUtil.sanitize(Expressions.equal("test", currentTime)));
 
     Assert.assertEquals(
         "Sanitized string should be identical except for descriptive literal",
         "test = (time)",
-        ExpressionUtil.toSanitizedString(Expressions.equal("test", "23:49:51")));
+        ExpressionUtil.toSanitizedString(Expressions.equal("test", currentTime)));
   }
 
   @Test
