@@ -144,6 +144,20 @@ public class VectorizedColumnIterator extends BaseColumnIterator {
     }
   }
 
+  public class TimestampInt96BatchReader extends BatchReader {
+    @Override
+    protected int nextBatchOf(
+        final FieldVector vector,
+        final int expectedBatchSize,
+        final int numValsInVector,
+        final int typeWidth,
+        NullabilityHolder holder) {
+      return vectorizedPageIterator
+          .timestampInt96PageReader()
+          .nextBatch(vector, expectedBatchSize, numValsInVector, typeWidth, holder);
+    }
+  }
+
   public class FloatBatchReader extends BatchReader {
     @Override
     protected int nextBatchOf(
@@ -172,6 +186,8 @@ public class VectorizedColumnIterator extends BaseColumnIterator {
     }
   }
 
+  /** @deprecated will be removed in 1.4.0 */
+  @Deprecated
   public class IntBackedDecimalBatchReader extends BatchReader {
     @Override
     protected int nextBatchOf(
@@ -186,6 +202,8 @@ public class VectorizedColumnIterator extends BaseColumnIterator {
     }
   }
 
+  /** @deprecated will be removed in 1.4.0 */
+  @Deprecated
   public class LongBackedDecimalBatchReader extends BatchReader {
     @Override
     protected int nextBatchOf(
@@ -200,6 +218,8 @@ public class VectorizedColumnIterator extends BaseColumnIterator {
     }
   }
 
+  /** @deprecated will be removed in 1.4.0 */
+  @Deprecated
   public class FixedLengthDecimalBatchReader extends BatchReader {
     @Override
     protected int nextBatchOf(
@@ -286,6 +306,10 @@ public class VectorizedColumnIterator extends BaseColumnIterator {
     return new TimestampMillisBatchReader();
   }
 
+  public TimestampInt96BatchReader timestampInt96BatchReader() {
+    return new TimestampInt96BatchReader();
+  }
+
   public FloatBatchReader floatBatchReader() {
     return new FloatBatchReader();
   }
@@ -294,14 +318,20 @@ public class VectorizedColumnIterator extends BaseColumnIterator {
     return new DoubleBatchReader();
   }
 
+  /** @deprecated will be removed in 1.4.0 */
+  @Deprecated
   public IntBackedDecimalBatchReader intBackedDecimalBatchReader() {
     return new IntBackedDecimalBatchReader();
   }
 
+  /** @deprecated will be removed in 1.4.0 */
+  @Deprecated
   public LongBackedDecimalBatchReader longBackedDecimalBatchReader() {
     return new LongBackedDecimalBatchReader();
   }
 
+  /** @deprecated will be removed in 1.4.0 */
+  @Deprecated
   public FixedLengthDecimalBatchReader fixedLengthDecimalBatchReader() {
     return new FixedLengthDecimalBatchReader();
   }
