@@ -26,15 +26,19 @@ import org.apache.iceberg.HasTableOperations;
 import org.apache.iceberg.Table;
 import org.apache.iceberg.TableMetadata;
 import org.apache.iceberg.aws.s3.S3TestUtil;
+import org.apache.iceberg.aws.util.RetryDetector;
 import org.apache.iceberg.catalog.TableIdentifier;
 import org.apache.iceberg.exceptions.CommitFailedException;
 import org.apache.iceberg.exceptions.CommitStateUnknownException;
 import org.apache.iceberg.exceptions.ForbiddenException;
 import org.apache.iceberg.exceptions.NotFoundException;
 import org.apache.iceberg.types.Types;
+import org.assertj.core.api.Assertions;
 import org.junit.Assert;
 import org.junit.Test;
 import org.mockito.Mockito;
+import software.amazon.awssdk.core.metrics.CoreMetric;
+import software.amazon.awssdk.metrics.MetricCollector;
 import software.amazon.awssdk.services.glue.model.AccessDeniedException;
 import software.amazon.awssdk.services.glue.model.ConcurrentModificationException;
 import software.amazon.awssdk.services.glue.model.EntityNotFoundException;
@@ -123,6 +127,77 @@ public class TestGlueCatalogCommitFailure extends GlueTestBase {
     Assert.assertEquals("No new metadata files should exist", 2, metadataFileCount(ops.current()));
   }
 
+  @Test
+  public void testCheckCommitStatusAfterRetries() {
+    String namespace = createNamespace();
+    String tableName = createTable(namespace);
+    TableIdentifier tableId = TableIdentifier.of(namespace, tableName);
+
+    GlueTableOperations spyOps =
+        Mockito.spy((GlueTableOperations) glueCatalog.newTableOps(tableId));
+    GlueCatalog spyCatalog = Mockito.spy(glueCatalog);
+    Mockito.doReturn(spyOps).when(spyCatalog).newTableOps(Mockito.eq(tableId));
+    Table table = spyCatalog.loadTable(tableId);
+
+    TableMetadata metadataV1 = spyOps.current();
+    simulateRetriedCommit(spyOps, true /* report retry */);
+    updateTable(table, spyOps);
+
+    Assert.assertNotEquals("Current metadata should have changed", metadataV1, spyOps.current());
+    Assert.assertTrue("Current metadata should still exist", metadataFileExists(spyOps.current()));
+    Assert.assertEquals(
+        "No new metadata files should exist", 2, metadataFileCount(spyOps.current()));
+  }
+
+  @Test
+  public void testNoRetryAwarenessCorruptsTable() {
+    // This test exists to replicate the issue the prior test validates the fix for
+    // See https://github.com/apache/iceberg/issues/7151
+    String namespace = createNamespace();
+    String tableName = createTable(namespace);
+    TableIdentifier tableId = TableIdentifier.of(namespace, tableName);
+
+    GlueTableOperations spyOps =
+        Mockito.spy((GlueTableOperations) glueCatalog.newTableOps(tableId));
+    GlueCatalog spyCatalog = Mockito.spy(glueCatalog);
+    Mockito.doReturn(spyOps).when(spyCatalog).newTableOps(Mockito.eq(tableId));
+    Table table = spyCatalog.loadTable(tableId);
+
+    // Its possible that Glue or DynamoDB might someday make changes that render the retry detection
+    // mechanism unnecessary. At that time, this test would start failing while the prior one would
+    // still work. If or when that happens, we can re-evaluate whether the mechanism is still
+    // necessary.
+    simulateRetriedCommit(spyOps, false /* hide retry */);
+    Assertions.assertThatThrownBy(() -> updateTable(table, spyOps))
+        .as("Hidden retry causes writer to conflict with itself")
+        .isInstanceOf(CommitFailedException.class)
+        .hasMessageContaining("Glue detected concurrent update")
+        .cause()
+        .isInstanceOf(ConcurrentModificationException.class);
+
+    Assertions.assertThatThrownBy(() -> glueCatalog.loadTable(tableId))
+        .as("Table still accessible despite hidden retry, underlying assumptions may have changed")
+        .isInstanceOf(NotFoundException.class)
+        .hasMessageContaining("Location does not exist");
+  }
+
+  private void simulateRetriedCommit(GlueTableOperations spyOps, boolean reportRetry) {
+    // Perform a successful commit, then call it again, optionally letting the retryDetector know
+    // about it
+    Mockito.doAnswer(
+            i -> {
+              final MetricCollector metrics = MetricCollector.create("test");
+              metrics.reportMetric(CoreMetric.RETRY_COUNT, reportRetry ? 1 : 0);
+
+              i.callRealMethod();
+              i.getArgument(3, RetryDetector.class).publish(metrics.collect());
+              i.callRealMethod();
+              return null;
+            })
+        .when(spyOps)
+        .persistGlueTable(Mockito.any(), Mockito.anyMap(), Mockito.any(), Mockito.any());
+  }
+
   @Test
   public void testCommitThrowsExceptionWhileSucceeded() {
     Table table = setupTable();
@@ -253,7 +328,8 @@ public class TestGlueCatalogCommitFailure extends GlueTestBase {
               realOps.persistGlueTable(
                   i.getArgument(0, software.amazon.awssdk.services.glue.model.Table.class),
                   mapProperties,
-                  i.getArgument(2, TableMetadata.class));
+                  i.getArgument(2, TableMetadata.class),
+                  i.getArgument(3, RetryDetector.class));
 
               // new metadata location is stored in map property, and used for locking
               String newMetadataLocation =
@@ -267,7 +343,7 @@ public class TestGlueCatalogCommitFailure extends GlueTestBase {
               throw new RuntimeException("Datacenter on fire");
             })
         .when(spyOperations)
-        .persistGlueTable(Mockito.any(), Mockito.anyMap(), Mockito.any());
+        .persistGlueTable(Mockito.any(), Mockito.anyMap(), Mockito.any(), Mockito.any());
   }
 
   @Test
@@ -422,11 +498,12 @@ public class TestGlueCatalogCommitFailure extends GlueTestBase {
               realOps.persistGlueTable(
                   i.getArgument(0, software.amazon.awssdk.services.glue.model.Table.class),
                   i.getArgument(1, Map.class),
-                  i.getArgument(2, TableMetadata.class));
+                  i.getArgument(2, TableMetadata.class),
+                  i.getArgument(3, RetryDetector.class));
               throw new RuntimeException("Datacenter on fire");
             })
         .when(spyOps)
-        .persistGlueTable(Mockito.any(), Mockito.anyMap(), Mockito.any());
+        .persistGlueTable(Mockito.any(), Mockito.anyMap(), Mockito.any(), Mockito.any());
   }
 
   private void failCommitAndThrowException(GlueTableOperations spyOps) {
@@ -436,7 +513,7 @@ public class TestGlueCatalogCommitFailure extends GlueTestBase {
   private void failCommitAndThrowException(GlueTableOperations spyOps, Exception exceptionToThrow) {
     Mockito.doThrow(exceptionToThrow)
         .when(spyOps)
-        .persistGlueTable(Mockito.any(), Mockito.anyMap(), Mockito.any());
+        .persistGlueTable(Mockito.any(), Mockito.anyMap(), Mockito.any(), Mockito.any());
   }
 
   private void breakFallbackCatalogCommitCheck(GlueTableOperations spyOperations) {
