@@ -25,7 +25,6 @@ import java.util.function.Supplier;
 import java.util.stream.IntStream;
 import org.apache.iceberg.aws.AwsClientFactories;
 import org.apache.iceberg.aws.AwsIntegTestUtil;
-import org.apache.iceberg.aws.AwsProperties;
 import org.apache.iceberg.io.PositionOutputStream;
 import org.apache.iceberg.io.SeekableInputStream;
 import org.junit.AfterClass;
@@ -42,7 +41,7 @@ public class TestS3MultipartUpload {
   private static S3Client s3;
   private static String bucketName;
   private static String prefix;
-  private static AwsProperties properties;
+  private static S3FileIOProperties properties;
   private static S3FileIO io;
   private String objectUri;
 
@@ -51,9 +50,9 @@ public class TestS3MultipartUpload {
     s3 = AwsClientFactories.defaultFactory().s3();
     bucketName = AwsIntegTestUtil.testBucketName();
     prefix = UUID.randomUUID().toString();
-    properties = new AwsProperties();
-    properties.setS3FileIoMultiPartSize(AwsProperties.S3FILEIO_MULTIPART_SIZE_MIN);
-    properties.setS3ChecksumEnabled(true);
+    properties = new S3FileIOProperties();
+    properties.setMultiPartSize(S3FileIOProperties.MULTIPART_SIZE_MIN);
+    properties.setChecksumEnabled(true);
     io = new S3FileIO(() -> s3, properties);
   }
 
@@ -73,14 +72,14 @@ public class TestS3MultipartUpload {
     int parts = 200;
     writeInts(objectUri, parts, random::nextInt);
     Assert.assertEquals(
-        parts * (long) AwsProperties.S3FILEIO_MULTIPART_SIZE_MIN,
+        parts * (long) S3FileIOProperties.MULTIPART_SIZE_MIN,
         io.newInputFile(objectUri).getLength());
   }
 
   @Test
   public void testManyPartsWriteWithBytes() throws IOException {
     int parts = 200;
-    byte[] bytes = new byte[AwsProperties.S3FILEIO_MULTIPART_SIZE_MIN];
+    byte[] bytes = new byte[S3FileIOProperties.MULTIPART_SIZE_MIN];
     writeBytes(
         objectUri,
         parts,
@@ -89,7 +88,7 @@ public class TestS3MultipartUpload {
           return bytes;
         });
     Assert.assertEquals(
-        parts * (long) AwsProperties.S3FILEIO_MULTIPART_SIZE_MIN,
+        parts * (long) S3FileIOProperties.MULTIPART_SIZE_MIN,
         io.newInputFile(objectUri).getLength());
   }
 
@@ -101,8 +100,8 @@ public class TestS3MultipartUpload {
 
   @Test
   public void testContentsWriteWithBytes() throws IOException {
-    byte[] bytes = new byte[AwsProperties.S3FILEIO_MULTIPART_SIZE_MIN];
-    for (int i = 0; i < AwsProperties.S3FILEIO_MULTIPART_SIZE_MIN; i++) {
+    byte[] bytes = new byte[S3FileIOProperties.MULTIPART_SIZE_MIN];
+    for (int i = 0; i < S3FileIOProperties.MULTIPART_SIZE_MIN; i++) {
       bytes[i] = 6;
     }
     writeBytes(objectUri, 10, () -> bytes);
@@ -111,7 +110,7 @@ public class TestS3MultipartUpload {
 
   @Test
   public void testUploadRemainder() throws IOException {
-    long length = 3 * AwsProperties.S3FILEIO_MULTIPART_SIZE_MIN + 2 * 1024 * 1024;
+    long length = 3 * S3FileIOProperties.MULTIPART_SIZE_MIN + 2 * 1024 * 1024;
     writeInts(objectUri, 1, length, random::nextInt);
     Assert.assertEquals(length, io.newInputFile(objectUri).getLength());
   }
@@ -128,7 +127,7 @@ public class TestS3MultipartUpload {
   }
 
   private void writeInts(String fileUri, int parts, Supplier<Integer> writer) {
-    writeInts(fileUri, parts, AwsProperties.S3FILEIO_MULTIPART_SIZE_MIN, writer);
+    writeInts(fileUri, parts, S3FileIOProperties.MULTIPART_SIZE_MIN, writer);
   }
 
   private void writeInts(String fileUri, int parts, long partSize, Supplier<Integer> writer) {
