@@ -18,6 +18,7 @@
  */
 package org.apache.iceberg.aws.s3;
 
+import java.util.Arrays;
 import java.util.Collection;
 import java.util.List;
 import java.util.Map;
@@ -27,9 +28,8 @@ import java.util.concurrent.ExecutorService;
 import java.util.concurrent.Future;
 import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.stream.Collectors;
-import org.apache.iceberg.aws.AwsClientFactories;
 import org.apache.iceberg.aws.AwsClientFactory;
-import org.apache.iceberg.aws.AwsProperties;
+import org.apache.iceberg.aws.S3FileIOAwsClientFactories;
 import org.apache.iceberg.common.DynConstructors;
 import org.apache.iceberg.io.BulkDeletionFailureException;
 import org.apache.iceberg.io.CredentialSupplier;
@@ -40,12 +40,14 @@ import org.apache.iceberg.io.OutputFile;
 import org.apache.iceberg.io.SupportsBulkOperations;
 import org.apache.iceberg.io.SupportsPrefixOperations;
 import org.apache.iceberg.metrics.MetricsContext;
+import org.apache.iceberg.relocated.com.google.common.base.Joiner;
 import org.apache.iceberg.relocated.com.google.common.collect.Lists;
 import org.apache.iceberg.relocated.com.google.common.collect.Maps;
 import org.apache.iceberg.relocated.com.google.common.collect.Multimaps;
 import org.apache.iceberg.relocated.com.google.common.collect.SetMultimap;
 import org.apache.iceberg.relocated.com.google.common.collect.Sets;
 import org.apache.iceberg.relocated.com.google.common.collect.Streams;
+import org.apache.iceberg.util.PropertyUtil;
 import org.apache.iceberg.util.SerializableMap;
 import org.apache.iceberg.util.SerializableSupplier;
 import org.apache.iceberg.util.Tasks;
@@ -82,11 +84,12 @@ public class S3FileIO
 
   private String credential = null;
   private SerializableSupplier<S3Client> s3;
-  private AwsProperties awsProperties;
+  private S3FileIOProperties s3FileIOProperties;
   private SerializableMap<String, String> properties = null;
   private transient volatile S3Client client;
   private MetricsContext metrics = MetricsContext.nullMetrics();
   private final AtomicBoolean isResourceClosed = new AtomicBoolean(false);
+  private transient StackTraceElement[] createStack;
 
   /**
    * No-arg constructor to load the FileIO dynamically.
@@ -96,59 +99,60 @@ public class S3FileIO
   public S3FileIO() {}
 
   /**
-   * Constructor with custom s3 supplier and default AWS properties.
+   * Constructor with custom s3 supplier and S3FileIO properties.
    *
    * <p>Calling {@link S3FileIO#initialize(Map)} will overwrite information set in this constructor.
    *
    * @param s3 s3 supplier
    */
   public S3FileIO(SerializableSupplier<S3Client> s3) {
-    this(s3, new AwsProperties());
+    this(s3, new S3FileIOProperties());
   }
 
   /**
-   * Constructor with custom s3 supplier and AWS properties.
+   * Constructor with custom s3 supplier and S3FileIO properties.
    *
    * <p>Calling {@link S3FileIO#initialize(Map)} will overwrite information set in this constructor.
    *
    * @param s3 s3 supplier
-   * @param awsProperties aws properties
+   * @param s3FileIOProperties S3 FileIO properties
    */
-  public S3FileIO(SerializableSupplier<S3Client> s3, AwsProperties awsProperties) {
+  public S3FileIO(SerializableSupplier<S3Client> s3, S3FileIOProperties s3FileIOProperties) {
     this.s3 = s3;
-    this.awsProperties = awsProperties;
+    this.s3FileIOProperties = s3FileIOProperties;
+    this.createStack = Thread.currentThread().getStackTrace();
   }
 
   @Override
   public InputFile newInputFile(String path) {
-    return S3InputFile.fromLocation(path, client(), awsProperties, metrics);
+    return S3InputFile.fromLocation(path, client(), s3FileIOProperties, metrics);
   }
 
   @Override
   public InputFile newInputFile(String path, long length) {
-    return S3InputFile.fromLocation(path, length, client(), awsProperties, metrics);
+    return S3InputFile.fromLocation(path, length, client(), s3FileIOProperties, metrics);
   }
 
   @Override
   public OutputFile newOutputFile(String path) {
-    return S3OutputFile.fromLocation(path, client(), awsProperties, metrics);
+    return S3OutputFile.fromLocation(path, client(), s3FileIOProperties, metrics);
   }
 
   @Override
   public void deleteFile(String path) {
-    if (awsProperties.s3DeleteTags() != null && !awsProperties.s3DeleteTags().isEmpty()) {
+    if (s3FileIOProperties.deleteTags() != null && !s3FileIOProperties.deleteTags().isEmpty()) {
       try {
-        tagFileToDelete(path, awsProperties.s3DeleteTags());
+        tagFileToDelete(path, s3FileIOProperties.deleteTags());
       } catch (S3Exception e) {
-        LOG.warn("Failed to add delete tags: {} to {}", awsProperties.s3DeleteTags(), path, e);
+        LOG.warn("Failed to add delete tags: {} to {}", s3FileIOProperties.deleteTags(), path, e);
       }
     }
 
-    if (!awsProperties.isS3DeleteEnabled()) {
+    if (!s3FileIOProperties.isDeleteEnabled()) {
       return;
     }
 
-    S3URI location = new S3URI(path, awsProperties.s3BucketToAccessPointMapping());
+    S3URI location = new S3URI(path, s3FileIOProperties.bucketToAccessPointMapping());
     DeleteObjectRequest deleteRequest =
         DeleteObjectRequest.builder().bucket(location.bucket()).key(location.key()).build();
 
@@ -170,7 +174,7 @@ public class S3FileIO
    */
   @Override
   public void deleteFiles(Iterable<String> paths) throws BulkDeletionFailureException {
-    if (awsProperties.s3DeleteTags() != null && !awsProperties.s3DeleteTags().isEmpty()) {
+    if (s3FileIOProperties.deleteTags() != null && !s3FileIOProperties.deleteTags().isEmpty()) {
       Tasks.foreach(paths)
           .noRetry()
           .executeWith(executorService())
@@ -179,22 +183,22 @@ public class S3FileIO
               (path, exc) ->
                   LOG.warn(
                       "Failed to add delete tags: {} to {}",
-                      awsProperties.s3DeleteTags(),
+                      s3FileIOProperties.deleteTags(),
                       path,
                       exc))
-          .run(path -> tagFileToDelete(path, awsProperties.s3DeleteTags()));
+          .run(path -> tagFileToDelete(path, s3FileIOProperties.deleteTags()));
     }
 
-    if (awsProperties.isS3DeleteEnabled()) {
+    if (s3FileIOProperties.isDeleteEnabled()) {
       SetMultimap<String, String> bucketToObjects =
           Multimaps.newSetMultimap(Maps.newHashMap(), Sets::newHashSet);
       List<Future<List<String>>> deletionTasks = Lists.newArrayList();
       for (String path : paths) {
-        S3URI location = new S3URI(path, awsProperties.s3BucketToAccessPointMapping());
+        S3URI location = new S3URI(path, s3FileIOProperties.bucketToAccessPointMapping());
         String bucket = location.bucket();
         String objectKey = location.key();
         bucketToObjects.get(bucket).add(objectKey);
-        if (bucketToObjects.get(bucket).size() == awsProperties.s3FileIoDeleteBatchSize()) {
+        if (bucketToObjects.get(bucket).size() == s3FileIOProperties.deleteBatchSize()) {
           Set<String> keys = Sets.newHashSet(bucketToObjects.get(bucket));
           Future<List<String>> deletionTask =
               executorService().submit(() -> deleteBatch(bucket, keys));
@@ -236,7 +240,7 @@ public class S3FileIO
   }
 
   private void tagFileToDelete(String path, Set<Tag> deleteTags) throws S3Exception {
-    S3URI location = new S3URI(path, awsProperties.s3BucketToAccessPointMapping());
+    S3URI location = new S3URI(path, s3FileIOProperties.bucketToAccessPointMapping());
     String bucket = location.bucket();
     String objectKey = location.key();
     GetObjectTaggingRequest getObjectTaggingRequest =
@@ -290,7 +294,7 @@ public class S3FileIO
 
   @Override
   public Iterable<FileInfo> listPrefix(String prefix) {
-    S3URI s3uri = new S3URI(prefix, awsProperties.s3BucketToAccessPointMapping());
+    S3URI s3uri = new S3URI(prefix, s3FileIOProperties.bucketToAccessPointMapping());
     ListObjectsV2Request request =
         ListObjectsV2Request.builder().bucket(s3uri.bucket()).prefix(s3uri.key()).build();
 
@@ -336,7 +340,7 @@ public class S3FileIO
         if (executorService == null) {
           executorService =
               ThreadPools.newWorkerPool(
-                  "iceberg-s3fileio-delete", awsProperties.s3FileIoDeleteThreads());
+                  "iceberg-s3fileio-delete", s3FileIOProperties.deleteThreads());
         }
       }
     }
@@ -352,16 +356,25 @@ public class S3FileIO
   @Override
   public void initialize(Map<String, String> props) {
     this.properties = SerializableMap.copyOf(props);
-    this.awsProperties = new AwsProperties(properties);
+    this.s3FileIOProperties = new S3FileIOProperties(properties);
+    this.createStack =
+        PropertyUtil.propertyAsBoolean(props, "init-creation-stacktrace", true)
+            ? Thread.currentThread().getStackTrace()
+            : null;
 
     // Do not override s3 client if it was provided
     if (s3 == null) {
-      AwsClientFactory clientFactory = AwsClientFactories.from(props);
+      Object clientFactory = S3FileIOAwsClientFactories.initialize(props);
+      if (clientFactory instanceof S3FileIOAwsClientFactory) {
+        this.s3 = ((S3FileIOAwsClientFactory) clientFactory)::s3;
+      }
+      if (clientFactory instanceof AwsClientFactory) {
+        this.s3 = ((AwsClientFactory) clientFactory)::s3;
+      }
       if (clientFactory instanceof CredentialSupplier) {
         this.credential = ((CredentialSupplier) clientFactory).getCredential();
       }
-      this.s3 = clientFactory::s3;
-      if (awsProperties.s3PreloadClientEnabled()) {
+      if (s3FileIOProperties.isPreloadClientEnabled()) {
         client();
       }
     }
@@ -393,4 +406,19 @@ public class S3FileIO
       }
     }
   }
+
+  @SuppressWarnings("checkstyle:NoFinalizer")
+  @Override
+  protected void finalize() throws Throwable {
+    super.finalize();
+    if (!isResourceClosed.get()) {
+      close();
+
+      if (null != createStack) {
+        String trace =
+            Joiner.on("\n\t").join(Arrays.copyOfRange(createStack, 1, createStack.length));
+        LOG.warn("Unclosed S3FileIO instance created by:\n\t{}", trace);
+      }
+    }
+  }
 }
