@@ -125,7 +125,7 @@ public class BaseOverwriteFiles extends MergingSnapshotProducer<OverwriteFiles>
       StrictMetricsEvaluator metrics =
           new StrictMetricsEvaluator(base.schema(), rowFilter, isCaseSensitive());
 
-      for (DataFile file : addedFiles()) {
+      for (DataFile file : addedDataFiles()) {
         // the real test is that the strict or metrics test matches the file, indicating that all
         // records in the file match the filter. inclusive is used to avoid testing the metrics,
         // which is more complicated
