@@ -16,7 +16,6 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-
 package org.apache.iceberg;
 
 import java.io.IOException;
@@ -37,12 +36,6 @@ import org.apache.iceberg.relocated.com.google.common.collect.Lists;
 class BaseSnapshot implements Snapshot {
   private static final long INITIAL_SEQUENCE_NUMBER = 0;
 
-  /**
-   * @deprecated since 0.14.0, will be removed in 1.0.0; {@link FileIO} should be passed to methods which require it
-   */
-  @Deprecated
-  private final FileIO io;
-
   private final long snapshotId;
   private final Long parentId;
   private final long sequenceNumber;
@@ -51,6 +44,7 @@ class BaseSnapshot implements Snapshot {
   private final String operation;
   private final Map<String, String> summary;
   private final Integer schemaId;
+  private final String[] v1ManifestLocations;
 
   // lazily initialized
   private transient List<ManifestFile> allManifests = null;
@@ -61,28 +55,15 @@ class BaseSnapshot implements Snapshot {
   private transient List<DeleteFile> addedDeleteFiles = null;
   private transient List<DeleteFile> removedDeleteFiles = null;
 
-  /**
-   * For testing only.
-   */
-  BaseSnapshot(FileIO io,
-               long snapshotId,
-               Integer schemaId,
-               String... manifestFiles) {
-    this(io, snapshotId, null, System.currentTimeMillis(), null, null,
-        schemaId, Lists.transform(Arrays.asList(manifestFiles),
-            path -> new GenericManifestFile(io.newInputFile(path), 0)));
-  }
-
-  BaseSnapshot(FileIO io,
-               long sequenceNumber,
-               long snapshotId,
-               Long parentId,
-               long timestampMillis,
-               String operation,
-               Map<String, String> summary,
-               Integer schemaId,
-               String manifestList) {
-    this.io = io;
+  BaseSnapshot(
+      long sequenceNumber,
+      long snapshotId,
+      Long parentId,
+      long timestampMillis,
+      String operation,
+      Map<String, String> summary,
+      Integer schemaId,
+      String manifestList) {
     this.sequenceNumber = sequenceNumber;
     this.snapshotId = snapshotId;
     this.parentId = parentId;
@@ -91,17 +72,18 @@ class BaseSnapshot implements Snapshot {
     this.summary = summary;
     this.schemaId = schemaId;
     this.manifestListLocation = manifestList;
+    this.v1ManifestLocations = null;
   }
 
-  BaseSnapshot(long sequenceNumber,
-               long snapshotId,
-               Long parentId,
-               long timestampMillis,
-               String operation,
-               Map<String, String> summary,
-               Integer schemaId,
-               String manifestList) {
-    this.io = null;
+  BaseSnapshot(
+      long sequenceNumber,
+      long snapshotId,
+      Long parentId,
+      long timestampMillis,
+      String operation,
+      Map<String, String> summary,
+      Integer schemaId,
+      String[] v1ManifestLocations) {
     this.sequenceNumber = sequenceNumber;
     this.snapshotId = snapshotId;
     this.parentId = parentId;
@@ -109,19 +91,8 @@ class BaseSnapshot implements Snapshot {
     this.operation = operation;
     this.summary = summary;
     this.schemaId = schemaId;
-    this.manifestListLocation = manifestList;
-  }
-
-  BaseSnapshot(FileIO io,
-               long snapshotId,
-               Long parentId,
-               long timestampMillis,
-               String operation,
-               Map<String, String> summary,
-               Integer schemaId,
-               List<ManifestFile> dataManifests) {
-    this(io, INITIAL_SEQUENCE_NUMBER, snapshotId, parentId, timestampMillis, operation, summary, schemaId, null);
-    this.allManifests = dataManifests;
+    this.manifestListLocation = null;
+    this.v1ManifestLocations = v1ManifestLocations;
   }
 
   @Override
@@ -164,16 +135,28 @@ class BaseSnapshot implements Snapshot {
       throw new IllegalArgumentException("Cannot cache changes: FileIO is null");
     }
 
+    if (allManifests == null && v1ManifestLocations != null) {
+      // if we have a collection of manifest locations, then we need to load them here
+      allManifests =
+          Lists.transform(
+              Arrays.asList(v1ManifestLocations),
+              location -> new GenericManifestFile(fileIO.newInputFile(location), 0));
+    }
+
     if (allManifests == null) {
       // if manifests isn't set, then the snapshotFile is set and should be read to get the list
       this.allManifests = ManifestLists.read(fileIO.newInputFile(manifestListLocation));
     }
 
     if (dataManifests == null || deleteManifests == null) {
-      this.dataManifests = ImmutableList.copyOf(Iterables.filter(allManifests,
-          manifest -> manifest.content() == ManifestContent.DATA));
-      this.deleteManifests = ImmutableList.copyOf(Iterables.filter(allManifests,
-          manifest -> manifest.content() == ManifestContent.DELETES));
+      this.dataManifests =
+          ImmutableList.copyOf(
+              Iterables.filter(
+                  allManifests, manifest -> manifest.content() == ManifestContent.DATA));
+      this.deleteManifests =
+          ImmutableList.copyOf(
+              Iterables.filter(
+                  allManifests, manifest -> manifest.content() == ManifestContent.DELETES));
     }
   }
 
@@ -185,18 +168,6 @@ class BaseSnapshot implements Snapshot {
     return allManifests;
   }
 
-  /**
-   * @deprecated since 0.14.0, will be removed in 1.0.0; Use {@link Snapshot#allManifests(FileIO)} instead.
-   */
-  @Override
-  @Deprecated
-  public List<ManifestFile> allManifests() {
-    if (allManifests == null) {
-      cacheManifests(io);
-    }
-    return allManifests;
-  }
-
   @Override
   public List<ManifestFile> dataManifests(FileIO fileIO) {
     if (dataManifests == null) {
@@ -205,19 +176,6 @@ class BaseSnapshot implements Snapshot {
     return dataManifests;
   }
 
-
-  /**
-   * @deprecated since 0.14.0, will be removed in 1.0.0; Use {@link Snapshot#dataManifests(FileIO)} instead.
-   */
-  @Override
-  @Deprecated
-  public List<ManifestFile> dataManifests() {
-    if (dataManifests == null) {
-      cacheManifests(io);
-    }
-    return dataManifests;
-  }
-
   @Override
   public List<ManifestFile> deleteManifests(FileIO fileIO) {
     if (deleteManifests == null) {
@@ -226,18 +184,6 @@ class BaseSnapshot implements Snapshot {
     return deleteManifests;
   }
 
-  /**
-   * @deprecated since 0.14.0, will be removed in 1.0.0; Use {@link Snapshot#deleteManifests(FileIO)} instead.
-   */
-  @Override
-  @Deprecated
-  public List<ManifestFile> deleteManifests() {
-    if (deleteManifests == null) {
-      cacheManifests(io);
-    }
-    return deleteManifests;
-  }
-
   @Override
   public List<DataFile> addedDataFiles(FileIO fileIO) {
     if (addedDataFiles == null) {
@@ -246,18 +192,6 @@ class BaseSnapshot implements Snapshot {
     return addedDataFiles;
   }
 
-  /**
-   * @deprecated since 0.14.0, will be removed in 1.0.0; Use {@link Snapshot#addedDataFiles(FileIO)} instead.
-   */
-  @Override
-  @Deprecated
-  public List<DataFile> addedFiles() {
-    if (addedDataFiles == null) {
-      cacheDataFileChanges(io);
-    }
-    return addedDataFiles;
-  }
-
   @Override
   public List<DataFile> removedDataFiles(FileIO fileIO) {
     if (removedDataFiles == null) {
@@ -266,18 +200,6 @@ class BaseSnapshot implements Snapshot {
     return removedDataFiles;
   }
 
-  /**
-   * @deprecated since 0.14.0, will be removed in 1.0.0; Use {@link Snapshot#removedDataFiles(FileIO)} instead.
-   */
-  @Override
-  @Deprecated
-  public List<DataFile> deletedFiles() {
-    if (removedDataFiles == null) {
-      cacheDataFileChanges(io);
-    }
-    return removedDataFiles;
-  }
-
   @Override
   public Iterable<DeleteFile> addedDeleteFiles(FileIO fileIO) {
     if (addedDeleteFiles == null) {
@@ -305,11 +227,13 @@ class BaseSnapshot implements Snapshot {
     ImmutableList.Builder<DeleteFile> adds = ImmutableList.builder();
     ImmutableList.Builder<DeleteFile> deletes = ImmutableList.builder();
 
-    Iterable<ManifestFile> changedManifests = Iterables.filter(deleteManifests(fileIO),
-        manifest -> Objects.equal(manifest.snapshotId(), snapshotId));
+    Iterable<ManifestFile> changedManifests =
+        Iterables.filter(
+            deleteManifests(fileIO), manifest -> Objects.equal(manifest.snapshotId(), snapshotId));
 
     for (ManifestFile manifest : changedManifests) {
-      try (ManifestReader<DeleteFile> reader = ManifestFiles.readDeleteManifest(manifest, fileIO, null)) {
+      try (ManifestReader<DeleteFile> reader =
+          ManifestFiles.readDeleteManifest(manifest, fileIO, null)) {
         for (ManifestEntry<DeleteFile> entry : reader.entries()) {
           switch (entry.status()) {
             case ADDED:
@@ -338,11 +262,11 @@ class BaseSnapshot implements Snapshot {
     ImmutableList.Builder<DataFile> deletes = ImmutableList.builder();
 
     // read only manifests that were created by this snapshot
-    Iterable<ManifestFile> changedManifests = Iterables.filter(dataManifests(fileIO),
-        manifest -> Objects.equal(manifest.snapshotId(), snapshotId));
-    try (CloseableIterable<ManifestEntry<DataFile>> entries = new ManifestGroup(fileIO, changedManifests)
-        .ignoreExisting()
-        .entries()) {
+    Iterable<ManifestFile> changedManifests =
+        Iterables.filter(
+            dataManifests(fileIO), manifest -> Objects.equal(manifest.snapshotId(), snapshotId));
+    try (CloseableIterable<ManifestEntry<DataFile>> entries =
+        new ManifestGroup(fileIO, changedManifests).ignoreExisting().entries()) {
       for (ManifestEntry<DataFile> entry : entries) {
         switch (entry.status()) {
           case ADDED:
@@ -372,11 +296,11 @@ class BaseSnapshot implements Snapshot {
 
     if (o instanceof BaseSnapshot) {
       BaseSnapshot other = (BaseSnapshot) o;
-      return this.snapshotId == other.snapshotId() &&
-          Objects.equal(this.parentId, other.parentId()) &&
-          this.sequenceNumber == other.sequenceNumber() &&
-          this.timestampMillis == other.timestampMillis() &&
-          Objects.equal(this.schemaId, other.schemaId());
+      return this.snapshotId == other.snapshotId()
+          && Objects.equal(this.parentId, other.parentId())
+          && this.sequenceNumber == other.sequenceNumber()
+          && this.timestampMillis == other.timestampMillis()
+          && Objects.equal(this.schemaId, other.schemaId());
     }
 
     return false;
@@ -385,12 +309,7 @@ class BaseSnapshot implements Snapshot {
   @Override
   public int hashCode() {
     return Objects.hashCode(
-      this.snapshotId,
-      this.parentId,
-      this.sequenceNumber,
-      this.timestampMillis,
-      this.schemaId
-    );
+        this.snapshotId, this.parentId, this.sequenceNumber, this.timestampMillis, this.schemaId);
   }
 
   @Override
