@@ -31,14 +31,16 @@ import java.io.Serializable;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
-import java.util.concurrent.atomic.AtomicLong;
 import java.util.function.Consumer;
+import java.util.stream.Collectors;
 import org.apache.iceberg.encryption.EncryptionManager;
 import org.apache.iceberg.exceptions.CommitFailedException;
 import org.apache.iceberg.exceptions.CommitStateUnknownException;
 import org.apache.iceberg.exceptions.NoSuchTableException;
 import org.apache.iceberg.io.FileIO;
 import org.apache.iceberg.io.LocationProvider;
+import org.apache.iceberg.metrics.LoggingMetricsReporter;
+import org.apache.iceberg.metrics.MetricsReporter;
 import org.apache.iceberg.relocated.com.google.common.annotations.VisibleForTesting;
 import org.apache.iceberg.relocated.com.google.common.base.Preconditions;
 import org.apache.iceberg.relocated.com.google.common.collect.Lists;
@@ -63,7 +65,6 @@ public class BaseTransaction implements Transaction {
   private final TransactionTable transactionTable;
   private final TableOperations transactionOps;
   private final List<PendingUpdate> updates;
-  private final Set<Long> intermediateSnapshotIds;
   private final Set<String> deletedFiles =
       Sets.newHashSet(); // keep track of files deleted in the most recent commit
   private final Consumer<String> enqueueDelete = deletedFiles::add;
@@ -71,19 +72,29 @@ public class BaseTransaction implements Transaction {
   private TableMetadata base;
   private TableMetadata current;
   private boolean hasLastOpCommitted;
+  private final MetricsReporter reporter;
 
   BaseTransaction(
       String tableName, TableOperations ops, TransactionType type, TableMetadata start) {
+    this(tableName, ops, type, start, LoggingMetricsReporter.instance());
+  }
+
+  BaseTransaction(
+      String tableName,
+      TableOperations ops,
+      TransactionType type,
+      TableMetadata start,
+      MetricsReporter reporter) {
     this.tableName = tableName;
     this.ops = ops;
     this.transactionTable = new TransactionTable();
     this.current = start;
     this.transactionOps = new TransactionTableOperations();
     this.updates = Lists.newArrayList();
-    this.intermediateSnapshotIds = Sets.newHashSet();
     this.base = ops.current();
     this.type = type;
     this.hasLastOpCommitted = true;
+    this.reporter = reporter;
   }
 
   @Override
@@ -91,6 +102,10 @@ public class BaseTransaction implements Transaction {
     return transactionTable;
   }
 
+  public String tableName() {
+    return tableName;
+  }
+
   public TableMetadata startMetadata() {
     return current;
   }
@@ -148,7 +163,7 @@ public class BaseTransaction implements Transaction {
   @Override
   public AppendFiles newAppend() {
     checkLastOperationCommitted("AppendFiles");
-    AppendFiles append = new MergeAppend(tableName, transactionOps);
+    AppendFiles append = new MergeAppend(tableName, transactionOps).reportWith(reporter);
     append.deleteWith(enqueueDelete);
     updates.add(append);
     return append;
@@ -157,7 +172,7 @@ public class BaseTransaction implements Transaction {
   @Override
   public AppendFiles newFastAppend() {
     checkLastOperationCommitted("AppendFiles");
-    AppendFiles append = new FastAppend(tableName, transactionOps);
+    AppendFiles append = new FastAppend(tableName, transactionOps).reportWith(reporter);
     updates.add(append);
     return append;
   }
@@ -165,7 +180,7 @@ public class BaseTransaction implements Transaction {
   @Override
   public RewriteFiles newRewrite() {
     checkLastOperationCommitted("RewriteFiles");
-    RewriteFiles rewrite = new BaseRewriteFiles(tableName, transactionOps);
+    RewriteFiles rewrite = new BaseRewriteFiles(tableName, transactionOps).reportWith(reporter);
     rewrite.deleteWith(enqueueDelete);
     updates.add(rewrite);
     return rewrite;
@@ -174,7 +189,7 @@ public class BaseTransaction implements Transaction {
   @Override
   public RewriteManifests rewriteManifests() {
     checkLastOperationCommitted("RewriteManifests");
-    RewriteManifests rewrite = new BaseRewriteManifests(transactionOps);
+    RewriteManifests rewrite = new BaseRewriteManifests(transactionOps).reportWith(reporter);
     rewrite.deleteWith(enqueueDelete);
     updates.add(rewrite);
     return rewrite;
@@ -183,7 +198,8 @@ public class BaseTransaction implements Transaction {
   @Override
   public OverwriteFiles newOverwrite() {
     checkLastOperationCommitted("OverwriteFiles");
-    OverwriteFiles overwrite = new BaseOverwriteFiles(tableName, transactionOps);
+    OverwriteFiles overwrite =
+        new BaseOverwriteFiles(tableName, transactionOps).reportWith(reporter);
     overwrite.deleteWith(enqueueDelete);
     updates.add(overwrite);
     return overwrite;
@@ -192,7 +208,7 @@ public class BaseTransaction implements Transaction {
   @Override
   public RowDelta newRowDelta() {
     checkLastOperationCommitted("RowDelta");
-    RowDelta delta = new BaseRowDelta(tableName, transactionOps);
+    RowDelta delta = new BaseRowDelta(tableName, transactionOps).reportWith(reporter);
     delta.deleteWith(enqueueDelete);
     updates.add(delta);
     return delta;
@@ -201,7 +217,8 @@ public class BaseTransaction implements Transaction {
   @Override
   public ReplacePartitions newReplacePartitions() {
     checkLastOperationCommitted("ReplacePartitions");
-    ReplacePartitions replacePartitions = new BaseReplacePartitions(tableName, transactionOps);
+    ReplacePartitions replacePartitions =
+        new BaseReplacePartitions(tableName, transactionOps).reportWith(reporter);
     replacePartitions.deleteWith(enqueueDelete);
     updates.add(replacePartitions);
     return replacePartitions;
@@ -210,7 +227,7 @@ public class BaseTransaction implements Transaction {
   @Override
   public DeleteFiles newDelete() {
     checkLastOperationCommitted("DeleteFiles");
-    DeleteFiles delete = new StreamingDelete(tableName, transactionOps);
+    DeleteFiles delete = new StreamingDelete(tableName, transactionOps).reportWith(reporter);
     delete.deleteWith(enqueueDelete);
     updates.add(delete);
     return delete;
@@ -233,9 +250,17 @@ public class BaseTransaction implements Transaction {
     return expire;
   }
 
+  @Override
+  public ManageSnapshots manageSnapshots() {
+    SnapshotManager snapshotManager = new SnapshotManager(this);
+    updates.add(snapshotManager);
+    return snapshotManager;
+  }
+
   CherryPickOperation cherryPick() {
     checkLastOperationCommitted("CherryPick");
-    CherryPickOperation cherrypick = new CherryPickOperation(tableName, transactionOps);
+    CherryPickOperation cherrypick =
+        new CherryPickOperation(tableName, transactionOps).reportWith(reporter);
     updates.add(cherrypick);
     return cherrypick;
   }
@@ -379,9 +404,8 @@ public class BaseTransaction implements Transaction {
       return;
     }
 
-    // this is always set to the latest commit attempt's snapshot id.
-    AtomicLong currentSnapshotId = new AtomicLong(-1L);
-
+    Set<Long> startingSnapshots =
+        base.snapshots().stream().map(Snapshot::snapshotId).collect(Collectors.toSet());
     try {
       Tasks.foreach(ops)
           .retry(base.propertyAsInt(COMMIT_NUM_RETRIES, COMMIT_NUM_RETRIES_DEFAULT))
@@ -395,11 +419,6 @@ public class BaseTransaction implements Transaction {
               underlyingOps -> {
                 applyUpdates(underlyingOps);
 
-                if (current.currentSnapshot() != null) {
-                  currentSnapshotId.set(current.currentSnapshot().snapshotId());
-                }
-
-                // fix up the snapshot log, which should not contain intermediate snapshots
                 underlyingOps.commit(base, current);
               });
 
@@ -417,17 +436,18 @@ public class BaseTransaction implements Transaction {
     // the commit succeeded
 
     try {
-      if (currentSnapshotId.get() != -1) {
-        intermediateSnapshotIds.add(currentSnapshotId.get());
+      // clean up the data files that were deleted by each operation. first, get the list of
+      // committed manifests to ensure that no committed manifest is deleted.
+      // A manifest could be deleted in one successful operation commit, but reused in another
+      // successful commit of that operation if the whole transaction is retried.
+      Set<Long> newSnapshots = Sets.newHashSet();
+      for (Snapshot snapshot : current.snapshots()) {
+        if (!startingSnapshots.contains(snapshot.snapshotId())) {
+          newSnapshots.add(snapshot.snapshotId());
+        }
       }
 
-      // clean up the data files that were deleted by each operation. first, get the list of
-      // committed manifests to
-      // ensure that no committed manifest is deleted. a manifest could be deleted in one successful
-      // operation
-      // commit, but reused in another successful commit of that operation if the whole transaction
-      // is retried.
-      Set<String> committedFiles = committedFiles(ops, intermediateSnapshotIds);
+      Set<String> committedFiles = committedFiles(ops, newSnapshots);
       if (committedFiles != null) {
         // delete all of the files that were deleted in the most recent set of operation commits
         Tasks.foreach(deletedFiles)
@@ -504,15 +524,6 @@ public class BaseTransaction implements Transaction {
     return committedFiles;
   }
 
-  private static Long currentId(TableMetadata meta) {
-    if (meta != null) {
-      if (meta.currentSnapshot() != null) {
-        return meta.currentSnapshot().snapshotId();
-      }
-    }
-    return null;
-  }
-
   public class TransactionTableOperations implements TableOperations {
     private TableOperations tempOps = ops.temp(current);
 
@@ -534,13 +545,6 @@ public class BaseTransaction implements Transaction {
         throw new CommitFailedException("Table metadata refresh is required");
       }
 
-      // track the intermediate snapshot ids for rewriting the snapshot log
-      // an id is intermediate if it isn't the base snapshot id and it is replaced by a new current
-      Long oldId = currentId(current);
-      if (oldId != null && !oldId.equals(currentId(metadata)) && !oldId.equals(currentId(base))) {
-        intermediateSnapshotIds.add(oldId);
-      }
-
       BaseTransaction.this.current = metadata;
 
       this.tempOps = ops.temp(metadata);
