@@ -16,7 +16,6 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-
 package org.apache.iceberg;
 
 import org.apache.iceberg.exceptions.CommitFailedException;
@@ -24,11 +23,12 @@ import org.apache.iceberg.expressions.Expression;
 
 /**
  * {@link DeleteFiles Delete} implementation that avoids loading full manifests in memory.
- * <p>
- * This implementation will attempt to commit 5 times before throwing {@link CommitFailedException}.
+ *
+ * <p>This implementation will attempt to commit 5 times before throwing {@link
+ * CommitFailedException}.
  */
 public class StreamingDelete extends MergingSnapshotProducer<DeleteFiles> implements DeleteFiles {
-  StreamingDelete(String tableName, TableOperations ops) {
+  protected StreamingDelete(String tableName, TableOperations ops) {
     super(tableName, ops);
   }
 
@@ -59,4 +59,10 @@ public class StreamingDelete extends MergingSnapshotProducer<DeleteFiles> implem
     deleteByRowFilter(expr);
     return this;
   }
+
+  @Override
+  public StreamingDelete toBranch(String branch) {
+    targetBranch(branch);
+    return this;
+  }
 }
