@@ -18,6 +18,11 @@
  */
 package org.apache.iceberg.actions;
 
+/**
+ * @deprecated will be removed in 1.4.0; use {@link ImmutableDeleteReachableFiles.Result#builder()}
+ *     instead.
+ */
+@Deprecated
 public class BaseDeleteReachableFilesActionResult implements DeleteReachableFiles.Result {
 
   private final long deletedDataFilesCount;
