@@ -29,6 +29,9 @@ import org.apache.iceberg.hadoop.HadoopFileIO;
 import org.apache.iceberg.io.FileIO;
 import org.apache.iceberg.io.InputFile;
 import org.apache.iceberg.io.OutputFile;
+import org.apache.iceberg.metrics.MetricsReport;
+import org.apache.iceberg.metrics.MetricsReporter;
+import org.apache.iceberg.relocated.com.google.common.collect.ImmutableMap;
 import org.apache.iceberg.relocated.com.google.common.collect.Maps;
 import org.assertj.core.api.Assertions;
 import org.junit.Assert;
@@ -46,7 +49,7 @@ public class TestCatalogUtil {
         CatalogUtil.loadCatalog(TestCatalog.class.getName(), name, options, hadoopConf);
     Assertions.assertThat(catalog).isInstanceOf(TestCatalog.class);
     Assert.assertEquals(name, ((TestCatalog) catalog).catalogName);
-    Assert.assertEquals(options, ((TestCatalog) catalog).flinkOptions);
+    Assert.assertEquals(options, ((TestCatalog) catalog).catalogProperties);
   }
 
   @Test
@@ -60,7 +63,7 @@ public class TestCatalogUtil {
         CatalogUtil.loadCatalog(TestCatalogConfigurable.class.getName(), name, options, hadoopConf);
     Assertions.assertThat(catalog).isInstanceOf(TestCatalogConfigurable.class);
     Assert.assertEquals(name, ((TestCatalogConfigurable) catalog).catalogName);
-    Assert.assertEquals(options, ((TestCatalogConfigurable) catalog).flinkOptions);
+    Assert.assertEquals(options, ((TestCatalogConfigurable) catalog).catalogProperties);
     Assert.assertEquals(hadoopConf, ((TestCatalogConfigurable) catalog).configuration);
   }
 
@@ -187,17 +190,52 @@ public class TestCatalogUtil {
         () -> CatalogUtil.buildIcebergCatalog(name, options, hadoopConf));
   }
 
+  @Test
+  public void loadCustomMetricsReporter_noArg() {
+    Map<String, String> properties = Maps.newHashMap();
+    properties.put("key", "val");
+    properties.put(
+        CatalogProperties.METRICS_REPORTER_IMPL, TestMetricsReporterDefault.class.getName());
+
+    MetricsReporter metricsReporter = CatalogUtil.loadMetricsReporter(properties);
+    Assertions.assertThat(metricsReporter).isInstanceOf(TestMetricsReporterDefault.class);
+  }
+
+  @Test
+  public void loadCustomMetricsReporter_badArg() {
+    Assertions.assertThatThrownBy(
+            () ->
+                CatalogUtil.loadMetricsReporter(
+                    ImmutableMap.of(
+                        CatalogProperties.METRICS_REPORTER_IMPL,
+                        TestMetricsReporterBadArg.class.getName())))
+        .isInstanceOf(IllegalArgumentException.class)
+        .hasMessageContaining("missing no-arg constructor");
+  }
+
+  @Test
+  public void loadCustomMetricsReporter_badClass() {
+    Assertions.assertThatThrownBy(
+            () ->
+                CatalogUtil.loadMetricsReporter(
+                    ImmutableMap.of(
+                        CatalogProperties.METRICS_REPORTER_IMPL,
+                        TestFileIONotImpl.class.getName())))
+        .isInstanceOf(IllegalArgumentException.class)
+        .hasMessageContaining("does not implement MetricsReporter");
+  }
+
   public static class TestCatalog extends BaseMetastoreCatalog {
 
     private String catalogName;
-    private Map<String, String> flinkOptions;
+    private Map<String, String> catalogProperties;
 
     public TestCatalog() {}
 
     @Override
     public void initialize(String name, Map<String, String> properties) {
       this.catalogName = name;
-      this.flinkOptions = properties;
+      this.catalogProperties = properties;
     }
 
     @Override
@@ -227,7 +265,7 @@ public class TestCatalogUtil {
   public static class TestCatalogConfigurable extends BaseMetastoreCatalog implements Configurable {
 
     private String catalogName;
-    private Map<String, String> flinkOptions;
+    private Map<String, String> catalogProperties;
     private Configuration configuration;
 
     public TestCatalogConfigurable() {}
@@ -235,7 +273,7 @@ public class TestCatalogUtil {
     @Override
     public void initialize(String name, Map<String, String> properties) {
       this.catalogName = name;
-      this.flinkOptions = properties;
+      this.catalogProperties = properties;
     }
 
     @Override
@@ -399,4 +437,21 @@ public class TestCatalogUtil {
   public static class TestFileIONotImpl {
     public TestFileIONotImpl() {}
   }
+
+  public static class TestMetricsReporterBadArg implements MetricsReporter {
+    private final String arg;
+
+    public TestMetricsReporterBadArg(String arg) {
+      this.arg = arg;
+    }
+
+    @Override
+    public void report(MetricsReport report) {}
+  }
+
+  public static class TestMetricsReporterDefault implements MetricsReporter {
+
+    @Override
+    public void report(MetricsReport report) {}
+  }
 }
