@@ -314,16 +314,21 @@ public class TestMetadataTableScans extends MetadataTableScanTestBase {
                     "partition",
                     Types.StructType.of(optional(1000, "data_bucket", Types.IntegerType.get()))))
             .asStruct();
-
     TableScan scanNoFilter = partitionsTable.newScan().select("partition.data_bucket");
     Assert.assertEquals(expected, scanNoFilter.schema().asStruct());
-    CloseableIterable<FileScanTask> tasksNoFilter =
+
+    CloseableIterable<ContentFile<?>> files =
         PartitionsTable.planFiles((StaticTableScan) scanNoFilter);
-    Assert.assertEquals(4, Iterators.size(tasksNoFilter.iterator()));
-    validateIncludesPartitionScan(tasksNoFilter, 0);
-    validateIncludesPartitionScan(tasksNoFilter, 1);
-    validateIncludesPartitionScan(tasksNoFilter, 2);
-    validateIncludesPartitionScan(tasksNoFilter, 3);
+    if (formatVersion == 2) {
+      Assert.assertEquals(8, Iterators.size(files.iterator()));
+    } else {
+      Assert.assertEquals(4, Iterators.size(files.iterator()));
+    }
+
+    validateSingleFieldPartition(files, 0);
+    validateSingleFieldPartition(files, 1);
+    validateSingleFieldPartition(files, 2);
+    validateSingleFieldPartition(files, 3);
   }
 
   @Test
@@ -332,17 +337,23 @@ public class TestMetadataTableScans extends MetadataTableScanTestBase {
 
     Table partitionsTable = new PartitionsTable(table);
     Types.StructType expected =
-        new Schema(required(3, "file_count", Types.IntegerType.get())).asStruct();
+        new Schema(required(3, "file_count", Types.IntegerType.get(), "Count of data files"))
+            .asStruct();
 
     TableScan scanWithProjection = partitionsTable.newScan().select("file_count");
     Assert.assertEquals(expected, scanWithProjection.schema().asStruct());
-    CloseableIterable<FileScanTask> tasksWithProjection =
+    CloseableIterable<ContentFile<?>> files =
         PartitionsTable.planFiles((StaticTableScan) scanWithProjection);
-    Assert.assertEquals(4, Iterators.size(tasksWithProjection.iterator()));
-    validateIncludesPartitionScan(tasksWithProjection, 0);
-    validateIncludesPartitionScan(tasksWithProjection, 1);
-    validateIncludesPartitionScan(tasksWithProjection, 2);
-    validateIncludesPartitionScan(tasksWithProjection, 3);
+    if (formatVersion == 2) {
+      Assert.assertEquals(8, Iterators.size(files.iterator()));
+    } else {
+      Assert.assertEquals(4, Iterators.size(files.iterator()));
+    }
+
+    validateSingleFieldPartition(files, 0);
+    validateSingleFieldPartition(files, 1);
+    validateSingleFieldPartition(files, 2);
+    validateSingleFieldPartition(files, 3);
   }
 
   @Test
@@ -350,14 +361,14 @@ public class TestMetadataTableScans extends MetadataTableScanTestBase {
     table.newFastAppend().appendFile(FILE_WITH_STATS).commit();
 
     Table partitionsTable = new PartitionsTable(table);
-    CloseableIterable<FileScanTask> tasksAndEq =
+    CloseableIterable<ContentFile<?>> tasksAndEq =
         PartitionsTable.planFiles((StaticTableScan) partitionsTable.newScan());
-    for (FileScanTask fileTask : tasksAndEq) {
-      Assert.assertNull(fileTask.file().columnSizes());
-      Assert.assertNull(fileTask.file().valueCounts());
-      Assert.assertNull(fileTask.file().nullValueCounts());
-      Assert.assertNull(fileTask.file().lowerBounds());
-      Assert.assertNull(fileTask.file().upperBounds());
+    for (ContentFile<?> file : tasksAndEq) {
+      Assert.assertNull(file.columnSizes());
+      Assert.assertNull(file.valueCounts());
+      Assert.assertNull(file.nullValueCounts());
+      Assert.assertNull(file.lowerBounds());
+      Assert.assertNull(file.upperBounds());
     }
   }
 
@@ -372,10 +383,15 @@ public class TestMetadataTableScans extends MetadataTableScanTestBase {
             Expressions.equal("partition.data_bucket", 0),
             Expressions.greaterThan("record_count", 0));
     TableScan scanAndEq = partitionsTable.newScan().filter(andEquals);
-    CloseableIterable<FileScanTask> tasksAndEq =
+    CloseableIterable<ContentFile<?>> files =
         PartitionsTable.planFiles((StaticTableScan) scanAndEq);
-    Assert.assertEquals(1, Iterators.size(tasksAndEq.iterator()));
-    validateIncludesPartitionScan(tasksAndEq, 0);
+    if (formatVersion == 2) {
+      Assert.assertEquals(2, Iterators.size(files.iterator()));
+    } else {
+      Assert.assertEquals(1, Iterators.size(files.iterator()));
+    }
+
+    validateSingleFieldPartition(files, 0);
   }
 
   @Test
@@ -389,11 +405,16 @@ public class TestMetadataTableScans extends MetadataTableScanTestBase {
             Expressions.lessThan("partition.data_bucket", 2),
             Expressions.greaterThan("record_count", 0));
     TableScan scanLtAnd = partitionsTable.newScan().filter(ltAnd);
-    CloseableIterable<FileScanTask> tasksLtAnd =
+    CloseableIterable<ContentFile<?>> files =
         PartitionsTable.planFiles((StaticTableScan) scanLtAnd);
-    Assert.assertEquals(2, Iterators.size(tasksLtAnd.iterator()));
-    validateIncludesPartitionScan(tasksLtAnd, 0);
-    validateIncludesPartitionScan(tasksLtAnd, 1);
+    if (formatVersion == 2) {
+      Assert.assertEquals(4, Iterators.size(files.iterator()));
+    } else {
+      Assert.assertEquals(2, Iterators.size(files.iterator()));
+    }
+
+    validateSingleFieldPartition(files, 0);
+    validateSingleFieldPartition(files, 1);
   }
 
   @Test
@@ -407,12 +428,18 @@ public class TestMetadataTableScans extends MetadataTableScanTestBase {
             Expressions.equal("partition.data_bucket", 2),
             Expressions.greaterThan("record_count", 0));
     TableScan scanOr = partitionsTable.newScan().filter(or);
-    CloseableIterable<FileScanTask> tasksOr = PartitionsTable.planFiles((StaticTableScan) scanOr);
-    Assert.assertEquals(4, Iterators.size(tasksOr.iterator()));
-    validateIncludesPartitionScan(tasksOr, 0);
-    validateIncludesPartitionScan(tasksOr, 1);
-    validateIncludesPartitionScan(tasksOr, 2);
-    validateIncludesPartitionScan(tasksOr, 3);
+
+    CloseableIterable<ContentFile<?>> files = PartitionsTable.planFiles((StaticTableScan) scanOr);
+    if (formatVersion == 2) {
+      Assert.assertEquals(8, Iterators.size(files.iterator()));
+    } else {
+      Assert.assertEquals(4, Iterators.size(files.iterator()));
+    }
+
+    validateSingleFieldPartition(files, 0);
+    validateSingleFieldPartition(files, 1);
+    validateSingleFieldPartition(files, 2);
+    validateSingleFieldPartition(files, 3);
   }
 
   @Test
@@ -422,10 +449,15 @@ public class TestMetadataTableScans extends MetadataTableScanTestBase {
 
     Expression not = Expressions.not(Expressions.lessThan("partition.data_bucket", 2));
     TableScan scanNot = partitionsTable.newScan().filter(not);
-    CloseableIterable<FileScanTask> tasksNot = PartitionsTable.planFiles((StaticTableScan) scanNot);
-    Assert.assertEquals(2, Iterators.size(tasksNot.iterator()));
-    validateIncludesPartitionScan(tasksNot, 2);
-    validateIncludesPartitionScan(tasksNot, 3);
+    CloseableIterable<ContentFile<?>> files = PartitionsTable.planFiles((StaticTableScan) scanNot);
+    if (formatVersion == 2) {
+      Assert.assertEquals(4, Iterators.size(files.iterator()));
+    } else {
+      Assert.assertEquals(2, Iterators.size(files.iterator()));
+    }
+
+    validateSingleFieldPartition(files, 2);
+    validateSingleFieldPartition(files, 3);
   }
 
   @Test
@@ -436,10 +468,15 @@ public class TestMetadataTableScans extends MetadataTableScanTestBase {
 
     Expression set = Expressions.in("partition.data_bucket", 2, 3);
     TableScan scanSet = partitionsTable.newScan().filter(set);
-    CloseableIterable<FileScanTask> tasksSet = PartitionsTable.planFiles((StaticTableScan) scanSet);
-    Assert.assertEquals(2, Iterators.size(tasksSet.iterator()));
-    validateIncludesPartitionScan(tasksSet, 2);
-    validateIncludesPartitionScan(tasksSet, 3);
+    CloseableIterable<ContentFile<?>> files = PartitionsTable.planFiles((StaticTableScan) scanSet);
+    if (formatVersion == 2) {
+      Assert.assertEquals(4, Iterators.size(files.iterator()));
+    } else {
+      Assert.assertEquals(2, Iterators.size(files.iterator()));
+    }
+
+    validateSingleFieldPartition(files, 2);
+    validateSingleFieldPartition(files, 3);
   }
 
   @Test
@@ -450,13 +487,18 @@ public class TestMetadataTableScans extends MetadataTableScanTestBase {
 
     Expression unary = Expressions.notNull("partition.data_bucket");
     TableScan scanUnary = partitionsTable.newScan().filter(unary);
-    CloseableIterable<FileScanTask> tasksUnary =
+    CloseableIterable<ContentFile<?>> files =
         PartitionsTable.planFiles((StaticTableScan) scanUnary);
-    Assert.assertEquals(4, Iterators.size(tasksUnary.iterator()));
-    validateIncludesPartitionScan(tasksUnary, 0);
-    validateIncludesPartitionScan(tasksUnary, 1);
-    validateIncludesPartitionScan(tasksUnary, 2);
-    validateIncludesPartitionScan(tasksUnary, 3);
+    if (formatVersion == 2) {
+      Assert.assertEquals(8, Iterators.size(files.iterator()));
+    } else {
+      Assert.assertEquals(4, Iterators.size(files.iterator()));
+    }
+
+    validateSingleFieldPartition(files, 0);
+    validateSingleFieldPartition(files, 1);
+    validateSingleFieldPartition(files, 2);
+    validateSingleFieldPartition(files, 3);
   }
 
   @Test
@@ -621,6 +663,93 @@ public class TestMetadataTableScans extends MetadataTableScanTestBase {
     Assert.assertEquals("Dynamic schema for readable_metrics should match", actual, expected);
   }
 
+  @Test
+  public void testEntriesTableReadableMetricsSchema() {
+    Table entriesTable = new ManifestEntriesTable(table);
+    Types.StructType actual = entriesTable.newScan().schema().select("readable_metrics").asStruct();
+    int highestId = entriesTable.schema().highestFieldId();
+
+    Types.StructType expected =
+        Types.StructType.of(
+            optional(
+                highestId,
+                "readable_metrics",
+                Types.StructType.of(
+                    Types.NestedField.optional(
+                        highestId - 14,
+                        "data",
+                        Types.StructType.of(
+                            Types.NestedField.optional(
+                                highestId - 13,
+                                "column_size",
+                                Types.LongType.get(),
+                                "Total size on disk"),
+                            Types.NestedField.optional(
+                                highestId - 12,
+                                "value_count",
+                                Types.LongType.get(),
+                                "Total count, including null and NaN"),
+                            Types.NestedField.optional(
+                                highestId - 11,
+                                "null_value_count",
+                                Types.LongType.get(),
+                                "Null value count"),
+                            Types.NestedField.optional(
+                                highestId - 10,
+                                "nan_value_count",
+                                Types.LongType.get(),
+                                "NaN value count"),
+                            Types.NestedField.optional(
+                                highestId - 9,
+                                "lower_bound",
+                                Types.StringType.get(),
+                                "Lower bound"),
+                            Types.NestedField.optional(
+                                highestId - 8,
+                                "upper_bound",
+                                Types.StringType.get(),
+                                "Upper bound")),
+                        "Metrics for column data"),
+                    Types.NestedField.optional(
+                        highestId - 7,
+                        "id",
+                        Types.StructType.of(
+                            Types.NestedField.optional(
+                                highestId - 6,
+                                "column_size",
+                                Types.LongType.get(),
+                                "Total size on disk"),
+                            Types.NestedField.optional(
+                                highestId - 5,
+                                "value_count",
+                                Types.LongType.get(),
+                                "Total count, including null and NaN"),
+                            Types.NestedField.optional(
+                                highestId - 4,
+                                "null_value_count",
+                                Types.LongType.get(),
+                                "Null value count"),
+                            Types.NestedField.optional(
+                                highestId - 3,
+                                "nan_value_count",
+                                Types.LongType.get(),
+                                "NaN value count"),
+                            Types.NestedField.optional(
+                                highestId - 2,
+                                "lower_bound",
+                                Types.IntegerType.get(),
+                                "Lower bound"),
+                            Types.NestedField.optional(
+                                highestId - 1,
+                                "upper_bound",
+                                Types.IntegerType.get(),
+                                "Upper bound")),
+                        "Metrics for column id")),
+                "Column metrics in readable form"));
+
+    Assert.assertEquals("Dynamic schema for readable_metrics should match", actual, expected);
+  }
+
   @Test
   public void testPartitionSpecEvolutionAdditive() {
     preparePartitionedTable();
@@ -659,20 +788,30 @@ public class TestMetadataTableScans extends MetadataTableScanTestBase {
         Expressions.and(
             Expressions.equal("partition.id", 10), Expressions.greaterThan("record_count", 0));
     TableScan scan = metadataTable.newScan().filter(filter);
-    CloseableIterable<FileScanTask> tasks = PartitionsTable.planFiles((StaticTableScan) scan);
-
-    // Four data files of old spec, one new data file of new spec
-    Assert.assertEquals(5, Iterables.size(tasks));
+    CloseableIterable<ContentFile<?>> files = PartitionsTable.planFiles((StaticTableScan) scan);
+    if (formatVersion == 2) {
+      // Four data files and delete files of old spec, one new data file of new spec
+      Assert.assertEquals(9, Iterables.size(files));
+    } else {
+      // Four data files of old spec, one new data file of new spec
+      Assert.assertEquals(5, Iterables.size(files));
+    }
 
     filter =
         Expressions.and(
             Expressions.equal("partition.data_bucket", 0),
             Expressions.greaterThan("record_count", 0));
     scan = metadataTable.newScan().filter(filter);
-    tasks = PartitionsTable.planFiles((StaticTableScan) scan);
+    files = PartitionsTable.planFiles((StaticTableScan) scan);
 
-    // 1 original data file written by old spec, plus 1 new data file written by new spec
-    Assert.assertEquals(2, Iterables.size(tasks));
+    if (formatVersion == 2) {
+      // 1 original data file and delete file written by old spec, plus 1 new data file written by
+      // new spec
+      Assert.assertEquals(3, Iterables.size(files));
+    } else {
+      // 1 original data file written by old spec, plus 1 new data file written by new spec
+      Assert.assertEquals(2, Iterables.size(files));
+    }
   }
 
   @Test
@@ -713,10 +852,15 @@ public class TestMetadataTableScans extends MetadataTableScanTestBase {
         Expressions.and(
             Expressions.equal("partition.id", 10), Expressions.greaterThan("record_count", 0));
     TableScan scan = metadataTable.newScan().filter(filter);
-    CloseableIterable<FileScanTask> tasks = PartitionsTable.planFiles((StaticTableScan) scan);
+    CloseableIterable<ContentFile<?>> files = PartitionsTable.planFiles((StaticTableScan) scan);
 
-    // Four original files of original spec, one data file written by new spec
-    Assert.assertEquals(5, Iterables.size(tasks));
+    if (formatVersion == 2) {
+      // Four data and delete files of original spec, one data file written by new spec
+      Assert.assertEquals(9, Iterables.size(files));
+    } else {
+      // Four data files of original spec, one data file written by new spec
+      Assert.assertEquals(5, Iterables.size(files));
+    }
 
     // Filter for a dropped partition spec field.  Correct behavior is that only old partitions are
     // returned.
@@ -725,14 +869,14 @@ public class TestMetadataTableScans extends MetadataTableScanTestBase {
             Expressions.equal("partition.data_bucket", 0),
             Expressions.greaterThan("record_count", 0));
     scan = metadataTable.newScan().filter(filter);
-    tasks = PartitionsTable.planFiles((StaticTableScan) scan);
+    files = PartitionsTable.planFiles((StaticTableScan) scan);
 
     if (formatVersion == 1) {
       // 1 original data file written by old spec
-      Assert.assertEquals(1, Iterables.size(tasks));
+      Assert.assertEquals(1, Iterables.size(files));
     } else {
-      // 1 original data/delete files written by old spec, plus both of new data file/delete file
-      // written by new spec
+      // 1 original data and 1 delete files written by old spec, plus both of new data file/delete
+      // file written by new spec
       //
       // Unlike in V1, V2 does not write (data=null) on newer files' partition data, so these cannot
       // be filtered out
@@ -740,11 +884,11 @@ public class TestMetadataTableScans extends MetadataTableScanTestBase {
       //
       // However, these partition rows are filtered out later in Spark data filtering, as the newer
       // partitions
-      // will have 'data=null' field added as part of normalization to the Partitions table final
+      // will have 'data=null' field added as part of normalization to the Partition table final
       // schema.
-      // The Partitions table final schema is a union of fields of all specs, including dropped
+      // The Partition table final schema is a union of fields of all specs, including dropped
       // fields.
-      Assert.assertEquals(3, Iterables.size(tasks));
+      Assert.assertEquals(4, Iterables.size(files));
     }
   }
 
@@ -795,10 +939,10 @@ public class TestMetadataTableScans extends MetadataTableScanTestBase {
             Expressions.equal("partition.partition", 0),
             Expressions.greaterThan("record_count", 0));
     TableScan scanAndEq = partitionsTable.newScan().filter(andEquals);
-    CloseableIterable<FileScanTask> tasksAndEq =
+    CloseableIterable<ContentFile<?>> files =
         PartitionsTable.planFiles((StaticTableScan) scanAndEq);
-    Assert.assertEquals(1, Iterators.size(tasksAndEq.iterator()));
-    validateIncludesPartitionScan(tasksAndEq, 0);
+    Assert.assertEquals(1, Iterators.size(files.iterator()));
+    validateSingleFieldPartition(files, 0);
   }
 
   @Test
@@ -866,8 +1010,13 @@ public class TestMetadataTableScans extends MetadataTableScanTestBase {
                           true); // daemon threads will be terminated abruptly when the JVM exits
                       return thread;
                     }));
-    CloseableIterable<FileScanTask> tasks = PartitionsTable.planFiles((StaticTableScan) scan);
-    Assert.assertEquals(4, Iterables.size(tasks));
+    CloseableIterable<ContentFile<?>> files = PartitionsTable.planFiles((StaticTableScan) scan);
+    if (formatVersion == 2) {
+      Assert.assertEquals(8, Iterators.size(files.iterator()));
+    } else {
+      Assert.assertEquals(4, Iterators.size(files.iterator()));
+    }
+
     Assert.assertTrue("Thread should be created in provided pool", planThreadsIndex.get() > 0);
   }
 
