@@ -28,7 +28,6 @@ import java.util.Map;
 import java.util.Set;
 import java.util.stream.Collectors;
 import org.apache.iceberg.AppendFiles;
-import org.apache.iceberg.AssertHelpers;
 import org.apache.iceberg.BaseTable;
 import org.apache.iceberg.DataFile;
 import org.apache.iceberg.DataFiles;
@@ -65,6 +64,7 @@ import org.apache.iceberg.util.CharSequenceSet;
 import org.assertj.core.api.Assertions;
 import org.junit.Assert;
 import org.junit.Assume;
+import org.junit.jupiter.api.Assumptions;
 import org.junit.jupiter.api.Test;
 
 public abstract class CatalogTests<C extends Catalog & SupportsNamespaces> {
@@ -185,11 +185,10 @@ public abstract class CatalogTests<C extends Catalog & SupportsNamespaces> {
     catalog.createNamespace(NS);
     Assert.assertTrue("Namespace should exist", catalog.namespaceExists(NS));
 
-    AssertHelpers.assertThrows(
-        "Should fail to create an existing database",
-        AlreadyExistsException.class,
-        "newdb",
-        () -> catalog.createNamespace(NS));
+    Assertions.assertThatThrownBy(() -> catalog.createNamespace(NS))
+        .isInstanceOf(AlreadyExistsException.class)
+        .hasMessageContaining("Namespace already exists");
+
     Assert.assertTrue("Namespace should still exist", catalog.namespaceExists(NS));
   }
 
@@ -218,11 +217,9 @@ public abstract class CatalogTests<C extends Catalog & SupportsNamespaces> {
 
     Assert.assertFalse("Namespace should not exist", catalog.namespaceExists(NS));
 
-    AssertHelpers.assertThrows(
-        "Should fail to load nonexistent namespace metadata",
-        NoSuchNamespaceException.class,
-        "newdb",
-        () -> catalog.loadNamespaceMetadata(NS));
+    Assertions.assertThatThrownBy(() -> catalog.loadNamespaceMetadata(NS))
+        .isInstanceOf(NoSuchNamespaceException.class)
+        .hasMessage("Namespace does not exist: newdb");
 
     catalog.createNamespace(NS);
     Assert.assertTrue("Namespace should exist", catalog.namespaceExists(NS));
@@ -313,11 +310,9 @@ public abstract class CatalogTests<C extends Catalog & SupportsNamespaces> {
 
     C catalog = catalog();
 
-    AssertHelpers.assertThrows(
-        "setProperties should fail if the namespace does not exist",
-        NoSuchNamespaceException.class,
-        "does not exist",
-        () -> catalog.setProperties(NS, ImmutableMap.of("test", "value")));
+    Assertions.assertThatThrownBy(() -> catalog.setProperties(NS, ImmutableMap.of("test", "value")))
+        .isInstanceOf(NoSuchNamespaceException.class)
+        .hasMessage("Namespace does not exist: newdb");
   }
 
   @Test
@@ -347,11 +342,9 @@ public abstract class CatalogTests<C extends Catalog & SupportsNamespaces> {
 
     C catalog = catalog();
 
-    AssertHelpers.assertThrows(
-        "setProperties should fail if the namespace does not exist",
-        NoSuchNamespaceException.class,
-        "does not exist",
-        () -> catalog.removeProperties(NS, ImmutableSet.of("a", "b")));
+    Assertions.assertThatThrownBy(() -> catalog.removeProperties(NS, ImmutableSet.of("a", "b")))
+        .isInstanceOf(NoSuchNamespaceException.class)
+        .hasMessage("Namespace does not exist: newdb");
   }
 
   @Test
@@ -499,6 +492,10 @@ public abstract class CatalogTests<C extends Catalog & SupportsNamespaces> {
 
     Assert.assertFalse("Table should not exist", catalog.tableExists(ident));
 
+    if (requiresNamespaceCreate()) {
+      catalog.createNamespace(ident.namespace());
+    }
+
     Table table = catalog.buildTable(ident, SCHEMA).create();
     Assert.assertTrue("Table should exist", catalog.tableExists(ident));
 
@@ -573,16 +570,18 @@ public abstract class CatalogTests<C extends Catalog & SupportsNamespaces> {
 
     TableIdentifier ident = TableIdentifier.of("ns", "table");
 
+    if (requiresNamespaceCreate()) {
+      catalog.createNamespace(ident.namespace());
+    }
+
     Assert.assertFalse("Table should not exist", catalog.tableExists(ident));
 
     catalog.buildTable(ident, SCHEMA).create();
     Assert.assertTrue("Table should exist", catalog.tableExists(ident));
 
-    AssertHelpers.assertThrows(
-        "Should fail to create a table that already exists",
-        AlreadyExistsException.class,
-        "ns.table",
-        () -> catalog.buildTable(ident, OTHER_SCHEMA).create());
+    Assertions.assertThatThrownBy(() -> catalog.buildTable(ident, OTHER_SCHEMA).create())
+        .isInstanceOf(AlreadyExistsException.class)
+        .hasMessage("Table already exists: ns.table");
 
     Table table = catalog.loadTable(ident);
     Assert.assertEquals(
@@ -597,6 +596,10 @@ public abstract class CatalogTests<C extends Catalog & SupportsNamespaces> {
 
     TableIdentifier ident = TableIdentifier.of("ns", "table");
 
+    if (requiresNamespaceCreate()) {
+      catalog.createNamespace(ident.namespace());
+    }
+
     Assert.assertFalse("Table should not exist", catalog.tableExists(ident));
 
     Map<String, String> properties =
@@ -633,6 +636,10 @@ public abstract class CatalogTests<C extends Catalog & SupportsNamespaces> {
 
     TableIdentifier ident = TableIdentifier.of("ns", "table");
 
+    if (requiresNamespaceCreate()) {
+      catalog.createNamespace(ident.namespace());
+    }
+
     Assert.assertFalse("Table should not exist", catalog.tableExists(ident));
 
     Map<String, String> properties =
@@ -671,6 +678,10 @@ public abstract class CatalogTests<C extends Catalog & SupportsNamespaces> {
     TableIdentifier tableIdent = TableIdentifier.of("ns", "table");
     TableIdentifier metaIdent = TableIdentifier.of("ns", "table", "files");
 
+    if (requiresNamespaceCreate()) {
+      catalog.createNamespace(tableIdent.namespace());
+    }
+
     catalog.buildTable(tableIdent, SCHEMA).create();
 
     Table table = catalog.loadTable(metaIdent);
@@ -690,11 +701,9 @@ public abstract class CatalogTests<C extends Catalog & SupportsNamespaces> {
     TableIdentifier ident = TableIdentifier.of("ns", "table");
 
     Assert.assertFalse("Table should not exist", catalog.tableExists(ident));
-    AssertHelpers.assertThrows(
-        "Should fail to load a nonexistent table",
-        NoSuchTableException.class,
-        ident.toString(),
-        () -> catalog.loadTable(ident));
+    Assertions.assertThatThrownBy(() -> catalog.loadTable(ident))
+        .isInstanceOf(NoSuchTableException.class)
+        .hasMessage("Table does not exist: ns.table");
   }
 
   @Test
@@ -733,11 +742,9 @@ public abstract class CatalogTests<C extends Catalog & SupportsNamespaces> {
     Assert.assertFalse(
         "Destination table should not exist before rename", catalog.tableExists(RENAMED_TABLE));
 
-    AssertHelpers.assertThrows(
-        "Should reject renaming a table that does not exist",
-        NoSuchTableException.class,
-        "Table does not exist",
-        () -> catalog.renameTable(TABLE, RENAMED_TABLE));
+    Assertions.assertThatThrownBy(() -> catalog.renameTable(TABLE, RENAMED_TABLE))
+        .isInstanceOf(NoSuchTableException.class)
+        .hasMessageContaining("Table does not exist");
 
     Assert.assertFalse(
         "Destination table should not exist after failed rename",
@@ -762,11 +769,9 @@ public abstract class CatalogTests<C extends Catalog & SupportsNamespaces> {
     Assert.assertTrue(
         "Destination table should exist after create", catalog.tableExists(RENAMED_TABLE));
 
-    AssertHelpers.assertThrows(
-        "Should reject renaming a table if the new name already exists",
-        AlreadyExistsException.class,
-        "Table already exists",
-        () -> catalog.renameTable(TABLE, RENAMED_TABLE));
+    Assertions.assertThatThrownBy(() -> catalog.renameTable(TABLE, RENAMED_TABLE))
+        .isInstanceOf(AlreadyExistsException.class)
+        .hasMessageContaining("Table already exists");
 
     Assert.assertTrue(
         "Source table should still exist after failed rename", catalog.tableExists(TABLE));
@@ -934,6 +939,10 @@ public abstract class CatalogTests<C extends Catalog & SupportsNamespaces> {
   public void testUpdateTableSchema() {
     C catalog = catalog();
 
+    if (requiresNamespaceCreate()) {
+      catalog.createNamespace(NS);
+    }
+
     Table table = catalog.buildTable(TABLE, SCHEMA).create();
     UpdateSchema update = table.updateSchema().addColumn("new_col", Types.LongType.get());
 
@@ -953,6 +962,10 @@ public abstract class CatalogTests<C extends Catalog & SupportsNamespaces> {
   public void testUUIDValidation() {
     C catalog = catalog();
 
+    if (requiresNamespaceCreate()) {
+      catalog.createNamespace(NS);
+    }
+
     Table table = catalog.buildTable(TABLE, SCHEMA).create();
     UpdateSchema update = table.updateSchema().addColumn("new_col", Types.LongType.get());
 
@@ -961,11 +974,9 @@ public abstract class CatalogTests<C extends Catalog & SupportsNamespaces> {
 
     String expectedMessage =
         supportsServerSideRetry() ? "Requirement failed: UUID does not match" : "Cannot commit";
-    AssertHelpers.assertThrows(
-        "Should reject changes to tables that have been dropped and recreated",
-        CommitFailedException.class,
-        expectedMessage,
-        update::commit);
+    Assertions.assertThatThrownBy(update::commit)
+        .isInstanceOf(CommitFailedException.class)
+        .hasMessageContaining(expectedMessage);
 
     Table loaded = catalog.loadTable(TABLE);
     Assert.assertEquals(
@@ -981,6 +992,10 @@ public abstract class CatalogTests<C extends Catalog & SupportsNamespaces> {
         supportsServerSideRetry());
     C catalog = catalog();
 
+    if (requiresNamespaceCreate()) {
+      catalog.createNamespace(NS);
+    }
+
     Table table = catalog.buildTable(TABLE, SCHEMA).create();
 
     UpdateSchema update = table.updateSchema().addColumn("new_col", Types.LongType.get());
@@ -1003,6 +1018,10 @@ public abstract class CatalogTests<C extends Catalog & SupportsNamespaces> {
   public void testUpdateTableSchemaConflict() {
     C catalog = catalog();
 
+    if (requiresNamespaceCreate()) {
+      catalog.createNamespace(NS);
+    }
+
     Table table = catalog.buildTable(TABLE, SCHEMA).create();
 
     UpdateSchema update = table.updateSchema().addColumn("new_col", Types.LongType.get());
@@ -1015,11 +1034,9 @@ public abstract class CatalogTests<C extends Catalog & SupportsNamespaces> {
     // attempt to commit the original update
     String expectedMessage =
         supportsServerSideRetry() ? "Requirement failed: current schema changed" : "Cannot commit";
-    AssertHelpers.assertThrows(
-        "Second schema update commit should fail because of a conflict",
-        CommitFailedException.class,
-        expectedMessage,
-        update::commit);
+    Assertions.assertThatThrownBy(update::commit)
+        .isInstanceOf(CommitFailedException.class)
+        .hasMessageContaining(expectedMessage);
 
     Table loaded = catalog.loadTable(TABLE);
     Assert.assertEquals(
@@ -1032,6 +1049,10 @@ public abstract class CatalogTests<C extends Catalog & SupportsNamespaces> {
   public void testUpdateTableSchemaAssignmentConflict() {
     C catalog = catalog();
 
+    if (requiresNamespaceCreate()) {
+      catalog.createNamespace(NS);
+    }
+
     Table table = catalog.buildTable(TABLE, SCHEMA).create();
 
     UpdateSchema update = table.updateSchema().addColumn("new_col", Types.LongType.get());
@@ -1047,11 +1068,9 @@ public abstract class CatalogTests<C extends Catalog & SupportsNamespaces> {
         supportsServerSideRetry()
             ? "Requirement failed: last assigned field id changed"
             : "Cannot commit";
-    AssertHelpers.assertThrows(
-        "Second schema update commit should fail because of a conflict",
-        CommitFailedException.class,
-        expectedMessage,
-        update::commit);
+    Assertions.assertThatThrownBy(update::commit)
+        .isInstanceOf(CommitFailedException.class)
+        .hasMessageContaining(expectedMessage);
 
     Table loaded = catalog.loadTable(TABLE);
     Assert.assertEquals(
@@ -1064,6 +1083,10 @@ public abstract class CatalogTests<C extends Catalog & SupportsNamespaces> {
   public void testUpdateTableSchemaThenRevert() {
     C catalog = catalog();
 
+    if (requiresNamespaceCreate()) {
+      catalog.createNamespace(NS);
+    }
+
     Table table = catalog.buildTable(TABLE, SCHEMA).create();
 
     table
@@ -1085,6 +1108,10 @@ public abstract class CatalogTests<C extends Catalog & SupportsNamespaces> {
   public void testUpdateTableSpec() {
     C catalog = catalog();
 
+    if (requiresNamespaceCreate()) {
+      catalog.createNamespace(NS);
+    }
+
     Table table = catalog.buildTable(TABLE, SCHEMA).create();
     UpdatePartitionSpec update = table.updateSpec().addField("shard", Expressions.bucket("id", 16));
 
@@ -1105,6 +1132,10 @@ public abstract class CatalogTests<C extends Catalog & SupportsNamespaces> {
         "Spec update recovery is only supported with server-side retry", supportsServerSideRetry());
     C catalog = catalog();
 
+    if (requiresNamespaceCreate()) {
+      catalog.createNamespace(NS);
+    }
+
     Table table = catalog.buildTable(TABLE, SCHEMA).create();
 
     UpdatePartitionSpec update = table.updateSpec().addField("shard", Expressions.bucket("id", 16));
@@ -1131,6 +1162,10 @@ public abstract class CatalogTests<C extends Catalog & SupportsNamespaces> {
   public void testUpdateTableSpecConflict() {
     C catalog = catalog();
 
+    if (requiresNamespaceCreate()) {
+      catalog.createNamespace(NS);
+    }
+
     Table table = catalog.buildTable(TABLE, SCHEMA).withPartitionSpec(SPEC).create();
 
     UpdatePartitionSpec update =
@@ -1147,11 +1182,9 @@ public abstract class CatalogTests<C extends Catalog & SupportsNamespaces> {
         supportsServerSideRetry()
             ? "Requirement failed: default partition spec changed"
             : "Cannot commit";
-    AssertHelpers.assertThrows(
-        "Second partition spec update commit should fail because of a conflict",
-        CommitFailedException.class,
-        expectedMessage,
-        update::commit);
+    Assertions.assertThatThrownBy(update::commit)
+        .isInstanceOf(CommitFailedException.class)
+        .hasMessageContaining(expectedMessage);
 
     Table loaded = catalog.loadTable(TABLE);
 
@@ -1164,6 +1197,10 @@ public abstract class CatalogTests<C extends Catalog & SupportsNamespaces> {
   public void testUpdateTableAssignmentSpecConflict() {
     C catalog = catalog();
 
+    if (requiresNamespaceCreate()) {
+      catalog.createNamespace(NS);
+    }
+
     Table table = catalog.buildTable(TABLE, SCHEMA).create();
 
     UpdatePartitionSpec update = table.updateSpec().addField("shard", Expressions.bucket("id", 16));
@@ -1179,11 +1216,9 @@ public abstract class CatalogTests<C extends Catalog & SupportsNamespaces> {
         supportsServerSideRetry()
             ? "Requirement failed: last assigned partition id changed"
             : "Cannot commit";
-    AssertHelpers.assertThrows(
-        "Second partition spec update commit should fail because of a conflict",
-        CommitFailedException.class,
-        expectedMessage,
-        update::commit);
+    Assertions.assertThatThrownBy(update::commit)
+        .isInstanceOf(CommitFailedException.class)
+        .hasMessageContaining(expectedMessage);
 
     Table loaded = catalog.loadTable(TABLE);
 
@@ -1196,6 +1231,10 @@ public abstract class CatalogTests<C extends Catalog & SupportsNamespaces> {
   public void testUpdateTableSpecThenRevert() {
     C catalog = catalog();
 
+    if (requiresNamespaceCreate()) {
+      catalog.createNamespace(NS);
+    }
+
     // create a v2 table. otherwise the spec update would produce a different spec with a void
     // partition field
     Table table =
@@ -1218,6 +1257,10 @@ public abstract class CatalogTests<C extends Catalog & SupportsNamespaces> {
   public void testUpdateTableSortOrder() {
     C catalog = catalog();
 
+    if (requiresNamespaceCreate()) {
+      catalog.createNamespace(NS);
+    }
+
     Table table = catalog.buildTable(TABLE, SCHEMA).create();
     ReplaceSortOrder update = table.replaceSortOrder().asc(Expressions.bucket("id", 16)).asc("id");
 
@@ -1239,6 +1282,10 @@ public abstract class CatalogTests<C extends Catalog & SupportsNamespaces> {
         supportsServerSideRetry());
     C catalog = catalog();
 
+    if (requiresNamespaceCreate()) {
+      catalog.createNamespace(NS);
+    }
+
     Table table = catalog.buildTable(TABLE, SCHEMA).create();
 
     ReplaceSortOrder update = table.replaceSortOrder().asc(Expressions.bucket("id", 16)).asc("id");
@@ -1265,6 +1312,10 @@ public abstract class CatalogTests<C extends Catalog & SupportsNamespaces> {
   public void testUpdateTableOrderThenRevert() {
     C catalog = catalog();
 
+    if (requiresNamespaceCreate()) {
+      catalog.createNamespace(NS);
+    }
+
     Table table = catalog.buildTable(TABLE, SCHEMA).withSortOrder(WRITE_ORDER).create();
 
     table.replaceSortOrder().asc("id").commit();
@@ -1279,6 +1330,10 @@ public abstract class CatalogTests<C extends Catalog & SupportsNamespaces> {
   public void testAppend() throws IOException {
     C catalog = catalog();
 
+    if (requiresNamespaceCreate()) {
+      catalog.createNamespace(NS);
+    }
+
     Table table = catalog.buildTable(TABLE, SCHEMA).withPartitionSpec(SPEC).create();
 
     try (CloseableIterable<FileScanTask> tasks = table.newScan().planFiles()) {
@@ -1294,6 +1349,10 @@ public abstract class CatalogTests<C extends Catalog & SupportsNamespaces> {
   public void testConcurrentAppendEmptyTable() {
     C catalog = catalog();
 
+    if (requiresNamespaceCreate()) {
+      catalog.createNamespace(NS);
+    }
+
     Table table = catalog.buildTable(TABLE, SCHEMA).withPartitionSpec(SPEC).create();
 
     assertNoFiles(table);
@@ -1314,6 +1373,10 @@ public abstract class CatalogTests<C extends Catalog & SupportsNamespaces> {
   public void testConcurrentAppendNonEmptyTable() {
     C catalog = catalog();
 
+    if (requiresNamespaceCreate()) {
+      catalog.createNamespace(NS);
+    }
+
     Table table = catalog.buildTable(TABLE, SCHEMA).withPartitionSpec(SPEC).create();
 
     assertNoFiles(table);
@@ -1339,6 +1402,10 @@ public abstract class CatalogTests<C extends Catalog & SupportsNamespaces> {
   public void testUpdateTransaction() {
     C catalog = catalog();
 
+    if (requiresNamespaceCreate()) {
+      catalog.createNamespace(NS);
+    }
+
     Table table = catalog.buildTable(TABLE, SCHEMA).create();
 
     Transaction transaction = table.newTransaction();
@@ -1371,6 +1438,10 @@ public abstract class CatalogTests<C extends Catalog & SupportsNamespaces> {
   public void testCreateTransaction() {
     C catalog = catalog();
 
+    if (requiresNamespaceCreate()) {
+      catalog.createNamespace(NS);
+    }
+
     Transaction create = catalog.buildTable(TABLE, SCHEMA).createTransaction();
 
     Assert.assertFalse(
@@ -1392,6 +1463,10 @@ public abstract class CatalogTests<C extends Catalog & SupportsNamespaces> {
   public void testCompleteCreateTransaction() {
     C catalog = catalog();
 
+    if (requiresNamespaceCreate()) {
+      catalog.createNamespace(NS);
+    }
+
     Map<String, String> properties =
         ImmutableMap.of("user", "someone", "created-at", "2022-02-25T00:38:19");
     Transaction create =
@@ -1440,6 +1515,10 @@ public abstract class CatalogTests<C extends Catalog & SupportsNamespaces> {
   public void testCompleteCreateTransactionMultipleSchemas() {
     C catalog = catalog();
 
+    if (requiresNamespaceCreate()) {
+      catalog.createNamespace(NS);
+    }
+
     Map<String, String> properties =
         ImmutableMap.of("user", "someone", "created-at", "2022-02-25T00:38:19");
     Transaction create =
@@ -1525,6 +1604,10 @@ public abstract class CatalogTests<C extends Catalog & SupportsNamespaces> {
   public void testCompleteCreateTransactionV2() {
     C catalog = catalog();
 
+    if (requiresNamespaceCreate()) {
+      catalog.createNamespace(NS);
+    }
+
     Map<String, String> properties =
         ImmutableMap.of(
             "user", "someone", "created-at", "2022-02-25T00:38:19", "format-version", "2");
@@ -1582,6 +1665,10 @@ public abstract class CatalogTests<C extends Catalog & SupportsNamespaces> {
   public void testConcurrentCreateTransaction() {
     C catalog = catalog();
 
+    if (requiresNamespaceCreate()) {
+      catalog.createNamespace(NS);
+    }
+
     Transaction create = catalog.buildTable(TABLE, SCHEMA).createTransaction();
 
     Assert.assertFalse(
@@ -1598,11 +1685,9 @@ public abstract class CatalogTests<C extends Catalog & SupportsNamespaces> {
         supportsServerSideRetry()
             ? "Requirement failed: table already exists"
             : "Table already exists";
-    AssertHelpers.assertThrows(
-        "Should fail because table was created concurrently",
-        AlreadyExistsException.class,
-        expectedMessage,
-        create::commitTransaction);
+    Assertions.assertThatThrownBy(create::commitTransaction)
+        .isInstanceOf(AlreadyExistsException.class)
+        .hasMessageStartingWith(expectedMessage);
 
     // validate the concurrently created table is unmodified
     Table table = catalog.loadTable(TABLE);
@@ -1617,6 +1702,10 @@ public abstract class CatalogTests<C extends Catalog & SupportsNamespaces> {
   public void testCreateOrReplaceTransactionCreate() {
     C catalog = catalog();
 
+    if (requiresNamespaceCreate()) {
+      catalog.createNamespace(NS);
+    }
+
     Transaction create = catalog.buildTable(TABLE, SCHEMA).createOrReplaceTransaction();
 
     Assert.assertFalse(
@@ -1638,6 +1727,10 @@ public abstract class CatalogTests<C extends Catalog & SupportsNamespaces> {
   public void testCompleteCreateOrReplaceTransactionCreate() {
     C catalog = catalog();
 
+    if (requiresNamespaceCreate()) {
+      catalog.createNamespace(NS);
+    }
+
     Map<String, String> properties =
         ImmutableMap.of("user", "someone", "created-at", "2022-02-25T00:38:19");
     Transaction createOrReplace =
@@ -1686,6 +1779,10 @@ public abstract class CatalogTests<C extends Catalog & SupportsNamespaces> {
   public void testCreateOrReplaceReplaceTransactionReplace() {
     C catalog = catalog();
 
+    if (requiresNamespaceCreate()) {
+      catalog.createNamespace(NS);
+    }
+
     Table original = catalog.buildTable(TABLE, OTHER_SCHEMA).create();
 
     Assert.assertTrue("Table should exist before replaceTransaction", catalog.tableExists(TABLE));
@@ -1727,6 +1824,10 @@ public abstract class CatalogTests<C extends Catalog & SupportsNamespaces> {
   public void testCompleteCreateOrReplaceTransactionReplace() {
     C catalog = catalog();
 
+    if (requiresNamespaceCreate()) {
+      catalog.createNamespace(NS);
+    }
+
     Table original = catalog.buildTable(TABLE, OTHER_SCHEMA).create();
 
     Assert.assertTrue("Table should exist before replaceTransaction", catalog.tableExists(TABLE));
@@ -1796,6 +1897,10 @@ public abstract class CatalogTests<C extends Catalog & SupportsNamespaces> {
 
     C catalog = catalog();
 
+    if (requiresNamespaceCreate()) {
+      catalog.createNamespace(NS);
+    }
+
     Transaction createOrReplace = catalog.buildTable(TABLE, SCHEMA).createOrReplaceTransaction();
 
     Assert.assertFalse(
@@ -1811,11 +1916,9 @@ public abstract class CatalogTests<C extends Catalog & SupportsNamespaces> {
         supportsServerSideRetry()
             ? "Requirement failed: table already exists"
             : "Table already exists";
-    AssertHelpers.assertThrows(
-        "Should fail because table was created concurrently",
-        AlreadyExistsException.class,
-        expectedMessage,
-        createOrReplace::commitTransaction);
+    Assertions.assertThatThrownBy(createOrReplace::commitTransaction)
+        .isInstanceOf(AlreadyExistsException.class)
+        .hasMessage(expectedMessage);
 
     // validate the concurrently created table is unmodified
     Table table = catalog.loadTable(TABLE);
@@ -1830,6 +1933,10 @@ public abstract class CatalogTests<C extends Catalog & SupportsNamespaces> {
   public void testReplaceTransaction() {
     C catalog = catalog();
 
+    if (requiresNamespaceCreate()) {
+      catalog.createNamespace(NS);
+    }
+
     Table original = catalog.buildTable(TABLE, OTHER_SCHEMA).create();
 
     Assert.assertTrue("Table should exist before replaceTransaction", catalog.tableExists(TABLE));
@@ -1871,6 +1978,10 @@ public abstract class CatalogTests<C extends Catalog & SupportsNamespaces> {
   public void testCompleteReplaceTransaction() {
     C catalog = catalog();
 
+    if (requiresNamespaceCreate()) {
+      catalog.createNamespace(NS);
+    }
+
     Table original = catalog.buildTable(TABLE, OTHER_SCHEMA).create();
 
     Assert.assertTrue("Table should exist before replaceTransaction", catalog.tableExists(TABLE));
@@ -1936,17 +2047,23 @@ public abstract class CatalogTests<C extends Catalog & SupportsNamespaces> {
   public void testReplaceTransactionRequiresTableExists() {
     C catalog = catalog();
 
-    AssertHelpers.assertThrows(
-        "Should fail to create replace transaction with a missing table",
-        NoSuchTableException.class,
-        "Table does not exist",
-        () -> catalog.buildTable(TABLE, SCHEMA).replaceTransaction());
+    if (requiresNamespaceCreate()) {
+      catalog.createNamespace(NS);
+    }
+
+    Assertions.assertThatThrownBy(() -> catalog.buildTable(TABLE, SCHEMA).replaceTransaction())
+        .isInstanceOf(NoSuchTableException.class)
+        .hasMessage("Table does not exist: newdb.table");
   }
 
   @Test
   public void testConcurrentReplaceTransactions() {
     C catalog = catalog();
 
+    if (requiresNamespaceCreate()) {
+      catalog.createNamespace(NS);
+    }
+
     Transaction transaction = catalog.buildTable(TABLE, SCHEMA).createTransaction();
     transaction.newFastAppend().appendFile(FILE_A).commit();
     transaction.commitTransaction();
@@ -1988,6 +2105,10 @@ public abstract class CatalogTests<C extends Catalog & SupportsNamespaces> {
   public void testConcurrentReplaceTransactionSchema() {
     C catalog = catalog();
 
+    if (requiresNamespaceCreate()) {
+      catalog.createNamespace(NS);
+    }
+
     Transaction transaction = catalog.buildTable(TABLE, OTHER_SCHEMA).createTransaction();
     transaction.newFastAppend().appendFile(FILE_A).commit();
     transaction.commitTransaction();
@@ -2025,6 +2146,10 @@ public abstract class CatalogTests<C extends Catalog & SupportsNamespaces> {
   public void testConcurrentReplaceTransactionSchema2() {
     C catalog = catalog();
 
+    if (requiresNamespaceCreate()) {
+      catalog.createNamespace(NS);
+    }
+
     Transaction transaction = catalog.buildTable(TABLE, OTHER_SCHEMA).createTransaction();
     transaction.newFastAppend().appendFile(FILE_A).commit();
     transaction.commitTransaction();
@@ -2064,6 +2189,10 @@ public abstract class CatalogTests<C extends Catalog & SupportsNamespaces> {
 
     C catalog = catalog();
 
+    if (requiresNamespaceCreate()) {
+      catalog.createNamespace(NS);
+    }
+
     Transaction transaction = catalog.buildTable(TABLE, OTHER_SCHEMA).createTransaction();
     transaction.newFastAppend().appendFile(FILE_A).commit();
     transaction.commitTransaction();
@@ -2088,17 +2217,20 @@ public abstract class CatalogTests<C extends Catalog & SupportsNamespaces> {
 
     // even though the new schema is identical, the assertion that the last assigned id has not
     // changed will fail
-    AssertHelpers.assertThrows(
-        "Should reject concurrent schema update",
-        CommitFailedException.class,
-        "last assigned field id changed",
-        secondReplace::commitTransaction);
+    Assertions.assertThatThrownBy(secondReplace::commitTransaction)
+        .isInstanceOf(CommitFailedException.class)
+        .hasMessageStartingWith(
+            "Commit failed: Requirement failed: last assigned field id changed");
   }
 
   @Test
   public void testConcurrentReplaceTransactionPartitionSpec() {
     C catalog = catalog();
 
+    if (requiresNamespaceCreate()) {
+      catalog.createNamespace(NS);
+    }
+
     Transaction transaction = catalog.buildTable(TABLE, SCHEMA).createTransaction();
     transaction.newFastAppend().appendFile(FILE_A).commit();
     transaction.commitTransaction();
@@ -2134,6 +2266,10 @@ public abstract class CatalogTests<C extends Catalog & SupportsNamespaces> {
   public void testConcurrentReplaceTransactionPartitionSpec2() {
     C catalog = catalog();
 
+    if (requiresNamespaceCreate()) {
+      catalog.createNamespace(NS);
+    }
+
     Transaction transaction = catalog.buildTable(TABLE, SCHEMA).createTransaction();
     transaction.newFastAppend().appendFile(FILE_A).commit();
     transaction.commitTransaction();
@@ -2170,6 +2306,10 @@ public abstract class CatalogTests<C extends Catalog & SupportsNamespaces> {
     Assume.assumeTrue("Spec conflicts are detected server-side", supportsServerSideRetry());
     C catalog = catalog();
 
+    if (requiresNamespaceCreate()) {
+      catalog.createNamespace(NS);
+    }
+
     Transaction transaction = catalog.buildTable(TABLE, SCHEMA).createTransaction();
     transaction.newFastAppend().appendFile(FILE_A).commit();
     transaction.commitTransaction();
@@ -2196,17 +2336,20 @@ public abstract class CatalogTests<C extends Catalog & SupportsNamespaces> {
 
     // even though the new spec is identical, the assertion that the last assigned id has not
     // changed will fail
-    AssertHelpers.assertThrows(
-        "Should reject concurrent spec update",
-        CommitFailedException.class,
-        "last assigned partition id changed",
-        secondReplace::commitTransaction);
+    Assertions.assertThatThrownBy(secondReplace::commitTransaction)
+        .isInstanceOf(CommitFailedException.class)
+        .hasMessageStartingWith(
+            "Commit failed: Requirement failed: last assigned partition id changed");
   }
 
   @Test
   public void testConcurrentReplaceTransactionSortOrder() {
     C catalog = catalog();
 
+    if (requiresNamespaceCreate()) {
+      catalog.createNamespace(NS);
+    }
+
     Transaction transaction = catalog.buildTable(TABLE, SCHEMA).createTransaction();
     transaction.newFastAppend().appendFile(FILE_A).commit();
     transaction.commitTransaction();
@@ -2240,6 +2383,10 @@ public abstract class CatalogTests<C extends Catalog & SupportsNamespaces> {
   public void testConcurrentReplaceTransactionSortOrderConflict() {
     C catalog = catalog();
 
+    if (requiresNamespaceCreate()) {
+      catalog.createNamespace(NS);
+    }
+
     Transaction transaction = catalog.buildTable(TABLE, SCHEMA).createTransaction();
     transaction.newFastAppend().appendFile(FILE_A).commit();
     transaction.commitTransaction();
@@ -2280,6 +2427,10 @@ public abstract class CatalogTests<C extends Catalog & SupportsNamespaces> {
   public void testMetadataFileLocationsRemovalAfterCommit() {
     C catalog = catalog();
 
+    if (requiresNamespaceCreate()) {
+      catalog.createNamespace(NS);
+    }
+
     Table table = catalog.buildTable(TABLE, SCHEMA).create();
     table.updateSchema().addColumn("a", Types.LongType.get()).commit();
     table.updateSchema().addColumn("b", Types.LongType.get()).commit();
@@ -2325,6 +2476,17 @@ public abstract class CatalogTests<C extends Catalog & SupportsNamespaces> {
     }
   }
 
+  @Test
+  public void tableCreationWithoutNamespace() {
+    Assumptions.assumeTrue(requiresNamespaceCreate());
+
+    Assertions.assertThatThrownBy(
+            () ->
+                catalog().buildTable(TableIdentifier.of("non-existing", "table"), SCHEMA).create())
+        .isInstanceOf(NoSuchNamespaceException.class)
+        .hasMessageEndingWith("Namespace does not exist: non-existing");
+  }
+
   private static void assertEmpty(String context, Catalog catalog, Namespace ns) {
     try {
       Assert.assertEquals(context, 0, catalog.listTables(ns).size());
