@@ -18,8 +18,8 @@
  */
 package org.apache.iceberg.dell.ecs;
 
-import org.apache.iceberg.AssertHelpers;
 import org.apache.iceberg.exceptions.ValidationException;
+import org.assertj.core.api.Assertions;
 import org.junit.Assert;
 import org.junit.Test;
 
@@ -54,10 +54,9 @@ public class TestEcsURI {
 
   @Test
   public void testInvalidLocation() {
-    AssertHelpers.assertThrows(
-        "Invalid location should cause exception",
-        ValidationException.class,
-        "http://bucket/a",
-        () -> new EcsURI("http://bucket/a"));
+
+    Assertions.assertThatThrownBy(() -> new EcsURI("http://bucket/a"))
+        .isInstanceOf(ValidationException.class)
+        .hasMessage("Invalid ecs location: http://bucket/a");
   }
 }
