@@ -156,11 +156,15 @@ Convenience binary artifacts are staged on Nexus. The Maven repository URL is:
 
 Please download, verify, and test.
 
-Please vote in the next 72 hours.
+Please vote in the next 72 hours. (Weekends excluded)
 
 [ ] +1 Release this as Apache Iceberg ${version}
 [ ] +0
 [ ] -1 Do not release this because...
+
+Only PMC members have binding votes, but other community members are encouraged to cast
+non-binding votes. This vote will pass if there are 3 binding +1 votes and more binding
++1 votes than -1 votes.
 EOF
 
 echo "Success! The release candidate is available here:"
