@@ -28,6 +28,7 @@ import org.apache.flink.annotation.VisibleForTesting;
 import org.apache.flink.util.Preconditions;
 import org.apache.iceberg.Snapshot;
 import org.apache.iceberg.Table;
+import org.apache.iceberg.flink.TableLoader;
 import org.apache.iceberg.flink.source.FlinkSplitPlanner;
 import org.apache.iceberg.flink.source.ScanContext;
 import org.apache.iceberg.flink.source.StreamingStartingStrategy;
@@ -46,13 +47,18 @@ public class ContinuousSplitPlannerImpl implements ContinuousSplitPlanner {
   private final ScanContext scanContext;
   private final boolean isSharedPool;
   private final ExecutorService workerPool;
+  private final TableLoader tableLoader;
 
   /**
+   * @param tableLoader A cloned tableLoader.
    * @param threadName thread name prefix for worker pool to run the split planning. If null, a
    *     shared worker pool will be used.
    */
-  public ContinuousSplitPlannerImpl(Table table, ScanContext scanContext, String threadName) {
-    this.table = table;
+  public ContinuousSplitPlannerImpl(
+      TableLoader tableLoader, ScanContext scanContext, String threadName) {
+    this.tableLoader = tableLoader;
+    this.tableLoader.open();
+    this.table = tableLoader.loadTable();
     this.scanContext = scanContext;
     this.isSharedPool = threadName == null;
     this.workerPool =
@@ -67,6 +73,7 @@ public class ContinuousSplitPlannerImpl implements ContinuousSplitPlanner {
     if (!isSharedPool) {
       workerPool.shutdown();
     }
+    tableLoader.close();
   }
 
   @Override
@@ -159,7 +166,9 @@ public class ContinuousSplitPlannerImpl implements ContinuousSplitPlanner {
     if (scanContext.streamingStartingStrategy()
         == StreamingStartingStrategy.TABLE_SCAN_THEN_INCREMENTAL) {
       // do a batch table scan first
-      splits = FlinkSplitPlanner.planIcebergSourceSplits(table, scanContext, workerPool);
+      splits =
+          FlinkSplitPlanner.planIcebergSourceSplits(
+              table, scanContext.copyWithSnapshotId(startSnapshot.snapshotId()), workerPool);
       LOG.info(
           "Discovered {} splits from initial batch table scan with snapshot Id {}",
           splits.size(),
