@@ -16,10 +16,10 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-
 package org.apache.iceberg.flink.sink;
 
 import java.io.IOException;
+import java.util.concurrent.TimeUnit;
 import org.apache.flink.streaming.api.operators.AbstractStreamOperator;
 import org.apache.flink.streaming.api.operators.BoundedOneInput;
 import org.apache.flink.streaming.api.operators.ChainingStrategy;
@@ -40,6 +40,7 @@ class IcebergStreamWriter<T> extends AbstractStreamOperator<WriteResult>
   private transient TaskWriter<T> writer;
   private transient int subTaskId;
   private transient int attemptId;
+  private transient IcebergStreamWriterMetrics writerMetrics;
 
   IcebergStreamWriter(String fullTableName, TaskWriterFactory<T> taskWriterFactory) {
     this.fullTableName = fullTableName;
@@ -51,6 +52,7 @@ class IcebergStreamWriter<T> extends AbstractStreamOperator<WriteResult>
   public void open() {
     this.subTaskId = getRuntimeContext().getIndexOfThisSubtask();
     this.attemptId = getRuntimeContext().getAttemptNumber();
+    this.writerMetrics = new IcebergStreamWriterMetrics(super.metrics, fullTableName);
 
     // Initialize the task writer factory.
     this.taskWriterFactory.initialize(subTaskId, attemptId);
@@ -61,9 +63,7 @@ class IcebergStreamWriter<T> extends AbstractStreamOperator<WriteResult>
 
   @Override
   public void prepareSnapshotPreBarrier(long checkpointId) throws Exception {
-    // close all open files and emit files to downstream committer operator
-    emit(writer.complete());
-
+    flush();
     this.writer = taskWriterFactory.create();
   }
 
@@ -73,8 +73,8 @@ class IcebergStreamWriter<T> extends AbstractStreamOperator<WriteResult>
   }
 
   @Override
-  public void dispose() throws Exception {
-    super.dispose();
+  public void close() throws Exception {
+    super.close();
     if (writer != null) {
       writer.close();
       writer = null;
@@ -83,9 +83,13 @@ class IcebergStreamWriter<T> extends AbstractStreamOperator<WriteResult>
 
   @Override
   public void endInput() throws IOException {
-    // For bounded stream, it may don't enable the checkpoint mechanism so we'd better to emit the remaining
-    // completed files to downstream before closing the writer so that we won't miss any of them.
-    emit(writer.complete());
+    // For bounded stream, it may don't enable the checkpoint mechanism so we'd better to emit the
+    // remaining completed files to downstream before closing the writer so that we won't miss any
+    // of them.
+    // Note that if the task is not closed after calling endInput, checkpoint may be triggered again
+    // causing files to be sent repeatedly, the writer is marked as null after the last file is sent
+    // to guard against duplicated writes.
+    flush();
   }
 
   @Override
@@ -97,7 +101,20 @@ class IcebergStreamWriter<T> extends AbstractStreamOperator<WriteResult>
         .toString();
   }
 
-  private void emit(WriteResult result) {
+  /** close all open files and emit files to downstream committer operator */
+  private void flush() throws IOException {
+    if (writer == null) {
+      return;
+    }
+
+    long startNano = System.nanoTime();
+    WriteResult result = writer.complete();
+    writerMetrics.updateFlushResult(result);
     output.collect(new StreamRecord<>(result));
+    writerMetrics.flushDuration(TimeUnit.NANOSECONDS.toMillis(System.nanoTime() - startNano));
+
+    // Set writer to null to prevent duplicate flushes in the corner case of
+    // prepareSnapshotPreBarrier happening after endInput.
+    writer = null;
   }
 }
