@@ -80,12 +80,6 @@ public class TestCatalogTableLoader extends FlinkTestBase {
     validateTableLoader(TableLoader.fromCatalog(catalogLoader, IDENTIFIER));
   }
 
-  private static void validateCatalogLoader(CatalogLoader loader)
-      throws IOException, ClassNotFoundException {
-    Table table = javaSerdes(loader).loadCatalog().createTable(IDENTIFIER, SCHEMA);
-    validateHadoopConf(table);
-  }
-
   private static void validateTableLoader(TableLoader loader)
       throws IOException, ClassNotFoundException {
     TableLoader copied = javaSerdes(loader);
