@@ -88,6 +88,10 @@ public class TestChangeLogTable extends ChangeLogTableTestBase {
     sql("USE CATALOG %s", CATALOG_NAME);
     sql("CREATE DATABASE %s", DATABASE_NAME);
     sql("USE %s", DATABASE_NAME);
+    // Set the table.exec.sink.upsert-materialize=NONE, so that downstream operators will receive
+    // the
+    // records with the same order as the source operator, bypassing Flink's inferred shuffle.
+    getTableEnv().getConfig().set("table.exec.sink.upsert-materialize", "NONE");
   }
 
   @After
@@ -95,7 +99,7 @@ public class TestChangeLogTable extends ChangeLogTableTestBase {
   public void clean() {
     sql("DROP TABLE IF EXISTS %s", TABLE_NAME);
     sql("DROP DATABASE IF EXISTS %s", DATABASE_NAME);
-    sql("DROP CATALOG IF EXISTS %s", CATALOG_NAME);
+    dropCatalog(CATALOG_NAME, true);
     BoundedTableFactory.clearDataSets();
   }
 
