@@ -28,6 +28,7 @@ import org.apache.flink.table.api.TableSchema;
 import org.apache.flink.table.data.RowData;
 import org.apache.flink.test.util.MiniClusterWithClientResource;
 import org.apache.flink.types.Row;
+import org.apache.iceberg.AssertHelpers;
 import org.apache.iceberg.DistributionMode;
 import org.apache.iceberg.FileFormat;
 import org.apache.iceberg.PartitionSpec;
@@ -44,7 +45,6 @@ import org.apache.iceberg.flink.util.FlinkCompatibilityUtil;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableMap;
 import org.apache.iceberg.relocated.com.google.common.collect.Lists;
 import org.apache.iceberg.relocated.com.google.common.collect.Maps;
-import org.assertj.core.api.Assertions;
 import org.junit.Assert;
 import org.junit.Before;
 import org.junit.ClassRule;
@@ -197,9 +197,14 @@ public class TestFlinkIcebergSink extends TestFlinkIcebergSinkBase {
         .set(TableProperties.WRITE_DISTRIBUTION_MODE, DistributionMode.HASH.modeName())
         .commit();
 
-    Assertions.assertThatThrownBy(() -> testWriteRow(null, DistributionMode.RANGE))
-        .isInstanceOf(IllegalArgumentException.class)
-        .hasMessage("Flink does not support 'range' write distribution mode now.");
+    AssertHelpers.assertThrows(
+        "Does not support range distribution-mode now.",
+        IllegalArgumentException.class,
+        "Flink does not support 'range' write distribution mode now.",
+        () -> {
+          testWriteRow(null, DistributionMode.RANGE);
+          return null;
+        });
   }
 
   @Test
@@ -345,9 +350,17 @@ public class TestFlinkIcebergSink extends TestFlinkIcebergSinkBase {
             .writeParallelism(parallelism)
             .setAll(newProps);
 
-    Assertions.assertThatThrownBy(builder::append)
-        .isInstanceOf(IllegalArgumentException.class)
-        .hasMessage("Invalid distribution mode: UNRECOGNIZED");
+    AssertHelpers.assertThrows(
+        "Should fail with invalid distribution mode.",
+        IllegalArgumentException.class,
+        "Invalid distribution mode: UNRECOGNIZED",
+        () -> {
+          builder.append();
+
+          // Execute the program.
+          env.execute("Test Iceberg DataStream.");
+          return null;
+        });
   }
 
   @Test
@@ -365,8 +378,16 @@ public class TestFlinkIcebergSink extends TestFlinkIcebergSinkBase {
             .writeParallelism(parallelism)
             .setAll(newProps);
 
-    Assertions.assertThatThrownBy(builder::append)
-        .isInstanceOf(IllegalArgumentException.class)
-        .hasMessage("Invalid file format: UNRECOGNIZED");
+    AssertHelpers.assertThrows(
+        "Should fail with invalid file format.",
+        IllegalArgumentException.class,
+        "Invalid file format: UNRECOGNIZED",
+        () -> {
+          builder.append();
+
+          // Execute the program.
+          env.execute("Test Iceberg DataStream.");
+          return null;
+        });
   }
 }
