@@ -41,6 +41,12 @@ public class TestTableLoader implements TableLoader {
     return TestTables.load(dir, "test");
   }
 
+  @Override
+  @SuppressWarnings({"checkstyle:NoClone", "checkstyle:SuperClone"})
+  public TableLoader clone() {
+    return new TestTableLoader(dir.getAbsolutePath());
+  }
+
   @Override
   public void close() {}
 }
