@@ -16,7 +16,6 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-
 package org.apache.iceberg.gcp.gcs;
 
 import com.google.cloud.storage.BlobId;
@@ -29,18 +28,31 @@ import org.apache.iceberg.metrics.MetricsContext;
 class GCSInputFile extends BaseGCSFile implements InputFile {
   private Long length;
 
-  static GCSInputFile fromLocation(String location, Storage storage,
-                                   GCPProperties gcpProperties, MetricsContext metrics) {
+  static GCSInputFile fromLocation(
+      String location, Storage storage, GCPProperties gcpProperties, MetricsContext metrics) {
     return new GCSInputFile(storage, BlobId.fromGsUtilUri(location), null, gcpProperties, metrics);
   }
 
-  static GCSInputFile fromLocation(String location, long length, Storage storage,
-      GCPProperties gcpProperties, MetricsContext metrics) {
+  static GCSInputFile fromLocation(
+      String location,
+      long length,
+      Storage storage,
+      GCPProperties gcpProperties,
+      MetricsContext metrics) {
     return new GCSInputFile(
-        storage, BlobId.fromGsUtilUri(location), length > 0 ? length : null, gcpProperties, metrics);
+        storage,
+        BlobId.fromGsUtilUri(location),
+        length > 0 ? length : null,
+        gcpProperties,
+        metrics);
   }
 
-  GCSInputFile(Storage storage, BlobId blobId, Long length, GCPProperties gcpProperties, MetricsContext metrics) {
+  GCSInputFile(
+      Storage storage,
+      BlobId blobId,
+      Long length,
+      GCPProperties gcpProperties,
+      MetricsContext metrics) {
     super(storage, blobId, gcpProperties, metrics);
     this.length = length;
   }
