@@ -16,9 +16,10 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-
 package org.apache.iceberg.mr.hive.serde.objectinspector;
 
+import static org.apache.iceberg.types.Types.NestedField.required;
+
 import org.apache.hadoop.hive.serde2.objectinspector.StructField;
 import org.apache.hadoop.hive.serde2.objectinspector.StructObjectInspector;
 import org.apache.iceberg.Schema;
@@ -29,23 +30,25 @@ import org.apache.iceberg.types.Types;
 import org.junit.Assert;
 import org.junit.Test;
 
-import static org.apache.iceberg.types.Types.NestedField.required;
-
 public class TestIcebergRecordObjectInspector {
 
   @Test
   public void testIcebergRecordObjectInspector() {
-    Schema schema = new Schema(
+    Schema schema =
+        new Schema(
             required(1, "integer_field", Types.IntegerType.get()),
-            required(2, "struct_field", Types.StructType.of(
-                    Types.NestedField.required(3, "string_field", Types.StringType.get())))
-    );
+            required(
+                2,
+                "struct_field",
+                Types.StructType.of(
+                    Types.NestedField.required(3, "string_field", Types.StringType.get()))));
 
     Record record = RandomGenericData.generate(schema, 1, 0L).get(0);
     Record innerRecord = record.get(1, Record.class);
 
     StructObjectInspector soi = (StructObjectInspector) IcebergObjectInspector.create(schema);
-    Assert.assertEquals(ImmutableList.of(record.get(0), record.get(1)), soi.getStructFieldsDataAsList(record));
+    Assert.assertEquals(
+        ImmutableList.of(record.get(0), record.get(1)), soi.getStructFieldsDataAsList(record));
 
     StructField integerField = soi.getStructFieldRef("integer_field");
     Assert.assertEquals(record.get(0), soi.getStructFieldData(record, integerField));
@@ -57,21 +60,24 @@ public class TestIcebergRecordObjectInspector {
     StructObjectInspector innerSoi = (StructObjectInspector) structField.getFieldObjectInspector();
     StructField stringField = innerSoi.getStructFieldRef("string_field");
 
-    Assert.assertEquals(ImmutableList.of(innerRecord.get(0)), innerSoi.getStructFieldsDataAsList(innerRecord));
+    Assert.assertEquals(
+        ImmutableList.of(innerRecord.get(0)), innerSoi.getStructFieldsDataAsList(innerRecord));
     Assert.assertEquals(innerRecord.get(0), innerSoi.getStructFieldData(innerData, stringField));
   }
 
   @Test
   public void testIcebergRecordObjectInspectorWithRowNull() {
-    Schema schema = new Schema(
-        required(1, "integer_field", Types.IntegerType.get()),
-        required(2, "struct_field", Types.StructType.of(
-            Types.NestedField.required(3, "string_field", Types.StringType.get())))
-    );
+    Schema schema =
+        new Schema(
+            required(1, "integer_field", Types.IntegerType.get()),
+            required(
+                2,
+                "struct_field",
+                Types.StructType.of(
+                    Types.NestedField.required(3, "string_field", Types.StringType.get()))));
     StructObjectInspector soi = (StructObjectInspector) IcebergObjectInspector.create(schema);
     Assert.assertNull(soi.getStructFieldsDataAsList(null));
     StructField integerField = soi.getStructFieldRef("integer_field");
     Assert.assertNull(soi.getStructFieldData(null, integerField));
   }
-
 }
