@@ -20,27 +20,28 @@
 package org.apache.spark.sql.catalyst.analysis
 
 import org.apache.spark.sql.AnalysisException
-import org.apache.spark.sql.catalyst.SQLConfHelper
 import org.apache.spark.sql.catalyst.expressions.Alias
 import org.apache.spark.sql.catalyst.expressions.AnsiCast
-import org.apache.spark.sql.catalyst.expressions.AssignmentUtils._
+import org.apache.spark.sql.catalyst.expressions.AttributeReference
 import org.apache.spark.sql.catalyst.expressions.Cast
 import org.apache.spark.sql.catalyst.expressions.CreateNamedStruct
 import org.apache.spark.sql.catalyst.expressions.Expression
+import org.apache.spark.sql.catalyst.expressions.ExtractValue
 import org.apache.spark.sql.catalyst.expressions.GetStructField
 import org.apache.spark.sql.catalyst.expressions.Literal
 import org.apache.spark.sql.catalyst.expressions.NamedExpression
 import org.apache.spark.sql.catalyst.plans.logical.Assignment
 import org.apache.spark.sql.catalyst.plans.logical.LogicalPlan
+import org.apache.spark.sql.internal.SQLConf
 import org.apache.spark.sql.internal.SQLConf.StoreAssignmentPolicy
 import org.apache.spark.sql.types.DataType
 import org.apache.spark.sql.types.StructField
 import org.apache.spark.sql.types.StructType
 import scala.collection.mutable
 
-trait AssignmentAlignmentSupport extends CastSupport {
+trait AssignmentAlignmentSupport {
 
-  self: SQLConfHelper =>
+  def conf: SQLConf
 
   private case class ColumnUpdate(ref: Seq[String], expr: Expression)
 
@@ -66,10 +67,10 @@ trait AssignmentAlignmentSupport extends CastSupport {
       table: LogicalPlan,
       assignments: Seq[Assignment]): Seq[Assignment] = {
 
-    val columnUpdates = assignments.map(a => ColumnUpdate(toAssignmentRef(a.key), a.value))
+    val columnUpdates = assignments.map(a => ColumnUpdate(a.key, a.value))
     val outputExprs = applyUpdates(table.output, columnUpdates)
     outputExprs.zip(table.output).map {
-      case (expr, attr) => handleCharVarcharLimits(Assignment(attr, expr))
+      case (expr, attr) => Assignment(attr, expr)
     }
   }
 
@@ -103,11 +104,7 @@ trait AssignmentAlignmentSupport extends CastSupport {
 
               // recursively apply this method on nested fields
               val newUpdates = updates.map(u => u.copy(ref = u.ref.tail))
-              val updatedFieldExprs = applyUpdates(
-                fieldExprs,
-                newUpdates,
-                resolver,
-                namePrefix :+ col.name)
+              val updatedFieldExprs = applyUpdates(fieldExprs, newUpdates, resolver, namePrefix :+ col.name)
 
               // construct a new struct with updated field expressions
               toNamedStruct(fields, updatedFieldExprs)
@@ -174,7 +171,7 @@ trait AssignmentAlignmentSupport extends CastSupport {
             s"Cannot write nullable values to non-null column '${tableAttr.name}'")
         }
 
-        // use byName = true to catch cases when struct field names don't match
+        // we use byName = true to catch cases when struct field names don't match
         // e.g. a struct with fields (a, b) is assigned as a struct with fields (a, c) or (b, a)
         val errors = new mutable.ArrayBuffer[String]()
         val canWrite = DataType.canWrite(
@@ -182,8 +179,7 @@ trait AssignmentAlignmentSupport extends CastSupport {
           storeAssignmentPolicy, err => errors += err)
 
         if (!canWrite) {
-          throw new AnalysisException(
-            s"Cannot write incompatible data:\n- ${errors.mkString("\n- ")}")
+          throw new AnalysisException(s"Cannot write incompatible data:\n- ${errors.mkString("\n- ")}")
         }
 
       case _ => // OK
@@ -198,4 +194,14 @@ trait AssignmentAlignmentSupport extends CastSupport {
         Cast(expr, tableAttr.dataType, Option(conf.sessionLocalTimeZone))
     }
   }
+
+  implicit protected def asAssignmentReference(expr: Expression): Seq[String] = expr match {
+    case attr: AttributeReference => Seq(attr.name)
+    case Alias(child, _) => asAssignmentReference(child)
+    case GetStructField(child, _, Some(name)) => asAssignmentReference(child) :+ name
+    case other: ExtractValue =>
+      throw new AnalysisException(s"Updating nested fields is only supported for structs: $other")
+    case other =>
+      throw new AnalysisException(s"Cannot convert to a reference, unsupported expression: $other")
+  }
 }
