@@ -16,9 +16,15 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-
 package org.apache.iceberg.spark.source;
 
+import static org.apache.iceberg.TableProperties.SPLIT_OPEN_FILE_COST;
+import static org.apache.iceberg.types.Types.NestedField.optional;
+import static org.apache.iceberg.types.Types.NestedField.required;
+import static org.apache.spark.sql.functions.current_date;
+import static org.apache.spark.sql.functions.date_add;
+import static org.apache.spark.sql.functions.expr;
+
 import java.io.IOException;
 import java.util.List;
 import java.util.Map;
@@ -33,18 +39,15 @@ import org.apache.iceberg.Table;
 import org.apache.iceberg.TableProperties;
 import org.apache.iceberg.deletes.PositionDelete;
 import org.apache.iceberg.hadoop.HadoopTables;
-import org.apache.iceberg.io.ClusteredEqualityDeleteWriter;
 import org.apache.iceberg.io.ClusteredPositionDeleteWriter;
 import org.apache.iceberg.io.OutputFileFactory;
 import org.apache.iceberg.relocated.com.google.common.collect.Iterables;
-import org.apache.iceberg.relocated.com.google.common.collect.Lists;
 import org.apache.iceberg.relocated.com.google.common.collect.Maps;
 import org.apache.iceberg.relocated.com.google.common.collect.Sets;
 import org.apache.iceberg.types.Types;
 import org.apache.spark.sql.Dataset;
 import org.apache.spark.sql.Row;
 import org.apache.spark.sql.catalyst.InternalRow;
-import org.apache.spark.sql.catalyst.expressions.GenericInternalRow;
 import org.openjdk.jmh.annotations.Benchmark;
 import org.openjdk.jmh.annotations.Setup;
 import org.openjdk.jmh.annotations.TearDown;
@@ -52,13 +55,6 @@ import org.openjdk.jmh.annotations.Threads;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import static org.apache.iceberg.TableProperties.SPLIT_OPEN_FILE_COST;
-import static org.apache.iceberg.types.Types.NestedField.optional;
-import static org.apache.iceberg.types.Types.NestedField.required;
-import static org.apache.spark.sql.functions.current_date;
-import static org.apache.spark.sql.functions.date_add;
-import static org.apache.spark.sql.functions.expr;
-
 public abstract class IcebergSourceDeleteBenchmark extends IcebergSourceBenchmark {
   private static final Logger LOG = LoggerFactory.getLogger(IcebergSourceDeleteBenchmark.class);
   private static final long TARGET_FILE_SIZE_IN_BYTES = 512L * 1024 * 1024;
@@ -83,11 +79,13 @@ public abstract class IcebergSourceDeleteBenchmark extends IcebergSourceBenchmar
   public void readIceberg() {
     Map<String, String> tableProperties = Maps.newHashMap();
     tableProperties.put(SPLIT_OPEN_FILE_COST, Integer.toString(128 * 1024 * 1024));
-    withTableProperties(tableProperties, () -> {
-      String tableLocation = table().location();
-      Dataset<Row> df = spark().read().format("iceberg").load(tableLocation);
-      materialize(df);
-    });
+    withTableProperties(
+        tableProperties,
+        () -> {
+          String tableLocation = table().location();
+          Dataset<Row> df = spark().read().format("iceberg").load(tableLocation);
+          materialize(df);
+        });
   }
 
   @Benchmark
@@ -96,61 +94,42 @@ public abstract class IcebergSourceDeleteBenchmark extends IcebergSourceBenchmar
     Map<String, String> tableProperties = Maps.newHashMap();
     tableProperties.put(SPLIT_OPEN_FILE_COST, Integer.toString(128 * 1024 * 1024));
     tableProperties.put(TableProperties.PARQUET_VECTORIZATION_ENABLED, "true");
-    withTableProperties(tableProperties, () -> {
-      String tableLocation = table().location();
-      Dataset<Row> df = spark().read().format("iceberg").load(tableLocation);
-      materialize(df);
-    });
-  }
-
-  @Benchmark
-  @Threads(1)
-  public void readIcebergWithIsDeletedColumn() {
-    Map<String, String> tableProperties = Maps.newHashMap();
-    tableProperties.put(SPLIT_OPEN_FILE_COST, Integer.toString(128 * 1024 * 1024));
-    withTableProperties(tableProperties, () -> {
-      String tableLocation = table().location();
-      Dataset<Row> df = spark().read().format("iceberg").load(tableLocation).filter("_deleted = false");
-      materialize(df);
-    });
-  }
-
-  @Benchmark
-  @Threads(1)
-  public void readDeletedRows() {
-    Map<String, String> tableProperties = Maps.newHashMap();
-    tableProperties.put(SPLIT_OPEN_FILE_COST, Integer.toString(128 * 1024 * 1024));
-    withTableProperties(tableProperties, () -> {
-      String tableLocation = table().location();
-      Dataset<Row> df = spark().read().format("iceberg").load(tableLocation).filter("_deleted = true");
-      materialize(df);
-    });
+    withTableProperties(
+        tableProperties,
+        () -> {
+          String tableLocation = table().location();
+          Dataset<Row> df = spark().read().format("iceberg").load(tableLocation);
+          materialize(df);
+        });
   }
 
   protected abstract void appendData() throws IOException;
 
   protected void writeData(int fileNum) {
-    Dataset<Row> df = spark().range(NUM_ROWS)
-        .withColumnRenamed("id", "longCol")
-        .withColumn("intCol", expr("CAST(MOD(longCol, 2147483647) AS INT)"))
-        .withColumn("floatCol", expr("CAST(longCol AS FLOAT)"))
-        .withColumn("doubleCol", expr("CAST(longCol AS DOUBLE)"))
-        .withColumn("dateCol", date_add(current_date(), fileNum))
-        .withColumn("timestampCol", expr("TO_TIMESTAMP(dateCol)"))
-        .withColumn("stringCol", expr("CAST(dateCol AS STRING)"));
+    Dataset<Row> df =
+        spark()
+            .range(NUM_ROWS)
+            .withColumnRenamed("id", "longCol")
+            .withColumn("intCol", expr("CAST(MOD(longCol, 2147483647) AS INT)"))
+            .withColumn("floatCol", expr("CAST(longCol AS FLOAT)"))
+            .withColumn("doubleCol", expr("CAST(longCol AS DOUBLE)"))
+            .withColumn("dateCol", date_add(current_date(), fileNum))
+            .withColumn("timestampCol", expr("TO_TIMESTAMP(dateCol)"))
+            .withColumn("stringCol", expr("CAST(dateCol AS STRING)"));
     appendAsFile(df);
   }
 
   @Override
   protected Table initTable() {
-    Schema schema = new Schema(
-        required(1, "longCol", Types.LongType.get()),
-        required(2, "intCol", Types.IntegerType.get()),
-        required(3, "floatCol", Types.FloatType.get()),
-        optional(4, "doubleCol", Types.DoubleType.get()),
-        optional(6, "dateCol", Types.DateType.get()),
-        optional(7, "timestampCol", Types.TimestampType.withZone()),
-        optional(8, "stringCol", Types.StringType.get()));
+    Schema schema =
+        new Schema(
+            required(1, "longCol", Types.LongType.get()),
+            required(2, "intCol", Types.IntegerType.get()),
+            required(3, "floatCol", Types.FloatType.get()),
+            optional(4, "doubleCol", Types.DoubleType.get()),
+            optional(6, "dateCol", Types.DateType.get()),
+            optional(7, "timestampCol", Types.TimestampType.withZone()),
+            optional(8, "stringCol", Types.StringType.get()));
     PartitionSpec partitionSpec = PartitionSpec.unpartitioned();
     HadoopTables tables = new HadoopTables(hadoopConf());
     Map<String, String> properties = Maps.newHashMap();
@@ -164,17 +143,19 @@ public abstract class IcebergSourceDeleteBenchmark extends IcebergSourceBenchmar
     return new Configuration();
   }
 
-  protected void writePosDeletes(CharSequence path, long numRows, double percentage) throws IOException {
+  protected void writePosDeletes(CharSequence path, long numRows, double percentage)
+      throws IOException {
     writePosDeletes(path, numRows, percentage, 1);
   }
 
-  protected void writePosDeletes(CharSequence path, long numRows, double percentage,
-                                 int numDeleteFile) throws IOException {
+  protected void writePosDeletes(
+      CharSequence path, long numRows, double percentage, int numDeleteFile) throws IOException {
     writePosDeletesWithNoise(path, numRows, percentage, 0, numDeleteFile);
   }
 
-  protected void writePosDeletesWithNoise(CharSequence path, long numRows, double percentage, int numNoise,
-                                          int numDeleteFile) throws IOException {
+  protected void writePosDeletesWithNoise(
+      CharSequence path, long numRows, double percentage, int numNoise, int numDeleteFile)
+      throws IOException {
     Set<Long> deletedPos = Sets.newHashSet();
     while (deletedPos.size() < numRows * percentage) {
       deletedPos.add(ThreadLocalRandom.current().nextLong(numRows));
@@ -188,14 +169,15 @@ public abstract class IcebergSourceDeleteBenchmark extends IcebergSourceBenchmar
     }
   }
 
-  protected void writePosDeletes(CharSequence path, List<Long> deletedPos, int numNoise) throws IOException {
+  protected void writePosDeletes(CharSequence path, List<Long> deletedPos, int numNoise)
+      throws IOException {
     OutputFileFactory fileFactory = newFileFactory();
-    SparkFileWriterFactory writerFactory = SparkFileWriterFactory.builderFor(table())
-        .dataFileFormat(fileFormat())
-        .build();
+    SparkFileWriterFactory writerFactory =
+        SparkFileWriterFactory.builderFor(table()).dataFileFormat(fileFormat()).build();
 
-    ClusteredPositionDeleteWriter<InternalRow> writer = new ClusteredPositionDeleteWriter<>(
-        writerFactory, fileFactory, table().io(), TARGET_FILE_SIZE_IN_BYTES);
+    ClusteredPositionDeleteWriter<InternalRow> writer =
+        new ClusteredPositionDeleteWriter<>(
+            writerFactory, fileFactory, table().io(), TARGET_FILE_SIZE_IN_BYTES);
 
     PartitionSpec unpartitionedSpec = table().specs().get(0);
 
@@ -216,65 +198,15 @@ public abstract class IcebergSourceDeleteBenchmark extends IcebergSourceBenchmar
     rowDelta.validateDeletedFiles().commit();
   }
 
-  protected void writeEqDeletes(long numRows, double percentage) throws IOException {
-    Set<Long> deletedValues = Sets.newHashSet();
-    while (deletedValues.size() < numRows * percentage) {
-      deletedValues.add(ThreadLocalRandom.current().nextLong(numRows));
-    }
-
-    List<InternalRow> rows = Lists.newArrayList();
-    for (Long value : deletedValues) {
-      GenericInternalRow genericInternalRow = new GenericInternalRow(7);
-      genericInternalRow.setLong(0, value);
-      genericInternalRow.setInt(1, (int) (value % Integer.MAX_VALUE));
-      genericInternalRow.setFloat(2, (float) value);
-      genericInternalRow.setNullAt(3);
-      genericInternalRow.setNullAt(4);
-      genericInternalRow.setNullAt(5);
-      genericInternalRow.setNullAt(6);
-      rows.add(genericInternalRow);
-    }
-    LOG.info("Num of equality deleted rows: {}", rows.size());
-
-    writeEqDeletes(rows);
-  }
-
-  private void writeEqDeletes(List<InternalRow> rows) throws IOException {
-    int equalityFieldId = table().schema().findField("longCol").fieldId();
-
-    OutputFileFactory fileFactory = newFileFactory();
-    SparkFileWriterFactory writerFactory = SparkFileWriterFactory
-        .builderFor(table())
-        .dataFileFormat(fileFormat())
-        .equalityDeleteRowSchema(table().schema())
-        .equalityFieldIds(new int[]{equalityFieldId})
-        .build();
-
-    ClusteredEqualityDeleteWriter<InternalRow> writer = new ClusteredEqualityDeleteWriter<>(
-        writerFactory, fileFactory, table().io(), TARGET_FILE_SIZE_IN_BYTES);
-
-    PartitionSpec unpartitionedSpec = table().specs().get(0);
-    try (ClusteredEqualityDeleteWriter<InternalRow> closeableWriter = writer) {
-      for (InternalRow row : rows) {
-        closeableWriter.write(row, unpartitionedSpec, null);
-      }
-    }
-
-    RowDelta rowDelta = table().newRowDelta();
-    LOG.info("Num of Delete File: {}", writer.result().deleteFiles().size());
-    writer.result().deleteFiles().forEach(rowDelta::addDeletes);
-    rowDelta.validateDeletedFiles().commit();
-  }
-
   private OutputFileFactory newFileFactory() {
-    return OutputFileFactory.builderFor(table(), 1, 1)
-        .format(fileFormat())
-        .build();
+    return OutputFileFactory.builderFor(table(), 1, 1).format(fileFormat()).build();
   }
 
   private CharSequence noisePath(CharSequence path) {
-    // assume the data file name would be something like "00000-0-30da64e0-56b5-4743-a11b-3188a1695bf7-00001.parquet"
-    // so the dataFileSuffixLen is the UUID string length + length of "-00001.parquet", which is 36 + 14 = 60. It's OK
+    // assume the data file name would be something like
+    // "00000-0-30da64e0-56b5-4743-a11b-3188a1695bf7-00001.parquet"
+    // so the dataFileSuffixLen is the UUID string length + length of "-00001.parquet", which is 36
+    // + 14 = 60. It's OK
     // to be not accurate here.
     int dataFileSuffixLen = 60;
     UUID uuid = UUID.randomUUID();
