@@ -34,15 +34,21 @@ import static org.apache.iceberg.expressions.Expressions.startsWith;
 
 import java.sql.Date;
 import java.sql.Timestamp;
+import java.time.Instant;
+import java.time.LocalDate;
+import java.util.Map;
 import java.util.Objects;
 import java.util.stream.Collectors;
 import java.util.stream.Stream;
 import org.apache.iceberg.expressions.Expression;
 import org.apache.iceberg.expressions.Expression.Operation;
+import org.apache.iceberg.expressions.Expressions;
 import org.apache.iceberg.relocated.com.google.common.base.Preconditions;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableMap;
 import org.apache.iceberg.util.NaNUtil;
 import org.apache.spark.sql.catalyst.util.DateTimeUtils;
+import org.apache.spark.sql.sources.AlwaysFalse$;
+import org.apache.spark.sql.sources.AlwaysTrue$;
 import org.apache.spark.sql.sources.And;
 import org.apache.spark.sql.sources.EqualNullSafe;
 import org.apache.spark.sql.sources.EqualTo;
@@ -61,8 +67,10 @@ import org.apache.spark.sql.sources.StringStartsWith;
 public class SparkFilters {
   private SparkFilters() {}
 
-  private static final ImmutableMap<Class<? extends Filter>, Operation> FILTERS =
+  private static final Map<Class<? extends Filter>, Operation> FILTERS =
       ImmutableMap.<Class<? extends Filter>, Operation>builder()
+          .put(AlwaysTrue$.class, Operation.TRUE)
+          .put(AlwaysFalse$.class, Operation.FALSE)
           .put(EqualTo.class, Operation.EQ)
           .put(EqualNullSafe.class, Operation.EQ)
           .put(GreaterThan.class, Operation.GT)
@@ -78,11 +86,28 @@ public class SparkFilters {
           .put(StringStartsWith.class, Operation.STARTS_WITH)
           .buildOrThrow();
 
+  public static Expression convert(Filter[] filters) {
+    Expression expression = Expressions.alwaysTrue();
+    for (Filter filter : filters) {
+      Expression converted = convert(filter);
+      Preconditions.checkArgument(
+          converted != null, "Cannot convert filter to Iceberg: %s", filter);
+      expression = Expressions.and(expression, converted);
+    }
+    return expression;
+  }
+
   public static Expression convert(Filter filter) {
     // avoid using a chain of if instanceof statements by mapping to the expression enum.
     Operation op = FILTERS.get(filter.getClass());
     if (op != null) {
       switch (op) {
+        case TRUE:
+          return Expressions.alwaysTrue();
+
+        case FALSE:
+          return Expressions.alwaysFalse();
+
         case IS_NULL:
           IsNull isNullFilter = (IsNull) filter;
           return isNull(isNullFilter.attribute());
@@ -178,6 +203,10 @@ public class SparkFilters {
       return DateTimeUtils.fromJavaTimestamp((Timestamp) value);
     } else if (value instanceof Date) {
       return DateTimeUtils.fromJavaDate((Date) value);
+    } else if (value instanceof Instant) {
+      return DateTimeUtils.instantToMicros((Instant) value);
+    } else if (value instanceof LocalDate) {
+      return DateTimeUtils.localDateToDays((LocalDate) value);
     }
     return value;
   }
