@@ -22,10 +22,8 @@ package org.apache.spark.sql.execution.datasources
 import org.apache.iceberg.spark.SparkFilters
 import org.apache.spark.sql.AnalysisException
 import org.apache.spark.sql.SparkSession
-import org.apache.spark.sql.catalyst.expressions.Attribute
 import org.apache.spark.sql.catalyst.expressions.Expression
 import org.apache.spark.sql.catalyst.plans.logical.Filter
-import org.apache.spark.sql.catalyst.plans.logical.LeafNode
 
 object SparkExpressionConverter {
 
@@ -38,14 +36,15 @@ object SparkExpressionConverter {
 
   @throws[AnalysisException]
   def collectResolvedSparkExpression(session: SparkSession, tableName: String, where: String): Expression = {
-    val tableAttrs = session.table(tableName).queryExecution.analyzed.output
-    val unresolvedExpression = session.sessionState.sqlParser.parseExpression(where)
-    val filter = Filter(unresolvedExpression, DummyRelation(tableAttrs))
-    val optimizedLogicalPlan = session.sessionState.executePlan(filter).optimizedPlan
+    var expression: Expression = null
+    // Add a dummy prefix linking to the table to collect the resolved spark expression from optimized plan.
+    val prefix = String.format("SELECT 42 from %s where ", tableName)
+    val logicalPlan = session.sessionState.sqlParser.parsePlan(prefix + where)
+    val optimizedLogicalPlan = session.sessionState.executePlan(logicalPlan).optimizedPlan
     optimizedLogicalPlan.collectFirst {
-      case filter: Filter => filter.condition
-    }.getOrElse(throw new AnalysisException("Failed to find filter expression"))
+      case filter: Filter =>
+        expression = filter.expressions.head
+    }
+    expression
   }
-
-  case class DummyRelation(output: Seq[Attribute]) extends LeafNode
 }
