@@ -20,10 +20,6 @@ package org.apache.iceberg.spark.actions;
 
 import static org.apache.iceberg.TableProperties.COMMIT_NUM_RETRIES;
 import static org.apache.iceberg.types.Types.NestedField.optional;
-import static org.apache.iceberg.types.Types.NestedField.required;
-import static org.apache.spark.sql.functions.current_date;
-import static org.apache.spark.sql.functions.date_add;
-import static org.apache.spark.sql.functions.expr;
 import static org.assertj.core.api.Assertions.assertThat;
 import static org.mockito.ArgumentMatchers.any;
 import static org.mockito.ArgumentMatchers.argThat;
@@ -47,6 +43,7 @@ import java.util.stream.Collectors;
 import java.util.stream.IntStream;
 import java.util.stream.Stream;
 import org.apache.hadoop.conf.Configuration;
+import org.apache.iceberg.AssertHelpers;
 import org.apache.iceberg.ContentFile;
 import org.apache.iceberg.DataFile;
 import org.apache.iceberg.DeleteFile;
@@ -62,6 +59,7 @@ import org.apache.iceberg.SortOrder;
 import org.apache.iceberg.StructLike;
 import org.apache.iceberg.Table;
 import org.apache.iceberg.TableProperties;
+import org.apache.iceberg.actions.ActionsProvider;
 import org.apache.iceberg.actions.BinPackStrategy;
 import org.apache.iceberg.actions.RewriteDataFiles;
 import org.apache.iceberg.actions.RewriteDataFiles.Result;
@@ -76,7 +74,6 @@ import org.apache.iceberg.encryption.EncryptedFiles;
 import org.apache.iceberg.encryption.EncryptedOutputFile;
 import org.apache.iceberg.encryption.EncryptionKeyMetadata;
 import org.apache.iceberg.exceptions.CommitStateUnknownException;
-import org.apache.iceberg.expressions.Expression;
 import org.apache.iceberg.expressions.Expressions;
 import org.apache.iceberg.hadoop.HadoopTables;
 import org.apache.iceberg.io.CloseableIterable;
@@ -89,25 +86,20 @@ import org.apache.iceberg.relocated.com.google.common.collect.Lists;
 import org.apache.iceberg.relocated.com.google.common.collect.Maps;
 import org.apache.iceberg.relocated.com.google.common.collect.Streams;
 import org.apache.iceberg.spark.FileRewriteCoordinator;
-import org.apache.iceberg.spark.ScanTaskSetManager;
+import org.apache.iceberg.spark.FileScanTaskSetManager;
 import org.apache.iceberg.spark.SparkTableUtil;
 import org.apache.iceberg.spark.SparkTestBase;
-import org.apache.iceberg.spark.SparkWriteOptions;
-import org.apache.iceberg.spark.actions.RewriteDataFilesSparkAction.RewriteExecutionContext;
+import org.apache.iceberg.spark.actions.BaseRewriteDataFilesSparkAction.RewriteExecutionContext;
 import org.apache.iceberg.spark.source.ThreeColumnRecord;
 import org.apache.iceberg.types.Comparators;
 import org.apache.iceberg.types.Conversions;
 import org.apache.iceberg.types.Types;
 import org.apache.iceberg.types.Types.NestedField;
 import org.apache.iceberg.util.Pair;
-import org.apache.iceberg.util.StructLikeMap;
 import org.apache.spark.sql.Dataset;
 import org.apache.spark.sql.Row;
-import org.apache.spark.sql.internal.SQLConf;
-import org.assertj.core.api.Assertions;
 import org.junit.Assert;
 import org.junit.Before;
-import org.junit.BeforeClass;
 import org.junit.Rule;
 import org.junit.Test;
 import org.junit.rules.TemporaryFolder;
@@ -128,22 +120,16 @@ public class TestRewriteDataFilesAction extends SparkTestBase {
   @Rule public TemporaryFolder temp = new TemporaryFolder();
 
   private final FileRewriteCoordinator coordinator = FileRewriteCoordinator.get();
-  private final ScanTaskSetManager manager = ScanTaskSetManager.get();
+  private final FileScanTaskSetManager manager = FileScanTaskSetManager.get();
   private String tableLocation = null;
 
-  @BeforeClass
-  public static void setupSpark() {
-    // disable AQE as tests assume that writes generate a particular number of files
-    spark.conf().set(SQLConf.ADAPTIVE_EXECUTION_ENABLED().key(), "false");
-  }
-
   @Before
   public void setupTableLocation() throws Exception {
     File tableDir = temp.newFolder();
     this.tableLocation = tableDir.toURI().toString();
   }
 
-  private RewriteDataFilesSparkAction basicRewrite(Table table) {
+  private RewriteDataFiles basicRewrite(Table table) {
     // Always compact regardless of input files
     table.refresh();
     return actions().rewriteDataFiles(table).option(BinPackStrategy.MIN_INPUT_FILES, "1");
@@ -221,41 +207,6 @@ public class TestRewriteDataFilesAction extends SparkTestBase {
     assertEquals("Rows must match", expectedRecords, actualRecords);
   }
 
-  @Test
-  public void testBinPackAfterPartitionChange() {
-    Table table = createTable();
-
-    writeRecords(20, SCALE, 20);
-    shouldHaveFiles(table, 20);
-    table.updateSpec().addField(Expressions.ref("c1")).commit();
-
-    List<Object[]> originalData = currentData();
-    long dataSizeBefore = testDataSize(table);
-
-    RewriteDataFiles.Result result =
-        basicRewrite(table)
-            .option(SortStrategy.MIN_INPUT_FILES, "1")
-            .option(
-                SortStrategy.MIN_FILE_SIZE_BYTES, Integer.toString(averageFileSize(table) + 1000))
-            .option(
-                RewriteDataFiles.TARGET_FILE_SIZE_BYTES,
-                Integer.toString(averageFileSize(table) + 1001))
-            .execute();
-
-    Assert.assertEquals(
-        "Should have 1 fileGroup because all files were not correctly partitioned",
-        1,
-        result.rewriteResults().size());
-    assertThat(result.rewrittenBytesCount()).isEqualTo(dataSizeBefore);
-
-    List<Object[]> postRewriteData = currentData();
-    assertEquals("We shouldn't have changed the data", originalData, postRewriteData);
-
-    shouldHaveSnapshots(table, 2);
-    shouldHaveACleanCache(table);
-    shouldHaveFiles(table, 20);
-  }
-
   @Test
   public void testBinPackWithDeletes() throws Exception {
     Table table = createTablePartitioned(4, 2);
@@ -635,12 +586,14 @@ public class TestRewriteDataFilesAction extends SparkTestBase {
 
     List<Object[]> originalData = currentData();
 
-    RewriteDataFilesSparkAction realRewrite =
-        basicRewrite(table)
-            .option(
-                RewriteDataFiles.MAX_FILE_GROUP_SIZE_BYTES, Integer.toString(fileSize * 2 + 1000));
+    BaseRewriteDataFilesSparkAction realRewrite =
+        (org.apache.iceberg.spark.actions.BaseRewriteDataFilesSparkAction)
+            basicRewrite(table)
+                .option(
+                    RewriteDataFiles.MAX_FILE_GROUP_SIZE_BYTES,
+                    Integer.toString(fileSize * 2 + 1000));
 
-    RewriteDataFilesSparkAction spyRewrite = Mockito.spy(realRewrite);
+    BaseRewriteDataFilesSparkAction spyRewrite = Mockito.spy(realRewrite);
 
     // Fail groups 1, 3, and 7 during rewrite
     GroupInfoMatcher failGroup = new GroupInfoMatcher(1, 3, 7);
@@ -648,9 +601,10 @@ public class TestRewriteDataFilesAction extends SparkTestBase {
         .when(spyRewrite)
         .rewriteFiles(any(), argThat(failGroup));
 
-    Assertions.assertThatThrownBy(spyRewrite::execute)
-        .isInstanceOf(RuntimeException.class)
-        .hasMessage("Rewrite Failed");
+    AssertHelpers.assertThrows(
+        "Should fail entire rewrite if part fails",
+        RuntimeException.class,
+        () -> spyRewrite.execute());
 
     table.refresh();
 
@@ -669,12 +623,14 @@ public class TestRewriteDataFilesAction extends SparkTestBase {
 
     List<Object[]> originalData = currentData();
 
-    RewriteDataFilesSparkAction realRewrite =
-        basicRewrite(table)
-            .option(
-                RewriteDataFiles.MAX_FILE_GROUP_SIZE_BYTES, Integer.toString(fileSize * 2 + 1000));
+    BaseRewriteDataFilesSparkAction realRewrite =
+        (org.apache.iceberg.spark.actions.BaseRewriteDataFilesSparkAction)
+            basicRewrite(table)
+                .option(
+                    RewriteDataFiles.MAX_FILE_GROUP_SIZE_BYTES,
+                    Integer.toString(fileSize * 2 + 1000));
 
-    RewriteDataFilesSparkAction spyRewrite = spy(realRewrite);
+    BaseRewriteDataFilesSparkAction spyRewrite = spy(realRewrite);
     RewriteDataFilesCommitManager util = spy(new RewriteDataFilesCommitManager(table));
 
     // Fail to commit
@@ -682,9 +638,10 @@ public class TestRewriteDataFilesAction extends SparkTestBase {
 
     doReturn(util).when(spyRewrite).commitManager(table.currentSnapshot().snapshotId());
 
-    Assertions.assertThatThrownBy(spyRewrite::execute)
-        .isInstanceOf(RuntimeException.class)
-        .hasMessage("Commit Failure");
+    AssertHelpers.assertThrows(
+        "Should fail entire rewrite if commit fails",
+        RuntimeException.class,
+        () -> spyRewrite.execute());
 
     table.refresh();
 
@@ -703,13 +660,15 @@ public class TestRewriteDataFilesAction extends SparkTestBase {
 
     List<Object[]> originalData = currentData();
 
-    RewriteDataFilesSparkAction realRewrite =
-        basicRewrite(table)
-            .option(
-                RewriteDataFiles.MAX_FILE_GROUP_SIZE_BYTES, Integer.toString(fileSize * 2 + 1000))
-            .option(RewriteDataFiles.MAX_CONCURRENT_FILE_GROUP_REWRITES, "3");
+    BaseRewriteDataFilesSparkAction realRewrite =
+        (org.apache.iceberg.spark.actions.BaseRewriteDataFilesSparkAction)
+            basicRewrite(table)
+                .option(
+                    RewriteDataFiles.MAX_FILE_GROUP_SIZE_BYTES,
+                    Integer.toString(fileSize * 2 + 1000))
+                .option(RewriteDataFiles.MAX_CONCURRENT_FILE_GROUP_REWRITES, "3");
 
-    RewriteDataFilesSparkAction spyRewrite = Mockito.spy(realRewrite);
+    BaseRewriteDataFilesSparkAction spyRewrite = Mockito.spy(realRewrite);
 
     // Fail groups 1, 3, and 7 during rewrite
     GroupInfoMatcher failGroup = new GroupInfoMatcher(1, 3, 7);
@@ -717,9 +676,10 @@ public class TestRewriteDataFilesAction extends SparkTestBase {
         .when(spyRewrite)
         .rewriteFiles(any(), argThat(failGroup));
 
-    Assertions.assertThatThrownBy(spyRewrite::execute)
-        .isInstanceOf(RuntimeException.class)
-        .hasMessage("Rewrite Failed");
+    AssertHelpers.assertThrows(
+        "Should fail entire rewrite if part fails",
+        RuntimeException.class,
+        () -> spyRewrite.execute());
 
     table.refresh();
 
@@ -739,14 +699,16 @@ public class TestRewriteDataFilesAction extends SparkTestBase {
     List<Object[]> originalData = currentData();
     long dataSizeBefore = testDataSize(table);
 
-    RewriteDataFilesSparkAction realRewrite =
-        basicRewrite(table)
-            .option(
-                RewriteDataFiles.MAX_FILE_GROUP_SIZE_BYTES, Integer.toString(fileSize * 2 + 1000))
-            .option(RewriteDataFiles.PARTIAL_PROGRESS_ENABLED, "true")
-            .option(RewriteDataFiles.PARTIAL_PROGRESS_MAX_COMMITS, "3");
+    BaseRewriteDataFilesSparkAction realRewrite =
+        (org.apache.iceberg.spark.actions.BaseRewriteDataFilesSparkAction)
+            basicRewrite(table)
+                .option(
+                    RewriteDataFiles.MAX_FILE_GROUP_SIZE_BYTES,
+                    Integer.toString(fileSize * 2 + 1000))
+                .option(RewriteDataFiles.PARTIAL_PROGRESS_ENABLED, "true")
+                .option(RewriteDataFiles.PARTIAL_PROGRESS_MAX_COMMITS, "3");
 
-    RewriteDataFilesSparkAction spyRewrite = Mockito.spy(realRewrite);
+    BaseRewriteDataFilesSparkAction spyRewrite = Mockito.spy(realRewrite);
 
     // Fail groups 1, 3, and 7 during rewrite
     GroupInfoMatcher failGroup = new GroupInfoMatcher(1, 3, 7);
@@ -756,9 +718,7 @@ public class TestRewriteDataFilesAction extends SparkTestBase {
 
     RewriteDataFiles.Result result = spyRewrite.execute();
 
-    assertThat(result.rewriteResults()).hasSize(7);
-    assertThat(result.rewriteFailures()).hasSize(3);
-    assertThat(result.failedDataFilesCount()).isEqualTo(6);
+    Assert.assertEquals("Should have 7 fileGroups", result.rewriteResults().size(), 7);
     assertThat(result.rewrittenBytesCount()).isGreaterThan(0L).isLessThan(dataSizeBefore);
 
     table.refresh();
@@ -781,15 +741,17 @@ public class TestRewriteDataFilesAction extends SparkTestBase {
     List<Object[]> originalData = currentData();
     long dataSizeBefore = testDataSize(table);
 
-    RewriteDataFilesSparkAction realRewrite =
-        basicRewrite(table)
-            .option(
-                RewriteDataFiles.MAX_FILE_GROUP_SIZE_BYTES, Integer.toString(fileSize * 2 + 1000))
-            .option(RewriteDataFiles.MAX_CONCURRENT_FILE_GROUP_REWRITES, "3")
-            .option(RewriteDataFiles.PARTIAL_PROGRESS_ENABLED, "true")
-            .option(RewriteDataFiles.PARTIAL_PROGRESS_MAX_COMMITS, "3");
+    BaseRewriteDataFilesSparkAction realRewrite =
+        (org.apache.iceberg.spark.actions.BaseRewriteDataFilesSparkAction)
+            basicRewrite(table)
+                .option(
+                    RewriteDataFiles.MAX_FILE_GROUP_SIZE_BYTES,
+                    Integer.toString(fileSize * 2 + 1000))
+                .option(RewriteDataFiles.MAX_CONCURRENT_FILE_GROUP_REWRITES, "3")
+                .option(RewriteDataFiles.PARTIAL_PROGRESS_ENABLED, "true")
+                .option(RewriteDataFiles.PARTIAL_PROGRESS_MAX_COMMITS, "3");
 
-    RewriteDataFilesSparkAction spyRewrite = Mockito.spy(realRewrite);
+    BaseRewriteDataFilesSparkAction spyRewrite = Mockito.spy(realRewrite);
 
     // Fail groups 1, 3, and 7 during rewrite
     GroupInfoMatcher failGroup = new GroupInfoMatcher(1, 3, 7);
@@ -799,9 +761,7 @@ public class TestRewriteDataFilesAction extends SparkTestBase {
 
     RewriteDataFiles.Result result = spyRewrite.execute();
 
-    assertThat(result.rewriteResults()).hasSize(7);
-    assertThat(result.rewriteFailures()).hasSize(3);
-    assertThat(result.failedDataFilesCount()).isEqualTo(6);
+    Assert.assertEquals("Should have 7 fileGroups", result.rewriteResults().size(), 7);
     assertThat(result.rewrittenBytesCount()).isGreaterThan(0L).isLessThan(dataSizeBefore);
 
     table.refresh();
@@ -824,15 +784,17 @@ public class TestRewriteDataFilesAction extends SparkTestBase {
     List<Object[]> originalData = currentData();
     long dataSizeBefore = testDataSize(table);
 
-    RewriteDataFilesSparkAction realRewrite =
-        basicRewrite(table)
-            .option(
-                RewriteDataFiles.MAX_FILE_GROUP_SIZE_BYTES, Integer.toString(fileSize * 2 + 1000))
-            .option(RewriteDataFiles.MAX_CONCURRENT_FILE_GROUP_REWRITES, "3")
-            .option(RewriteDataFiles.PARTIAL_PROGRESS_ENABLED, "true")
-            .option(RewriteDataFiles.PARTIAL_PROGRESS_MAX_COMMITS, "3");
+    BaseRewriteDataFilesSparkAction realRewrite =
+        (org.apache.iceberg.spark.actions.BaseRewriteDataFilesSparkAction)
+            basicRewrite(table)
+                .option(
+                    RewriteDataFiles.MAX_FILE_GROUP_SIZE_BYTES,
+                    Integer.toString(fileSize * 2 + 1000))
+                .option(RewriteDataFiles.MAX_CONCURRENT_FILE_GROUP_REWRITES, "3")
+                .option(RewriteDataFiles.PARTIAL_PROGRESS_ENABLED, "true")
+                .option(RewriteDataFiles.PARTIAL_PROGRESS_MAX_COMMITS, "3");
 
-    RewriteDataFilesSparkAction spyRewrite = spy(realRewrite);
+    BaseRewriteDataFilesSparkAction spyRewrite = spy(realRewrite);
     RewriteDataFilesCommitManager util = spy(new RewriteDataFilesCommitManager(table));
 
     // First and Third commits work, second does not
@@ -865,35 +827,32 @@ public class TestRewriteDataFilesAction extends SparkTestBase {
   public void testInvalidOptions() {
     Table table = createTable(20);
 
-    Assertions.assertThatThrownBy(
-            () ->
-                basicRewrite(table)
-                    .option(RewriteDataFiles.PARTIAL_PROGRESS_ENABLED, "true")
-                    .option(RewriteDataFiles.PARTIAL_PROGRESS_MAX_COMMITS, "-5")
-                    .execute())
-        .isInstanceOf(IllegalArgumentException.class)
-        .hasMessage(
-            "Cannot set partial-progress.max-commits to -5, "
-                + "the value must be positive when partial-progress.enabled is true");
+    AssertHelpers.assertThrows(
+        "No negative values for partial progress max commits",
+        IllegalArgumentException.class,
+        () ->
+            basicRewrite(table)
+                .option(RewriteDataFiles.PARTIAL_PROGRESS_ENABLED, "true")
+                .option(RewriteDataFiles.PARTIAL_PROGRESS_MAX_COMMITS, "-5")
+                .execute());
 
-    Assertions.assertThatThrownBy(
-            () ->
-                basicRewrite(table)
-                    .option(RewriteDataFiles.MAX_CONCURRENT_FILE_GROUP_REWRITES, "-5")
-                    .execute())
-        .isInstanceOf(IllegalArgumentException.class)
-        .hasMessage(
-            "Cannot set max-concurrent-file-group-rewrites to -5, the value must be positive.");
+    AssertHelpers.assertThrows(
+        "No negative values for max concurrent groups",
+        IllegalArgumentException.class,
+        () ->
+            basicRewrite(table)
+                .option(RewriteDataFiles.MAX_CONCURRENT_FILE_GROUP_REWRITES, "-5")
+                .execute());
 
-    Assertions.assertThatThrownBy(() -> basicRewrite(table).option("foobarity", "-5").execute())
-        .isInstanceOf(IllegalArgumentException.class)
-        .hasMessage(
-            "Cannot use options [foobarity], they are not supported by the action or the rewriter BIN-PACK");
+    AssertHelpers.assertThrows(
+        "No unknown options allowed",
+        IllegalArgumentException.class,
+        () -> basicRewrite(table).option("foobarity", "-5").execute());
 
-    Assertions.assertThatThrownBy(
-            () -> basicRewrite(table).option(RewriteDataFiles.REWRITE_JOB_ORDER, "foo").execute())
-        .isInstanceOf(IllegalArgumentException.class)
-        .hasMessage("Invalid rewrite job order name: foo");
+    AssertHelpers.assertThrows(
+        "Cannot set rewrite-job-order to foo",
+        IllegalArgumentException.class,
+        () -> basicRewrite(table).option(RewriteDataFiles.REWRITE_JOB_ORDER, "foo").execute());
   }
 
   @Test
@@ -1115,8 +1074,8 @@ public class TestRewriteDataFilesAction extends SparkTestBase {
 
     List<Object[]> originalData = currentData();
 
-    RewriteDataFilesSparkAction action = basicRewrite(table);
-    RewriteDataFilesSparkAction spyAction = spy(action);
+    BaseRewriteDataFilesSparkAction action = (BaseRewriteDataFilesSparkAction) basicRewrite(table);
+    BaseRewriteDataFilesSparkAction spyAction = spy(action);
     RewriteDataFilesCommitManager util = spy(new RewriteDataFilesCommitManager(table));
 
     doAnswer(
@@ -1129,10 +1088,10 @@ public class TestRewriteDataFilesAction extends SparkTestBase {
 
     doReturn(util).when(spyAction).commitManager(table.currentSnapshot().snapshotId());
 
-    Assertions.assertThatThrownBy(spyAction::execute)
-        .isInstanceOf(CommitStateUnknownException.class)
-        .hasMessageStartingWith(
-            "Unknown State\n" + "Cannot determine whether the commit was successful or not");
+    AssertHelpers.assertThrows(
+        "Should propagate CommitStateUnknown Exception",
+        CommitStateUnknownException.class,
+        () -> spyAction.execute());
 
     List<Object[]> postRewriteData = currentData();
     assertEquals("We shouldn't have changed the data", originalData, postRewriteData);
@@ -1140,125 +1099,27 @@ public class TestRewriteDataFilesAction extends SparkTestBase {
     shouldHaveSnapshots(table, 2); // Commit actually Succeeded
   }
 
-  @Test
-  public void testZOrderSort() {
-    int originalFiles = 20;
-    Table table = createTable(originalFiles);
-    shouldHaveLastCommitUnsorted(table, "c2");
-    shouldHaveFiles(table, originalFiles);
-
-    List<Object[]> originalData = currentData();
-    double originalFilesC2 = percentFilesRequired(table, "c2", "foo23");
-    double originalFilesC3 = percentFilesRequired(table, "c3", "bar21");
-    double originalFilesC2C3 =
-        percentFilesRequired(table, new String[] {"c2", "c3"}, new String[] {"foo23", "bar23"});
-
-    Assert.assertTrue("Should require all files to scan c2", originalFilesC2 > 0.99);
-    Assert.assertTrue("Should require all files to scan c3", originalFilesC3 > 0.99);
-
-    long dataSizeBefore = testDataSize(table);
-    RewriteDataFiles.Result result =
-        basicRewrite(table)
-            .zOrder("c2", "c3")
-            .option(
-                SortStrategy.MAX_FILE_SIZE_BYTES,
-                Integer.toString((averageFileSize(table) / 2) + 2))
-            // Divide files in 2
-            .option(
-                RewriteDataFiles.TARGET_FILE_SIZE_BYTES,
-                Integer.toString(averageFileSize(table) / 2))
-            .option(SortStrategy.MIN_INPUT_FILES, "1")
-            .execute();
-
-    Assert.assertEquals("Should have 1 fileGroups", 1, result.rewriteResults().size());
-    assertThat(result.rewrittenBytesCount()).isEqualTo(dataSizeBefore);
-    int zOrderedFilesTotal = Iterables.size(table.currentSnapshot().addedDataFiles(table.io()));
-    Assert.assertTrue("Should have written 40+ files", zOrderedFilesTotal >= 40);
-
-    table.refresh();
-
-    List<Object[]> postRewriteData = currentData();
-    assertEquals("We shouldn't have changed the data", originalData, postRewriteData);
-
-    shouldHaveSnapshots(table, 2);
-    shouldHaveACleanCache(table);
-
-    double filesScannedC2 = percentFilesRequired(table, "c2", "foo23");
-    double filesScannedC3 = percentFilesRequired(table, "c3", "bar21");
-    double filesScannedC2C3 =
-        percentFilesRequired(table, new String[] {"c2", "c3"}, new String[] {"foo23", "bar23"});
-
-    Assert.assertTrue(
-        "Should have reduced the number of files required for c2",
-        filesScannedC2 < originalFilesC2);
-    Assert.assertTrue(
-        "Should have reduced the number of files required for c3",
-        filesScannedC3 < originalFilesC3);
-    Assert.assertTrue(
-        "Should have reduced the number of files required for a c2,c3 predicate",
-        filesScannedC2C3 < originalFilesC2C3);
-  }
-
-  @Test
-  public void testZOrderAllTypesSort() {
-    Table table = createTypeTestTable();
-    shouldHaveFiles(table, 10);
-
-    List<Row> originalRaw =
-        spark.read().format("iceberg").load(tableLocation).sort("longCol").collectAsList();
-    List<Object[]> originalData = rowsToJava(originalRaw);
-    long dataSizeBefore = testDataSize(table);
-
-    // TODO add in UUID when it is supported in Spark
-    RewriteDataFiles.Result result =
-        basicRewrite(table)
-            .zOrder(
-                "longCol",
-                "intCol",
-                "floatCol",
-                "doubleCol",
-                "dateCol",
-                "timestampCol",
-                "stringCol",
-                "binaryCol",
-                "booleanCol")
-            .option(SortStrategy.MIN_INPUT_FILES, "1")
-            .option(SortStrategy.REWRITE_ALL, "true")
-            .execute();
-
-    Assert.assertEquals("Should have 1 fileGroups", 1, result.rewriteResults().size());
-    assertThat(result.rewrittenBytesCount()).isEqualTo(dataSizeBefore);
-    int zOrderedFilesTotal = Iterables.size(table.currentSnapshot().addedDataFiles(table.io()));
-    Assert.assertEquals("Should have written 1 file", 1, zOrderedFilesTotal);
-
-    table.refresh();
-
-    List<Row> postRaw =
-        spark.read().format("iceberg").load(tableLocation).sort("longCol").collectAsList();
-    List<Object[]> postRewriteData = rowsToJava(postRaw);
-    assertEquals("We shouldn't have changed the data", originalData, postRewriteData);
-
-    shouldHaveSnapshots(table, 2);
-    shouldHaveACleanCache(table);
-  }
-
   @Test
   public void testInvalidAPIUsage() {
     Table table = createTable(1);
 
-    SortOrder sortOrder = SortOrder.builderFor(table.schema()).asc("c2").build();
+    AssertHelpers.assertThrows(
+        "Should be unable to set Strategy more than once",
+        IllegalArgumentException.class,
+        "Cannot set strategy",
+        () -> actions().rewriteDataFiles(table).binPack().sort());
 
-    Assertions.assertThatThrownBy(() -> actions().rewriteDataFiles(table).binPack().sort())
-        .isInstanceOf(IllegalArgumentException.class)
-        .hasMessage("Must use only one rewriter type (bin-pack, sort, zorder)");
+    AssertHelpers.assertThrows(
+        "Should be unable to set Strategy more than once",
+        IllegalArgumentException.class,
+        "Cannot set strategy",
+        () -> actions().rewriteDataFiles(table).sort().binPack());
 
-    Assertions.assertThatThrownBy(() -> actions().rewriteDataFiles(table).sort(sortOrder).binPack())
-        .isInstanceOf(IllegalArgumentException.class)
-        .hasMessage("Must use only one rewriter type (bin-pack, sort, zorder)");
-
-    Assertions.assertThatThrownBy(() -> actions().rewriteDataFiles(table).sort(sortOrder).binPack())
-        .isInstanceOf(IllegalArgumentException.class)
-        .hasMessage("Must use only one rewriter type (bin-pack, sort, zorder)");
+    AssertHelpers.assertThrows(
+        "Should be unable to set Strategy more than once",
+        IllegalArgumentException.class,
+        "Cannot set strategy",
+        () -> actions().rewriteDataFiles(table).sort(SortOrder.unsorted()).binPack());
   }
 
   @Test
@@ -1270,17 +1131,19 @@ public class TestRewriteDataFilesAction extends SparkTestBase {
     writeRecords(4, SCALE, 4);
     table.updateProperties().set(TableProperties.FORMAT_VERSION, "2").commit();
 
-    RewriteDataFilesSparkAction basicRewrite = basicRewrite(table).binPack();
+    BaseRewriteDataFilesSparkAction basicRewrite =
+        (BaseRewriteDataFilesSparkAction) basicRewrite(table).binPack();
     List<Long> expected =
         toGroupStream(table, basicRewrite)
             .mapToLong(RewriteFileGroup::sizeInBytes)
             .boxed()
             .collect(Collectors.toList());
 
-    RewriteDataFilesSparkAction jobOrderRewrite =
-        basicRewrite(table)
-            .option(RewriteDataFiles.REWRITE_JOB_ORDER, RewriteJobOrder.BYTES_ASC.orderName())
-            .binPack();
+    BaseRewriteDataFilesSparkAction jobOrderRewrite =
+        (BaseRewriteDataFilesSparkAction)
+            basicRewrite(table)
+                .option(RewriteDataFiles.REWRITE_JOB_ORDER, RewriteJobOrder.BYTES_ASC.orderName())
+                .binPack();
     List<Long> actual =
         toGroupStream(table, jobOrderRewrite)
             .mapToLong(RewriteFileGroup::sizeInBytes)
@@ -1302,17 +1165,19 @@ public class TestRewriteDataFilesAction extends SparkTestBase {
     writeRecords(4, SCALE, 4);
     table.updateProperties().set(TableProperties.FORMAT_VERSION, "2").commit();
 
-    RewriteDataFilesSparkAction basicRewrite = basicRewrite(table).binPack();
+    BaseRewriteDataFilesSparkAction basicRewrite =
+        (BaseRewriteDataFilesSparkAction) basicRewrite(table).binPack();
     List<Long> expected =
         toGroupStream(table, basicRewrite)
             .mapToLong(RewriteFileGroup::sizeInBytes)
             .boxed()
             .collect(Collectors.toList());
 
-    RewriteDataFilesSparkAction jobOrderRewrite =
-        basicRewrite(table)
-            .option(RewriteDataFiles.REWRITE_JOB_ORDER, RewriteJobOrder.BYTES_DESC.orderName())
-            .binPack();
+    BaseRewriteDataFilesSparkAction jobOrderRewrite =
+        (BaseRewriteDataFilesSparkAction)
+            basicRewrite(table)
+                .option(RewriteDataFiles.REWRITE_JOB_ORDER, RewriteJobOrder.BYTES_DESC.orderName())
+                .binPack();
     List<Long> actual =
         toGroupStream(table, jobOrderRewrite)
             .mapToLong(RewriteFileGroup::sizeInBytes)
@@ -1334,17 +1199,19 @@ public class TestRewriteDataFilesAction extends SparkTestBase {
     writeRecords(4, SCALE, 4);
     table.updateProperties().set(TableProperties.FORMAT_VERSION, "2").commit();
 
-    RewriteDataFilesSparkAction basicRewrite = basicRewrite(table).binPack();
+    BaseRewriteDataFilesSparkAction basicRewrite =
+        (BaseRewriteDataFilesSparkAction) basicRewrite(table).binPack();
     List<Long> expected =
         toGroupStream(table, basicRewrite)
             .mapToLong(RewriteFileGroup::numFiles)
             .boxed()
             .collect(Collectors.toList());
 
-    RewriteDataFilesSparkAction jobOrderRewrite =
-        basicRewrite(table)
-            .option(RewriteDataFiles.REWRITE_JOB_ORDER, RewriteJobOrder.FILES_ASC.orderName())
-            .binPack();
+    BaseRewriteDataFilesSparkAction jobOrderRewrite =
+        (BaseRewriteDataFilesSparkAction)
+            basicRewrite(table)
+                .option(RewriteDataFiles.REWRITE_JOB_ORDER, RewriteJobOrder.FILES_ASC.orderName())
+                .binPack();
     List<Long> actual =
         toGroupStream(table, jobOrderRewrite)
             .mapToLong(RewriteFileGroup::numFiles)
@@ -1366,17 +1233,19 @@ public class TestRewriteDataFilesAction extends SparkTestBase {
     writeRecords(4, SCALE, 4);
     table.updateProperties().set(TableProperties.FORMAT_VERSION, "2").commit();
 
-    RewriteDataFilesSparkAction basicRewrite = basicRewrite(table).binPack();
+    BaseRewriteDataFilesSparkAction basicRewrite =
+        (BaseRewriteDataFilesSparkAction) basicRewrite(table).binPack();
     List<Long> expected =
         toGroupStream(table, basicRewrite)
             .mapToLong(RewriteFileGroup::numFiles)
             .boxed()
             .collect(Collectors.toList());
 
-    RewriteDataFilesSparkAction jobOrderRewrite =
-        basicRewrite(table)
-            .option(RewriteDataFiles.REWRITE_JOB_ORDER, RewriteJobOrder.FILES_DESC.orderName())
-            .binPack();
+    BaseRewriteDataFilesSparkAction jobOrderRewrite =
+        (BaseRewriteDataFilesSparkAction)
+            basicRewrite(table)
+                .option(RewriteDataFiles.REWRITE_JOB_ORDER, RewriteJobOrder.FILES_DESC.orderName())
+                .binPack();
     List<Long> actual =
         toGroupStream(table, jobOrderRewrite)
             .mapToLong(RewriteFileGroup::numFiles)
@@ -1389,9 +1258,10 @@ public class TestRewriteDataFilesAction extends SparkTestBase {
     Assert.assertNotEquals("Number of files order should not be ascending", actual, expected);
   }
 
-  private Stream<RewriteFileGroup> toGroupStream(Table table, RewriteDataFilesSparkAction rewrite) {
+  private Stream<RewriteFileGroup> toGroupStream(
+      Table table, BaseRewriteDataFilesSparkAction rewrite) {
     rewrite.validateAndInitOptions();
-    StructLikeMap<List<List<FileScanTask>>> fileGroupsByPartition =
+    Map<StructLike, List<List<FileScanTask>>> fileGroupsByPartition =
         rewrite.planFileGroups(table.currentSnapshot().snapshotId());
 
     return rewrite.toGroupStream(
@@ -1560,41 +1430,6 @@ public class TestRewriteDataFilesAction extends SparkTestBase {
     return createTablePartitioned(partitions, files, SCALE, Maps.newHashMap());
   }
 
-  private Table createTypeTestTable() {
-    Schema schema =
-        new Schema(
-            required(1, "longCol", Types.LongType.get()),
-            required(2, "intCol", Types.IntegerType.get()),
-            required(3, "floatCol", Types.FloatType.get()),
-            optional(4, "doubleCol", Types.DoubleType.get()),
-            optional(5, "dateCol", Types.DateType.get()),
-            optional(6, "timestampCol", Types.TimestampType.withZone()),
-            optional(7, "stringCol", Types.StringType.get()),
-            optional(8, "booleanCol", Types.BooleanType.get()),
-            optional(9, "binaryCol", Types.BinaryType.get()));
-
-    Map<String, String> options = Maps.newHashMap();
-    Table table = TABLES.create(schema, PartitionSpec.unpartitioned(), options, tableLocation);
-
-    spark
-        .range(0, 10, 1, 10)
-        .withColumnRenamed("id", "longCol")
-        .withColumn("intCol", expr("CAST(longCol AS INT)"))
-        .withColumn("floatCol", expr("CAST(longCol AS FLOAT)"))
-        .withColumn("doubleCol", expr("CAST(longCol AS DOUBLE)"))
-        .withColumn("dateCol", date_add(current_date(), 1))
-        .withColumn("timestampCol", expr("TO_TIMESTAMP(dateCol)"))
-        .withColumn("stringCol", expr("CAST(dateCol AS STRING)"))
-        .withColumn("booleanCol", expr("longCol > 5"))
-        .withColumn("binaryCol", expr("CAST(longCol AS BINARY)"))
-        .write()
-        .format("iceberg")
-        .mode("append")
-        .save(tableLocation);
-
-    return table;
-  }
-
   protected int averageFileSize(Table table) {
     table.refresh();
     return (int)
@@ -1638,7 +1473,6 @@ public class TestRewriteDataFilesAction extends SparkTestBase {
         .write()
         .format("iceberg")
         .mode("append")
-        .option(SparkWriteOptions.USE_TABLE_DISTRIBUTION_AND_ORDERING, "false")
         .save(tableLocation);
   }
 
@@ -1683,32 +1517,17 @@ public class TestRewriteDataFilesAction extends SparkTestBase {
     return results;
   }
 
-  private SparkActions actions() {
+  private ActionsProvider actions() {
     return SparkActions.get();
   }
 
   private Set<String> cacheContents(Table table) {
     return ImmutableSet.<String>builder()
-        .addAll(manager.fetchSetIds(table))
-        .addAll(coordinator.fetchSetIds(table))
+        .addAll(manager.fetchSetIDs(table))
+        .addAll(coordinator.fetchSetIDs(table))
         .build();
   }
 
-  private double percentFilesRequired(Table table, String col, String value) {
-    return percentFilesRequired(table, new String[] {col}, new String[] {value});
-  }
-
-  private double percentFilesRequired(Table table, String[] cols, String[] values) {
-    Preconditions.checkArgument(cols.length == values.length);
-    Expression restriction = Expressions.alwaysTrue();
-    for (int i = 0; i < cols.length; i++) {
-      restriction = Expressions.and(restriction, Expressions.equal(cols[i], values[i]));
-    }
-    int totalFiles = Iterables.size(table.newScan().planFiles());
-    int filteredFiles = Iterables.size(table.newScan().filter(restriction).planFiles());
-    return (double) filteredFiles / (double) totalFiles;
-  }
-
   class GroupInfoMatcher implements ArgumentMatcher<RewriteFileGroup> {
     private final Set<Integer> groupIDs;
 
