@@ -182,37 +182,30 @@ public class TestParquetVectorizedReads extends AvroDataTest {
     }
   }
 
-  @Override
   @Test
   @Ignore
   public void testArray() {}
 
-  @Override
   @Test
   @Ignore
   public void testArrayOfStructs() {}
 
-  @Override
   @Test
   @Ignore
   public void testMap() {}
 
-  @Override
   @Test
   @Ignore
   public void testNumericMapKey() {}
 
-  @Override
   @Test
   @Ignore
   public void testComplexMapKey() {}
 
-  @Override
   @Test
   @Ignore
   public void testMapOfStructs() {}
 
-  @Override
   @Test
   @Ignore
   public void testMixedTypes() {}
@@ -319,14 +312,11 @@ public class TestParquetVectorizedReads extends AvroDataTest {
 
   @Test
   public void testSupportedReadsForParquetV2() throws Exception {
-    // Float and double column types are written using plain encoding with Parquet V2,
-    // also Parquet V2 will dictionary encode decimals that use fixed length binary
-    // (i.e. decimals > 8 bytes)
+    // Only float and double column types are written using plain encoding with Parquet V2
     Schema schema =
         new Schema(
             optional(102, "float_data", Types.FloatType.get()),
-            optional(103, "double_data", Types.DoubleType.get()),
-            optional(104, "decimal_data", Types.DecimalType.of(25, 5)));
+            optional(103, "double_data", Types.DoubleType.get()));
 
     File dataFile = temp.newFile();
     Assert.assertTrue("Delete should succeed", dataFile.delete());
