@@ -29,6 +29,7 @@ import java.sql.Timestamp;
 import java.time.OffsetDateTime;
 import java.util.List;
 import java.util.UUID;
+import java.util.stream.Collectors;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.iceberg.DataFile;
 import org.apache.iceberg.DataFiles;
@@ -39,11 +40,11 @@ import org.apache.iceberg.Table;
 import org.apache.iceberg.data.GenericAppenderFactory;
 import org.apache.iceberg.data.GenericRecord;
 import org.apache.iceberg.data.Record;
-import org.apache.iceberg.expressions.Literal;
 import org.apache.iceberg.hadoop.HadoopTables;
 import org.apache.iceberg.io.FileAppender;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableMap;
 import org.apache.iceberg.relocated.com.google.common.collect.Lists;
+import org.apache.iceberg.relocated.com.google.common.collect.Sets;
 import org.apache.iceberg.spark.SparkReadOptions;
 import org.apache.iceberg.spark.data.GenericsHelpers;
 import org.apache.iceberg.transforms.Transform;
@@ -54,22 +55,22 @@ import org.apache.spark.sql.Encoders;
 import org.apache.spark.sql.Row;
 import org.apache.spark.sql.SparkSession;
 import org.apache.spark.sql.api.java.UDF1;
-import org.apache.spark.sql.catalyst.InternalRow;
 import org.apache.spark.sql.catalyst.expressions.UnsafeRow;
+import org.apache.spark.sql.connector.read.Batch;
+import org.apache.spark.sql.connector.read.InputPartition;
+import org.apache.spark.sql.connector.read.ScanBuilder;
+import org.apache.spark.sql.connector.read.SupportsPushDownFilters;
 import org.apache.spark.sql.sources.And;
 import org.apache.spark.sql.sources.EqualTo;
 import org.apache.spark.sql.sources.Filter;
 import org.apache.spark.sql.sources.GreaterThan;
-import org.apache.spark.sql.sources.In;
 import org.apache.spark.sql.sources.LessThan;
+import org.apache.spark.sql.sources.Not;
 import org.apache.spark.sql.sources.StringStartsWith;
-import org.apache.spark.sql.sources.v2.DataSourceOptions;
-import org.apache.spark.sql.sources.v2.reader.DataSourceReader;
-import org.apache.spark.sql.sources.v2.reader.InputPartition;
-import org.apache.spark.sql.sources.v2.reader.SupportsPushDownFilters;
 import org.apache.spark.sql.types.IntegerType$;
 import org.apache.spark.sql.types.LongType$;
 import org.apache.spark.sql.types.StringType$;
+import org.apache.spark.sql.util.CaseInsensitiveStringMap;
 import org.assertj.core.api.Assertions;
 import org.junit.AfterClass;
 import org.junit.Assert;
@@ -183,7 +184,6 @@ public class TestFilteredScan {
 
     File testFile = new File(dataFolder, fileFormat.addExtension(UUID.randomUUID().toString()));
 
-    // create records using the table's schema
     this.records = testRecords(tableSchema);
 
     try (FileAppender<Record> writer =
@@ -203,18 +203,17 @@ public class TestFilteredScan {
 
   @Test
   public void testUnpartitionedIDFilters() {
-    DataSourceOptions options =
-        new DataSourceOptions(ImmutableMap.of("path", unpartitioned.toString()));
-
-    IcebergSource source = new IcebergSource();
+    CaseInsensitiveStringMap options =
+        new CaseInsensitiveStringMap(ImmutableMap.of("path", unpartitioned.toString()));
+    SparkScanBuilder builder =
+        new SparkScanBuilder(spark, TABLES.load(options.get("path")), options);
 
     for (int i = 0; i < 10; i += 1) {
-      DataSourceReader reader = source.createReader(options);
+      pushFilters(builder, EqualTo.apply("id", i));
+      Batch scan = builder.build().toBatch();
 
-      pushFilters(reader, EqualTo.apply("id", i));
-
-      List<InputPartition<InternalRow>> tasks = reader.planInputPartitions();
-      Assert.assertEquals("Should only create one task for a small file", 1, tasks.size());
+      InputPartition[] partitions = scan.planInputPartitions();
+      Assert.assertEquals("Should only create one task for a small file", 1, partitions.length);
 
       // validate row filtering
       assertEqualsSafe(
@@ -224,25 +223,27 @@ public class TestFilteredScan {
 
   @Test
   public void testUnpartitionedCaseInsensitiveIDFilters() {
-    DataSourceOptions options =
-        new DataSourceOptions(ImmutableMap.of("path", unpartitioned.toString()));
+    CaseInsensitiveStringMap options =
+        new CaseInsensitiveStringMap(ImmutableMap.of("path", unpartitioned.toString()));
 
     // set spark.sql.caseSensitive to false
     String caseSensitivityBeforeTest = TestFilteredScan.spark.conf().get("spark.sql.caseSensitive");
     TestFilteredScan.spark.conf().set("spark.sql.caseSensitive", "false");
 
     try {
-      IcebergSource source = new IcebergSource();
 
       for (int i = 0; i < 10; i += 1) {
-        DataSourceReader reader = source.createReader(options);
+        SparkScanBuilder builder =
+            new SparkScanBuilder(spark, TABLES.load(options.get("path")), options)
+                .caseSensitive(false);
 
         pushFilters(
-            reader,
+            builder,
             EqualTo.apply("ID", i)); // note lower(ID) == lower(id), so there must be a match
+        Batch scan = builder.build().toBatch();
 
-        List<InputPartition<InternalRow>> tasks = reader.planInputPartitions();
-        Assert.assertEquals("Should only create one task for a small file", 1, tasks.size());
+        InputPartition[] tasks = scan.planInputPartitions();
+        Assert.assertEquals("Should only create one task for a small file", 1, tasks.length);
 
         // validate row filtering
         assertEqualsSafe(
@@ -258,17 +259,17 @@ public class TestFilteredScan {
 
   @Test
   public void testUnpartitionedTimestampFilter() {
-    DataSourceOptions options =
-        new DataSourceOptions(ImmutableMap.of("path", unpartitioned.toString()));
+    CaseInsensitiveStringMap options =
+        new CaseInsensitiveStringMap(ImmutableMap.of("path", unpartitioned.toString()));
 
-    IcebergSource source = new IcebergSource();
+    SparkScanBuilder builder =
+        new SparkScanBuilder(spark, TABLES.load(options.get("path")), options);
 
-    DataSourceReader reader = source.createReader(options);
+    pushFilters(builder, LessThan.apply("ts", "2017-12-22T00:00:00+00:00"));
+    Batch scan = builder.build().toBatch();
 
-    pushFilters(reader, LessThan.apply("ts", "2017-12-22T00:00:00+00:00"));
-
-    List<InputPartition<InternalRow>> tasks = reader.planInputPartitions();
-    Assert.assertEquals("Should only create one task for a small file", 1, tasks.size());
+    InputPartition[] tasks = scan.planInputPartitions();
+    Assert.assertEquals("Should only create one task for a small file", 1, tasks.length);
 
     assertEqualsSafe(
         SCHEMA.asStruct(),
@@ -281,77 +282,81 @@ public class TestFilteredScan {
 
   @Test
   public void testBucketPartitionedIDFilters() {
-    File location = buildPartitionedTable("bucketed_by_id", BUCKET_BY_ID, "bucket4", "id");
+    Table table = buildPartitionedTable("bucketed_by_id", BUCKET_BY_ID, "bucket4", "id");
+    CaseInsensitiveStringMap options =
+        new CaseInsensitiveStringMap(ImmutableMap.of("path", table.location()));
 
-    DataSourceOptions options = new DataSourceOptions(ImmutableMap.of("path", location.toString()));
-
-    IcebergSource source = new IcebergSource();
-    DataSourceReader unfiltered = source.createReader(options);
+    Batch unfiltered =
+        new SparkScanBuilder(spark, TABLES.load(options.get("path")), options).build().toBatch();
     Assert.assertEquals(
-        "Unfiltered table should created 4 read tasks", 4, unfiltered.planInputPartitions().size());
+        "Unfiltered table should created 4 read tasks", 4, unfiltered.planInputPartitions().length);
 
     for (int i = 0; i < 10; i += 1) {
-      DataSourceReader reader = source.createReader(options);
+      SparkScanBuilder builder =
+          new SparkScanBuilder(spark, TABLES.load(options.get("path")), options);
 
-      pushFilters(reader, EqualTo.apply("id", i));
+      pushFilters(builder, EqualTo.apply("id", i));
+      Batch scan = builder.build().toBatch();
 
-      List<InputPartition<InternalRow>> tasks = reader.planInputPartitions();
+      InputPartition[] tasks = scan.planInputPartitions();
 
       // validate predicate push-down
-      Assert.assertEquals("Should create one task for a single bucket", 1, tasks.size());
+      Assert.assertEquals("Should create one task for a single bucket", 1, tasks.length);
 
       // validate row filtering
       assertEqualsSafe(
-          SCHEMA.asStruct(), expected(i), read(location.toString(), vectorized, "id = " + i));
+          SCHEMA.asStruct(), expected(i), read(table.location(), vectorized, "id = " + i));
     }
   }
 
   @SuppressWarnings("checkstyle:AvoidNestedBlocks")
   @Test
   public void testDayPartitionedTimestampFilters() {
-    File location = buildPartitionedTable("partitioned_by_day", PARTITION_BY_DAY, "ts_day", "ts");
+    Table table = buildPartitionedTable("partitioned_by_day", PARTITION_BY_DAY, "ts_day", "ts");
+    CaseInsensitiveStringMap options =
+        new CaseInsensitiveStringMap(ImmutableMap.of("path", table.location()));
+    Batch unfiltered =
+        new SparkScanBuilder(spark, TABLES.load(options.get("path")), options).build().toBatch();
 
-    DataSourceOptions options = new DataSourceOptions(ImmutableMap.of("path", location.toString()));
-
-    IcebergSource source = new IcebergSource();
-    DataSourceReader unfiltered = source.createReader(options);
     Assert.assertEquals(
-        "Unfiltered table should created 2 read tasks", 2, unfiltered.planInputPartitions().size());
+        "Unfiltered table should created 2 read tasks", 2, unfiltered.planInputPartitions().length);
 
     {
-      DataSourceReader reader = source.createReader(options);
+      SparkScanBuilder builder =
+          new SparkScanBuilder(spark, TABLES.load(options.get("path")), options);
 
-      pushFilters(reader, LessThan.apply("ts", "2017-12-22T00:00:00+00:00"));
+      pushFilters(builder, LessThan.apply("ts", "2017-12-22T00:00:00+00:00"));
+      Batch scan = builder.build().toBatch();
 
-      List<InputPartition<InternalRow>> tasks = reader.planInputPartitions();
-      Assert.assertEquals("Should create one task for 2017-12-21", 1, tasks.size());
+      InputPartition[] tasks = scan.planInputPartitions();
+      Assert.assertEquals("Should create one task for 2017-12-21", 1, tasks.length);
 
       assertEqualsSafe(
           SCHEMA.asStruct(),
           expected(5, 6, 7, 8, 9),
           read(
-              location.toString(),
-              vectorized,
-              "ts < cast('2017-12-22 00:00:00+00:00' as timestamp)"));
+              table.location(), vectorized, "ts < cast('2017-12-22 00:00:00+00:00' as timestamp)"));
     }
 
     {
-      DataSourceReader reader = source.createReader(options);
+      SparkScanBuilder builder =
+          new SparkScanBuilder(spark, TABLES.load(options.get("path")), options);
 
       pushFilters(
-          reader,
+          builder,
           And.apply(
               GreaterThan.apply("ts", "2017-12-22T06:00:00+00:00"),
               LessThan.apply("ts", "2017-12-22T08:00:00+00:00")));
+      Batch scan = builder.build().toBatch();
 
-      List<InputPartition<InternalRow>> tasks = reader.planInputPartitions();
-      Assert.assertEquals("Should create one task for 2017-12-22", 1, tasks.size());
+      InputPartition[] tasks = scan.planInputPartitions();
+      Assert.assertEquals("Should create one task for 2017-12-22", 1, tasks.length);
 
       assertEqualsSafe(
           SCHEMA.asStruct(),
           expected(1, 2),
           read(
-              location.toString(),
+              table.location(),
               vectorized,
               "ts > cast('2017-12-22 06:00:00+00:00' as timestamp) and "
                   + "ts < cast('2017-12-22 08:00:00+00:00' as timestamp)"));
@@ -361,50 +366,52 @@ public class TestFilteredScan {
   @SuppressWarnings("checkstyle:AvoidNestedBlocks")
   @Test
   public void testHourPartitionedTimestampFilters() {
-    File location =
-        buildPartitionedTable("partitioned_by_hour", PARTITION_BY_HOUR, "ts_hour", "ts");
+    Table table = buildPartitionedTable("partitioned_by_hour", PARTITION_BY_HOUR, "ts_hour", "ts");
 
-    DataSourceOptions options = new DataSourceOptions(ImmutableMap.of("path", location.toString()));
+    CaseInsensitiveStringMap options =
+        new CaseInsensitiveStringMap(ImmutableMap.of("path", table.location()));
+    Batch unfiltered =
+        new SparkScanBuilder(spark, TABLES.load(options.get("path")), options).build().toBatch();
 
-    IcebergSource source = new IcebergSource();
-    DataSourceReader unfiltered = source.createReader(options);
     Assert.assertEquals(
-        "Unfiltered table should created 9 read tasks", 9, unfiltered.planInputPartitions().size());
+        "Unfiltered table should created 9 read tasks", 9, unfiltered.planInputPartitions().length);
 
     {
-      DataSourceReader reader = source.createReader(options);
+      SparkScanBuilder builder =
+          new SparkScanBuilder(spark, TABLES.load(options.get("path")), options);
 
-      pushFilters(reader, LessThan.apply("ts", "2017-12-22T00:00:00+00:00"));
+      pushFilters(builder, LessThan.apply("ts", "2017-12-22T00:00:00+00:00"));
+      Batch scan = builder.build().toBatch();
 
-      List<InputPartition<InternalRow>> tasks = reader.planInputPartitions();
-      Assert.assertEquals("Should create 4 tasks for 2017-12-21: 15, 17, 21, 22", 4, tasks.size());
+      InputPartition[] tasks = scan.planInputPartitions();
+      Assert.assertEquals("Should create 4 tasks for 2017-12-21: 15, 17, 21, 22", 4, tasks.length);
 
       assertEqualsSafe(
           SCHEMA.asStruct(),
           expected(8, 9, 7, 6, 5),
           read(
-              location.toString(),
-              vectorized,
-              "ts < cast('2017-12-22 00:00:00+00:00' as timestamp)"));
+              table.location(), vectorized, "ts < cast('2017-12-22 00:00:00+00:00' as timestamp)"));
     }
 
     {
-      DataSourceReader reader = source.createReader(options);
+      SparkScanBuilder builder =
+          new SparkScanBuilder(spark, TABLES.load(options.get("path")), options);
 
       pushFilters(
-          reader,
+          builder,
           And.apply(
               GreaterThan.apply("ts", "2017-12-22T06:00:00+00:00"),
               LessThan.apply("ts", "2017-12-22T08:00:00+00:00")));
+      Batch scan = builder.build().toBatch();
 
-      List<InputPartition<InternalRow>> tasks = reader.planInputPartitions();
-      Assert.assertEquals("Should create 2 tasks for 2017-12-22: 6, 7", 2, tasks.size());
+      InputPartition[] tasks = scan.planInputPartitions();
+      Assert.assertEquals("Should create 2 tasks for 2017-12-22: 6, 7", 2, tasks.length);
 
       assertEqualsSafe(
           SCHEMA.asStruct(),
           expected(2, 1),
           read(
-              location.toString(),
+              table.location(),
               vectorized,
               "ts > cast('2017-12-22 06:00:00+00:00' as timestamp) and "
                   + "ts < cast('2017-12-22 08:00:00+00:00' as timestamp)"));
@@ -453,70 +460,68 @@ public class TestFilteredScan {
     }
   }
 
-  @Test
-  public void testInFilter() {
-    File location =
-        buildPartitionedTable("partitioned_by_data", PARTITION_BY_DATA, "data_ident", "data");
-
-    DataSourceOptions options = new DataSourceOptions(ImmutableMap.of("path", location.toString()));
-
-    IcebergSource source = new IcebergSource();
-    DataSourceReader reader = source.createReader(options);
-    pushFilters(reader, new In("data", new String[] {"foo", "junction", "brush", null}));
-
-    Assert.assertEquals(2, reader.planInputPartitions().size());
-  }
-
-  @Test
-  public void testInFilterForTimestamp() {
-    File location =
-        buildPartitionedTable("partitioned_by_hour", PARTITION_BY_HOUR, "ts_hour", "ts");
-
-    DataSourceOptions options = new DataSourceOptions(ImmutableMap.of("path", location.toString()));
-
-    IcebergSource source = new IcebergSource();
-    DataSourceReader reader = source.createReader(options);
-    pushFilters(
-        reader,
-        new In(
-            "ts",
-            new Timestamp[] {
-              new Timestamp(instant("2017-12-22T00:00:00.123+00:00") / 1000),
-              new Timestamp(instant("2017-12-22T09:20:44.294+00:00") / 1000),
-              new Timestamp(instant("2017-12-22T00:34:00.184+00:00") / 1000),
-              new Timestamp(instant("2017-12-21T15:15:16.230+00:00") / 1000),
-              null
-            }));
-
-    Assert.assertEquals(
-        "Should create 1 task for 2017-12-21: 15", 1, reader.planInputPartitions().size());
-  }
-
   @Test
   public void testPartitionedByDataStartsWithFilter() {
-    File location =
+    Table table =
         buildPartitionedTable("partitioned_by_data", PARTITION_BY_DATA, "data_ident", "data");
+    CaseInsensitiveStringMap options =
+        new CaseInsensitiveStringMap(ImmutableMap.of("path", table.location()));
 
-    DataSourceOptions options = new DataSourceOptions(ImmutableMap.of("path", location.toString()));
+    SparkScanBuilder builder =
+        new SparkScanBuilder(spark, TABLES.load(options.get("path")), options);
 
-    IcebergSource source = new IcebergSource();
-    DataSourceReader reader = source.createReader(options);
-    pushFilters(reader, new StringStartsWith("data", "junc"));
+    pushFilters(builder, new StringStartsWith("data", "junc"));
+    Batch scan = builder.build().toBatch();
 
-    Assert.assertEquals(1, reader.planInputPartitions().size());
+    Assert.assertEquals(1, scan.planInputPartitions().length);
+  }
+
+  @Test
+  public void testPartitionedByDataNotStartsWithFilter() {
+    Table table =
+        buildPartitionedTable("partitioned_by_data", PARTITION_BY_DATA, "data_ident", "data");
+    CaseInsensitiveStringMap options =
+        new CaseInsensitiveStringMap(ImmutableMap.of("path", table.location()));
+
+    SparkScanBuilder builder =
+        new SparkScanBuilder(spark, TABLES.load(options.get("path")), options);
+
+    pushFilters(builder, new Not(new StringStartsWith("data", "junc")));
+    Batch scan = builder.build().toBatch();
+
+    Assert.assertEquals(9, scan.planInputPartitions().length);
   }
 
   @Test
   public void testPartitionedByIdStartsWith() {
-    File location = buildPartitionedTable("partitioned_by_id", PARTITION_BY_ID, "id_ident", "id");
+    Table table = buildPartitionedTable("partitioned_by_id", PARTITION_BY_ID, "id_ident", "id");
 
-    DataSourceOptions options = new DataSourceOptions(ImmutableMap.of("path", location.toString()));
+    CaseInsensitiveStringMap options =
+        new CaseInsensitiveStringMap(ImmutableMap.of("path", table.location()));
 
-    IcebergSource source = new IcebergSource();
-    DataSourceReader reader = source.createReader(options);
-    pushFilters(reader, new StringStartsWith("data", "junc"));
+    SparkScanBuilder builder =
+        new SparkScanBuilder(spark, TABLES.load(options.get("path")), options);
 
-    Assert.assertEquals(1, reader.planInputPartitions().size());
+    pushFilters(builder, new StringStartsWith("data", "junc"));
+    Batch scan = builder.build().toBatch();
+
+    Assert.assertEquals(1, scan.planInputPartitions().length);
+  }
+
+  @Test
+  public void testPartitionedByIdNotStartsWith() {
+    Table table = buildPartitionedTable("partitioned_by_id", PARTITION_BY_ID, "id_ident", "id");
+
+    CaseInsensitiveStringMap options =
+        new CaseInsensitiveStringMap(ImmutableMap.of("path", table.location()));
+
+    SparkScanBuilder builder =
+        new SparkScanBuilder(spark, TABLES.load(options.get("path")), options);
+
+    pushFilters(builder, new Not(new StringStartsWith("data", "junc")));
+    Batch scan = builder.build().toBatch();
+
+    Assert.assertEquals(9, scan.planInputPartitions().length);
   }
 
   @Test
@@ -535,6 +540,28 @@ public class TestFilteredScan {
     Assert.assertEquals("junction", matchedData.get(0));
   }
 
+  @Test
+  public void testUnpartitionedNotStartsWith() {
+    Dataset<Row> df =
+        spark
+            .read()
+            .format("iceberg")
+            .option(SparkReadOptions.VECTORIZATION_ENABLED, String.valueOf(vectorized))
+            .load(unpartitioned.toString());
+
+    List<String> matchedData =
+        df.select("data").where("data NOT LIKE 'jun%'").as(Encoders.STRING()).collectAsList();
+
+    List<String> expected =
+        testRecords(SCHEMA).stream()
+            .map(r -> r.getField("data").toString())
+            .filter(d -> !d.startsWith("jun"))
+            .collect(Collectors.toList());
+
+    Assert.assertEquals(9, matchedData.size());
+    Assert.assertEquals(Sets.newHashSet(expected), Sets.newHashSet(matchedData));
+  }
+
   private static Record projectFlat(Schema projection, Record record) {
     Record result = GenericRecord.create(projection);
     List<Types.NestedField> fields = projection.asStruct().fields();
@@ -573,20 +600,20 @@ public class TestFilteredScan {
     return expected;
   }
 
-  private void pushFilters(DataSourceReader reader, Filter... filters) {
-    Assertions.assertThat(reader).isInstanceOf(SupportsPushDownFilters.class);
-    SupportsPushDownFilters filterable = (SupportsPushDownFilters) reader;
+  private void pushFilters(ScanBuilder scan, Filter... filters) {
+    Assertions.assertThat(scan).isInstanceOf(SupportsPushDownFilters.class);
+    SupportsPushDownFilters filterable = (SupportsPushDownFilters) scan;
     filterable.pushFilters(filters);
   }
 
-  private File buildPartitionedTable(
+  private Table buildPartitionedTable(
       String desc, PartitionSpec spec, String udf, String partitionColumn) {
     File location = new File(parent, desc);
-    Table byId = TABLES.create(SCHEMA, spec, location.toString());
+    Table table = TABLES.create(SCHEMA, spec, location.toString());
 
     // Do not combine or split files because the tests expect a split per partition.
     // A target split size of 2048 helps us achieve that.
-    byId.updateProperties().set("read.split.target-size", "2048").commit();
+    table.updateProperties().set("read.split.target-size", "2048").commit();
 
     // copy the unpartitioned table into the partitioned table to produce the partitioned data
     Dataset<Row> allRows =
@@ -604,9 +631,11 @@ public class TestFilteredScan {
         .write()
         .format("iceberg")
         .mode("append")
-        .save(byId.location());
+        .save(table.location());
 
-    return location;
+    table.refresh();
+
+    return table;
   }
 
   private List<Record> testRecords(Schema schema) {
@@ -644,10 +673,6 @@ public class TestFilteredScan {
     return OffsetDateTime.parse(timestamp);
   }
 
-  private static long instant(String timestamp) {
-    return Literal.of(timestamp).<Long>to(Types.TimestampType.withZone()).value();
-  }
-
   private static Record record(Schema schema, Object... values) {
     Record rec = GenericRecord.create(schema);
     for (int i = 0; i < values.length; i += 1) {
