@@ -63,7 +63,7 @@ import org.junit.Rule;
 import org.junit.Test;
 import org.junit.rules.TemporaryFolder;
 import scala.Option;
-import scala.collection.JavaConverters;
+import scala.collection.JavaConversions;
 
 public class TestForwardCompatibility {
   private static final Configuration CONF = new Configuration();
@@ -219,6 +219,6 @@ public class TestForwardCompatibility {
   }
 
   private <T> void send(List<T> records, MemoryStream<T> stream) {
-    stream.addData(JavaConverters.asScalaBuffer(records));
+    stream.addData(JavaConversions.asScalaBuffer(records));
   }
 }
