@@ -619,9 +619,10 @@ public class TestSparkDataWrite {
 
     Table spyTable = spy(table);
     when(spyTable.newAppend()).thenReturn(spyAppend);
+    SparkTable sparkTable = new SparkTable(spyTable, false);
 
     String manualTableName = "unknown_exception";
-    ManualSource.setTable(manualTableName, spyTable);
+    ManualSource.setTable(manualTableName, sparkTable);
 
     // Although an exception is thrown here, write and commit have succeeded
     AssertHelpers.assertThrowsWithCause(
