@@ -16,7 +16,6 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-
 package org.apache.iceberg.spark.extensions;
 
 import java.util.Map;
@@ -28,7 +27,8 @@ import org.junit.Assert;
 import org.junit.Test;
 
 public class TestAlterTableSchema extends SparkExtensionsTestBase {
-  public TestAlterTableSchema(String catalogName, String implementation, Map<String, String> config) {
+  public TestAlterTableSchema(
+      String catalogName, String implementation, Map<String, String> config) {
     super(catalogName, implementation, config);
   }
 
@@ -39,20 +39,25 @@ public class TestAlterTableSchema extends SparkExtensionsTestBase {
 
   @Test
   public void testSetIdentifierFields() {
-    sql("CREATE TABLE %s (id bigint NOT NULL, " +
-        "location struct<lon:bigint NOT NULL,lat:bigint NOT NULL> NOT NULL) USING iceberg", tableName);
+    sql(
+        "CREATE TABLE %s (id bigint NOT NULL, "
+            + "location struct<lon:bigint NOT NULL,lat:bigint NOT NULL> NOT NULL) USING iceberg",
+        tableName);
     Table table = validationCatalog.loadTable(tableIdent);
-    Assert.assertTrue("Table should start without identifier", table.schema().identifierFieldIds().isEmpty());
+    Assert.assertTrue(
+        "Table should start without identifier", table.schema().identifierFieldIds().isEmpty());
 
     sql("ALTER TABLE %s SET IDENTIFIER FIELDS id", tableName);
     table.refresh();
-    Assert.assertEquals("Should have new identifier field",
+    Assert.assertEquals(
+        "Should have new identifier field",
         Sets.newHashSet(table.schema().findField("id").fieldId()),
         table.schema().identifierFieldIds());
 
     sql("ALTER TABLE %s SET IDENTIFIER FIELDS id, location.lon", tableName);
     table.refresh();
-    Assert.assertEquals("Should have new identifier field",
+    Assert.assertEquals(
+        "Should have new identifier field",
         Sets.newHashSet(
             table.schema().findField("id").fieldId(),
             table.schema().findField("location.lon").fieldId()),
@@ -60,7 +65,8 @@ public class TestAlterTableSchema extends SparkExtensionsTestBase {
 
     sql("ALTER TABLE %s SET IDENTIFIER FIELDS location.lon", tableName);
     table.refresh();
-    Assert.assertEquals("Should have new identifier field",
+    Assert.assertEquals(
+        "Should have new identifier field",
         Sets.newHashSet(table.schema().findField("location.lon").fieldId()),
         table.schema().identifierFieldIds());
   }
@@ -69,13 +75,16 @@ public class TestAlterTableSchema extends SparkExtensionsTestBase {
   public void testSetInvalidIdentifierFields() {
     sql("CREATE TABLE %s (id bigint NOT NULL, id2 bigint) USING iceberg", tableName);
     Table table = validationCatalog.loadTable(tableIdent);
-    Assert.assertTrue("Table should start without identifier", table.schema().identifierFieldIds().isEmpty());
-    AssertHelpers.assertThrows("should not allow setting unknown fields",
+    Assert.assertTrue(
+        "Table should start without identifier", table.schema().identifierFieldIds().isEmpty());
+    AssertHelpers.assertThrows(
+        "should not allow setting unknown fields",
         IllegalArgumentException.class,
         "not found in current schema or added columns",
         () -> sql("ALTER TABLE %s SET IDENTIFIER FIELDS unknown", tableName));
 
-    AssertHelpers.assertThrows("should not allow setting optional fields",
+    AssertHelpers.assertThrows(
+        "should not allow setting optional fields",
         IllegalArgumentException.class,
         "not a required field",
         () -> sql("ALTER TABLE %s SET IDENTIFIER FIELDS id2", tableName));
@@ -83,14 +92,18 @@ public class TestAlterTableSchema extends SparkExtensionsTestBase {
 
   @Test
   public void testDropIdentifierFields() {
-    sql("CREATE TABLE %s (id bigint NOT NULL, " +
-        "location struct<lon:bigint NOT NULL,lat:bigint NOT NULL> NOT NULL) USING iceberg", tableName);
+    sql(
+        "CREATE TABLE %s (id bigint NOT NULL, "
+            + "location struct<lon:bigint NOT NULL,lat:bigint NOT NULL> NOT NULL) USING iceberg",
+        tableName);
     Table table = validationCatalog.loadTable(tableIdent);
-    Assert.assertTrue("Table should start without identifier", table.schema().identifierFieldIds().isEmpty());
+    Assert.assertTrue(
+        "Table should start without identifier", table.schema().identifierFieldIds().isEmpty());
 
     sql("ALTER TABLE %s SET IDENTIFIER FIELDS id, location.lon", tableName);
     table.refresh();
-    Assert.assertEquals("Should have new identifier fields",
+    Assert.assertEquals(
+        "Should have new identifier fields",
         Sets.newHashSet(
             table.schema().findField("id").fieldId(),
             table.schema().findField("location.lon").fieldId()),
@@ -98,13 +111,15 @@ public class TestAlterTableSchema extends SparkExtensionsTestBase {
 
     sql("ALTER TABLE %s DROP IDENTIFIER FIELDS id", tableName);
     table.refresh();
-    Assert.assertEquals("Should removed identifier field",
+    Assert.assertEquals(
+        "Should removed identifier field",
         Sets.newHashSet(table.schema().findField("location.lon").fieldId()),
         table.schema().identifierFieldIds());
 
     sql("ALTER TABLE %s SET IDENTIFIER FIELDS id, location.lon", tableName);
     table.refresh();
-    Assert.assertEquals("Should have new identifier fields",
+    Assert.assertEquals(
+        "Should have new identifier fields",
         Sets.newHashSet(
             table.schema().findField("id").fieldId(),
             table.schema().findField("location.lon").fieldId()),
@@ -112,29 +127,34 @@ public class TestAlterTableSchema extends SparkExtensionsTestBase {
 
     sql("ALTER TABLE %s DROP IDENTIFIER FIELDS id, location.lon", tableName);
     table.refresh();
-    Assert.assertEquals("Should have no identifier field",
-        Sets.newHashSet(),
-        table.schema().identifierFieldIds());
+    Assert.assertEquals(
+        "Should have no identifier field", Sets.newHashSet(), table.schema().identifierFieldIds());
   }
 
   @Test
   public void testDropInvalidIdentifierFields() {
-    sql("CREATE TABLE %s (id bigint NOT NULL, data string NOT NULL, " +
-        "location struct<lon:bigint NOT NULL,lat:bigint NOT NULL> NOT NULL) USING iceberg", tableName);
+    sql(
+        "CREATE TABLE %s (id bigint NOT NULL, data string NOT NULL, "
+            + "location struct<lon:bigint NOT NULL,lat:bigint NOT NULL> NOT NULL) USING iceberg",
+        tableName);
     Table table = validationCatalog.loadTable(tableIdent);
-    Assert.assertTrue("Table should start without identifier", table.schema().identifierFieldIds().isEmpty());
-    AssertHelpers.assertThrows("should not allow dropping unknown fields",
+    Assert.assertTrue(
+        "Table should start without identifier", table.schema().identifierFieldIds().isEmpty());
+    AssertHelpers.assertThrows(
+        "should not allow dropping unknown fields",
         IllegalArgumentException.class,
         "field unknown not found",
         () -> sql("ALTER TABLE %s DROP IDENTIFIER FIELDS unknown", tableName));
 
     sql("ALTER TABLE %s SET IDENTIFIER FIELDS id", tableName);
-    AssertHelpers.assertThrows("should not allow dropping a field that is not an identifier",
+    AssertHelpers.assertThrows(
+        "should not allow dropping a field that is not an identifier",
         IllegalArgumentException.class,
         "data is not an identifier field",
         () -> sql("ALTER TABLE %s DROP IDENTIFIER FIELDS data", tableName));
 
-    AssertHelpers.assertThrows("should not allow dropping a nested field that is not an identifier",
+    AssertHelpers.assertThrows(
+        "should not allow dropping a nested field that is not an identifier",
         IllegalArgumentException.class,
         "location.lon is not an identifier field",
         () -> sql("ALTER TABLE %s DROP IDENTIFIER FIELDS location.lon", tableName));
