@@ -22,6 +22,7 @@ import java.util.Map;
 import org.apache.iceberg.actions.MigrateTable;
 import org.apache.iceberg.relocated.com.google.common.base.Preconditions;
 import org.apache.iceberg.relocated.com.google.common.collect.Maps;
+import org.apache.iceberg.spark.actions.MigrateTableSparkAction;
 import org.apache.iceberg.spark.actions.SparkActions;
 import org.apache.iceberg.spark.procedures.SparkProcedures.ProcedureBuilder;
 import org.apache.spark.sql.catalyst.InternalRow;
@@ -91,14 +92,14 @@ class MigrateTableProcedure extends BaseProcedure {
 
     boolean dropBackup = args.isNullAt(2) ? false : args.getBoolean(2);
 
-    MigrateTable migrateTable =
+    MigrateTableSparkAction migrateTableSparkAction =
         SparkActions.get().migrateTable(tableName).tableProperties(properties);
 
-    MigrateTable.Result result;
+    final MigrateTable.Result result;
     if (dropBackup) {
-      result = migrateTable.dropBackup().execute();
+      result = migrateTableSparkAction.dropBackup().execute();
     } else {
-      result = migrateTable.execute();
+      result = migrateTableSparkAction.execute();
     }
 
     return new InternalRow[] {newInternalRow(result.migratedDataFilesCount())};
