@@ -26,7 +26,8 @@ import org.junit.Assert;
 public final class TaskCheckHelper {
   private TaskCheckHelper() {}
 
-  public static void assertEquals(BaseCombinedScanTask expected, BaseCombinedScanTask actual) {
+  public static void assertEquals(
+      ScanTaskGroup<FileScanTask> expected, ScanTaskGroup<FileScanTask> actual) {
     List<FileScanTask> expectedTasks = getFileScanTasksInFilePathOrder(expected);
     List<FileScanTask> actualTasks = getFileScanTasksInFilePathOrder(actual);
 
@@ -100,8 +101,9 @@ public final class TaskCheckHelper {
         "Should match the serialized record offsets", expected.keyMetadata(), actual.keyMetadata());
   }
 
-  private static List<FileScanTask> getFileScanTasksInFilePathOrder(BaseCombinedScanTask task) {
-    return task.files().stream()
+  private static List<FileScanTask> getFileScanTasksInFilePathOrder(
+      ScanTaskGroup<FileScanTask> taskGroup) {
+    return taskGroup.tasks().stream()
         // use file path + start position to differentiate the tasks
         .sorted(Comparator.comparing(o -> o.file().path().toString() + "##" + o.start()))
         .collect(Collectors.toList());
