@@ -18,23 +18,15 @@
  */
 package org.apache.iceberg.spark.source;
 
-import java.util.List;
 import org.apache.iceberg.AssertHelpers;
 import org.apache.iceberg.TableProperties;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableList;
-import org.apache.iceberg.spark.Spark3Util;
 import org.apache.iceberg.spark.SparkTestBaseWithCatalog;
-import org.apache.iceberg.types.Types;
 import org.apache.spark.sql.AnalysisException;
 import org.apache.spark.sql.Dataset;
-import org.apache.spark.sql.Encoders;
 import org.apache.spark.sql.Row;
-import org.apache.spark.sql.SparkSession;
 import org.apache.spark.sql.catalyst.analysis.NoSuchTableException;
-import org.apache.spark.sql.catalyst.parser.ParseException;
-import org.apache.spark.sql.internal.SQLConf;
 import org.junit.After;
-import org.junit.Assert;
 import org.junit.Before;
 import org.junit.Test;
 
@@ -192,37 +184,4 @@ public class TestDataFrameWriterV2 extends SparkTestBaseWithCatalog {
             row(1L, "a", null), row(2L, "b", null), row(3L, "c", 12.06F), row(4L, "d", 14.41F)),
         sql("select * from %s order by id", tableName));
   }
-
-  @Test
-  public void testWriteWithCaseSensitiveOption() throws NoSuchTableException, ParseException {
-    SparkSession sparkSession = spark.cloneSession();
-    sparkSession
-        .sql(
-            String.format(
-                "ALTER TABLE %s SET TBLPROPERTIES ('%s'='true')",
-                tableName, TableProperties.SPARK_WRITE_ACCEPT_ANY_SCHEMA))
-        .collect();
-
-    String schema = "ID bigint, DaTa string";
-    ImmutableList<String> records =
-        ImmutableList.of("{ \"id\": 1, \"data\": \"a\" }", "{ \"id\": 2, \"data\": \"b\" }");
-
-    // disable spark.sql.caseSensitive
-    sparkSession.sql(String.format("SET %s=false", SQLConf.CASE_SENSITIVE().key()));
-    Dataset<String> jsonDF =
-        sparkSession.createDataset(ImmutableList.copyOf(records), Encoders.STRING());
-    Dataset<Row> ds = sparkSession.read().schema(schema).json(jsonDF);
-    // write should succeed
-    ds.writeTo(tableName).option("merge-schema", "true").option("check-ordering", "false").append();
-    List<Types.NestedField> fields =
-        Spark3Util.loadIcebergTable(sparkSession, tableName).schema().asStruct().fields();
-    // Additional columns should not be created
-    Assert.assertEquals(2, fields.size());
-
-    // enable spark.sql.caseSensitive
-    sparkSession.sql(String.format("SET %s=true", SQLConf.CASE_SENSITIVE().key()));
-    ds.writeTo(tableName).option("merge-schema", "true").option("check-ordering", "false").append();
-    fields = Spark3Util.loadIcebergTable(sparkSession, tableName).schema().asStruct().fields();
-    Assert.assertEquals(4, fields.size());
-  }
 }
