@@ -43,14 +43,11 @@ public class TestIcebergSourceHiveTables extends TestIcebergSourceTablesBase {
 
   @After
   public void dropTable() throws IOException {
-    if (currentIdentifier != null) {
-      Table table = catalog.loadTable(currentIdentifier);
-      Path tablePath = new Path(table.location());
-      FileSystem fs = tablePath.getFileSystem(spark.sessionState().newHadoopConf());
-      fs.delete(tablePath, true);
-      catalog.dropTable(currentIdentifier, false);
-      currentIdentifier = null;
+    if (!catalog.tableExists(currentIdentifier)) {
+      return;
     }
+
+    dropTable(currentIdentifier);
   }
 
   @Override
@@ -59,6 +56,15 @@ public class TestIcebergSourceHiveTables extends TestIcebergSourceTablesBase {
     return TestIcebergSourceHiveTables.catalog.createTable(ident, schema, spec);
   }
 
+  @Override
+  public void dropTable(TableIdentifier ident) throws IOException {
+    Table table = catalog.loadTable(ident);
+    Path tablePath = new Path(table.location());
+    FileSystem fs = tablePath.getFileSystem(spark.sessionState().newHadoopConf());
+    fs.delete(tablePath, true);
+    catalog.dropTable(ident, false);
+  }
+
   @Override
   public Table loadTable(TableIdentifier ident, String entriesSuffix) {
     TableIdentifier identifier =
