@@ -41,15 +41,18 @@ import org.apache.spark.sql.catalyst.plans.logical.BranchOptions
 import org.apache.spark.sql.catalyst.plans.logical.CallArgument
 import org.apache.spark.sql.catalyst.plans.logical.CallStatement
 import org.apache.spark.sql.catalyst.plans.logical.CreateOrReplaceBranch
+import org.apache.spark.sql.catalyst.plans.logical.CreateOrReplaceTag
 import org.apache.spark.sql.catalyst.plans.logical.DropBranch
 import org.apache.spark.sql.catalyst.plans.logical.DropIdentifierFields
 import org.apache.spark.sql.catalyst.plans.logical.DropPartitionField
+import org.apache.spark.sql.catalyst.plans.logical.DropTag
 import org.apache.spark.sql.catalyst.plans.logical.LogicalPlan
 import org.apache.spark.sql.catalyst.plans.logical.NamedArgument
 import org.apache.spark.sql.catalyst.plans.logical.PositionalArgument
 import org.apache.spark.sql.catalyst.plans.logical.ReplacePartitionField
 import org.apache.spark.sql.catalyst.plans.logical.SetIdentifierFields
 import org.apache.spark.sql.catalyst.plans.logical.SetWriteDistributionAndOrdering
+import org.apache.spark.sql.catalyst.plans.logical.TagOptions
 import org.apache.spark.sql.catalyst.trees.CurrentOrigin
 import org.apache.spark.sql.catalyst.trees.Origin
 import org.apache.spark.sql.connector.expressions
@@ -58,16 +61,19 @@ import org.apache.spark.sql.connector.expressions.FieldReference
 import org.apache.spark.sql.connector.expressions.IdentityTransform
 import org.apache.spark.sql.connector.expressions.LiteralValue
 import org.apache.spark.sql.connector.expressions.Transform
-import scala.collection.JavaConverters._
+import scala.jdk.CollectionConverters._
 
 class IcebergSqlExtensionsAstBuilder(delegate: ParserInterface) extends IcebergSqlExtensionsBaseVisitor[AnyRef] {
 
+  private def toBuffer[T](list: java.util.List[T]): scala.collection.mutable.Buffer[T] = list.asScala
+  private def toSeq[T](list: java.util.List[T]): Seq[T] = toBuffer(list).toSeq
+
   /**
    * Create a [[CallStatement]] for a stored procedure call.
    */
   override def visitCall(ctx: CallContext): CallStatement = withOrigin(ctx) {
-    val name = ctx.multipartIdentifier.parts.asScala.map(_.getText)
-    val args = ctx.callArgument.asScala.map(typedVisit[CallArgument])
+    val name = toSeq(ctx.multipartIdentifier.parts).map(_.getText)
+    val args = toSeq(ctx.callArgument).map(typedVisit[CallArgument])
     CallStatement(name, args)
   }
 
@@ -128,6 +134,35 @@ class IcebergSqlExtensionsAstBuilder(delegate: ParserInterface) extends IcebergS
       ifNotExists)
   }
 
+  /**
+   * Create an CREATE OR REPLACE TAG logical command.
+   */
+  override def visitCreateOrReplaceTag(ctx: CreateOrReplaceTagContext): CreateOrReplaceTag = withOrigin(ctx) {
+    val createTagClause = ctx.createReplaceTagClause()
+
+    val tagName = createTagClause.identifier().getText
+
+    val tagOptionsContext = Option(createTagClause.tagOptions())
+    val snapshotId = tagOptionsContext.flatMap(tagOptions => Option(tagOptions.snapshotId()))
+      .map(_.getText.toLong)
+    val tagRetain = tagOptionsContext.flatMap(tagOptions => Option(tagOptions.refRetain()))
+    val tagRefAgeMs = tagRetain.map(retain =>
+      TimeUnit.valueOf(retain.timeUnit().getText.toUpperCase(Locale.ENGLISH)).toMillis(retain.number().getText.toLong))
+    val tagOptions = TagOptions(
+      snapshotId,
+      tagRefAgeMs
+    )
+
+    val replace = createTagClause.REPLACE() != null
+    val ifNotExists = createTagClause.EXISTS() != null
+
+    CreateOrReplaceTag(typedVisit[Seq[String]](ctx.multipartIdentifier),
+      tagName,
+      tagOptions,
+      replace,
+      ifNotExists)
+  }
+
   /**
    * Create an DROP BRANCH logical command.
    */
@@ -135,6 +170,13 @@ class IcebergSqlExtensionsAstBuilder(delegate: ParserInterface) extends IcebergS
     DropBranch(typedVisit[Seq[String]](ctx.multipartIdentifier), ctx.identifier().getText, ctx.EXISTS() != null)
   }
 
+  /**
+   * Create an DROP TAG logical command.
+   */
+  override def visitDropTag(ctx: DropTagContext): DropTag = withOrigin(ctx) {
+    DropTag(typedVisit[Seq[String]](ctx.multipartIdentifier), ctx.identifier().getText, ctx.EXISTS() != null)
+  }
+
   /**
    * Create an REPLACE PARTITION FIELD logical command.
    */
@@ -152,7 +194,7 @@ class IcebergSqlExtensionsAstBuilder(delegate: ParserInterface) extends IcebergS
   override def visitSetIdentifierFields(ctx: SetIdentifierFieldsContext): SetIdentifierFields = withOrigin(ctx) {
     SetIdentifierFields(
       typedVisit[Seq[String]](ctx.multipartIdentifier),
-      ctx.fieldList.fields.asScala.map(_.getText))
+      toSeq(ctx.fieldList.fields).map(_.getText))
   }
 
   /**
@@ -161,7 +203,7 @@ class IcebergSqlExtensionsAstBuilder(delegate: ParserInterface) extends IcebergS
   override def visitDropIdentifierFields(ctx: DropIdentifierFieldsContext): DropIdentifierFields = withOrigin(ctx) {
     DropIdentifierFields(
       typedVisit[Seq[String]](ctx.multipartIdentifier),
-      ctx.fieldList.fields.asScala.map(_.getText))
+      toSeq(ctx.fieldList.fields).map(_.getText))
   }
 
   /**
@@ -188,7 +230,7 @@ class IcebergSqlExtensionsAstBuilder(delegate: ParserInterface) extends IcebergS
     }
 
     val ordering = if (orderingSpec != null && orderingSpec.order != null) {
-      orderingSpec.order.fields.asScala.map(typedVisit[(Term, SortDirection, NullOrder)])
+      toSeq(orderingSpec.order.fields).map(typedVisit[(Term, SortDirection, NullOrder)])
     } else {
       Seq.empty
     }
@@ -207,8 +249,8 @@ class IcebergSqlExtensionsAstBuilder(delegate: ParserInterface) extends IcebergS
       throw new AnalysisException("ALTER TABLE contains multiple ordering clauses")
     }
 
-    val distributionSpec = writeSpec.writeDistributionSpec.asScala.headOption.orNull
-    val orderingSpec = writeSpec.writeOrderingSpec.asScala.headOption.orNull
+    val distributionSpec = toBuffer(writeSpec.writeDistributionSpec).headOption.orNull
+    val orderingSpec = toBuffer(writeSpec.writeOrderingSpec).headOption.orNull
 
     (distributionSpec, orderingSpec)
   }
@@ -238,7 +280,7 @@ class IcebergSqlExtensionsAstBuilder(delegate: ParserInterface) extends IcebergS
    * Create a named Transform from argument expressions.
    */
   override def visitApplyTransform(ctx: ApplyTransformContext): Transform = withOrigin(ctx) {
-    val args = ctx.arguments.asScala.map(typedVisit[expressions.Expression])
+    val args = toSeq(ctx.arguments).map(typedVisit[expressions.Expression])
     ApplyTransform(ctx.transformName.getText, args)
   }
 
@@ -260,7 +302,11 @@ class IcebergSqlExtensionsAstBuilder(delegate: ParserInterface) extends IcebergS
    * Return a multi-part identifier as Seq[String].
    */
   override def visitMultipartIdentifier(ctx: MultipartIdentifierContext): Seq[String] = withOrigin(ctx) {
-    ctx.parts.asScala.map(_.getText)
+    toSeq(ctx.parts).map(_.getText)
+  }
+
+  override def visitSingleOrder(ctx: SingleOrderContext): Seq[(Term, SortDirection, NullOrder)] = withOrigin(ctx) {
+    toSeq(ctx.order.fields).map(typedVisit[(Term, SortDirection, NullOrder)])
   }
 
   /**
@@ -298,7 +344,7 @@ class IcebergSqlExtensionsAstBuilder(delegate: ParserInterface) extends IcebergS
   }
 
   private def reconstructSqlString(ctx: ParserRuleContext): String = {
-    ctx.children.asScala.map {
+    toBuffer(ctx.children).map {
       case c: ParserRuleContext => reconstructSqlString(c)
       case t: TerminalNode => t.getText
     }.mkString(" ")
