@@ -22,6 +22,8 @@ import static org.mockito.Mockito.doAnswer;
 import static org.mockito.Mockito.spy;
 import static org.mockito.Mockito.when;
 
+import java.util.List;
+import java.util.Locale;
 import java.util.Map;
 import org.apache.iceberg.AssertHelpers;
 import org.apache.iceberg.RowDelta;
@@ -31,10 +33,11 @@ import org.apache.iceberg.TableProperties;
 import org.apache.iceberg.exceptions.CommitStateUnknownException;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableList;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableMap;
+import org.apache.iceberg.relocated.com.google.common.collect.Lists;
 import org.apache.iceberg.spark.source.SparkTable;
 import org.apache.iceberg.spark.source.TestSparkCatalog;
-import org.apache.spark.SparkException;
 import org.apache.spark.sql.connector.catalog.Identifier;
+import org.junit.Assert;
 import org.junit.Test;
 import org.junit.runners.Parameterized;
 
@@ -46,8 +49,9 @@ public class TestMergeOnReadDelete extends TestDelete {
       Map<String, String> config,
       String fileFormat,
       Boolean vectorized,
-      String distributionMode) {
-    super(catalogName, implementation, config, fileFormat, vectorized, distributionMode);
+      String distributionMode,
+      String branch) {
+    super(catalogName, implementation, config, fileFormat, vectorized, distributionMode, branch);
   }
 
   @Override
@@ -70,14 +74,19 @@ public class TestMergeOnReadDelete extends TestDelete {
 
     // write unpartitioned files
     append(tableName, "{ \"id\": 1, \"dep\": \"hr\", \"category\": \"c1\"}");
+    createBranchIfNeeded();
     append(
-        tableName,
+        commitTarget(),
         "{ \"id\": 2, \"dep\": \"hr\", \"category\": \"c1\" }\n"
             + "{ \"id\": 3, \"dep\": \"hr\", \"category\": \"c1\" }");
 
     Table table = validationCatalog.loadTable(tableIdent);
 
     RowDelta newRowDelta = table.newRowDelta();
+    if (branch != null) {
+      newRowDelta.toBranch(branch);
+    }
+
     RowDelta spyNewRowDelta = spy(newRowDelta);
     doAnswer(
             invocation -> {
@@ -89,7 +98,8 @@ public class TestMergeOnReadDelete extends TestDelete {
 
     Table spyTable = spy(table);
     when(spyTable.newRowDelta()).thenReturn(spyNewRowDelta);
-    SparkTable sparkTable = new SparkTable(spyTable, false);
+    SparkTable sparkTable =
+        branch == null ? new SparkTable(spyTable, false) : new SparkTable(spyTable, branch, false);
 
     ImmutableMap<String, String> config =
         ImmutableMap.of(
@@ -104,10 +114,8 @@ public class TestMergeOnReadDelete extends TestDelete {
     TestSparkCatalog.setTable(ident, sparkTable);
 
     // Although an exception is thrown here, write and commit have succeeded
-    AssertHelpers.assertThrowsWithCause(
+    AssertHelpers.assertThrows(
         "Should throw a Commit State Unknown Exception",
-        SparkException.class,
-        "Writing job aborted",
         CommitStateUnknownException.class,
         "Datacenter on Fire",
         () -> sql("DELETE FROM %s WHERE id = 2", "dummy_catalog.default.table"));
@@ -118,4 +126,33 @@ public class TestMergeOnReadDelete extends TestDelete {
         ImmutableList.of(row(1, "hr", "c1"), row(3, "hr", "c1")),
         sql("SELECT * FROM %s ORDER BY id", "dummy_catalog.default.table"));
   }
+
+  @Test
+  public void testAggregatePushDownInMergeOnReadDelete() {
+    createAndInitTable("id LONG, data INT");
+    sql(
+        "INSERT INTO TABLE %s VALUES (1, 1111), (1, 2222), (2, 3333), (2, 4444), (3, 5555), (3, 6666) ",
+        tableName);
+    createBranchIfNeeded();
+
+    sql("DELETE FROM %s WHERE data = 1111", commitTarget());
+    String select = "SELECT max(data), min(data), count(data) FROM %s";
+
+    List<Object[]> explain = sql("EXPLAIN " + select, selectTarget());
+    String explainString = explain.get(0)[0].toString().toLowerCase(Locale.ROOT);
+    boolean explainContainsPushDownAggregates = false;
+    if (explainString.contains("max(data)")
+        || explainString.contains("min(data)")
+        || explainString.contains("count(data)")) {
+      explainContainsPushDownAggregates = true;
+    }
+
+    Assert.assertFalse(
+        "min/max/count not pushed down for deleted", explainContainsPushDownAggregates);
+
+    List<Object[]> actual = sql(select, selectTarget());
+    List<Object[]> expected = Lists.newArrayList();
+    expected.add(new Object[] {6666, 2222, 5L});
+    assertEquals("min/max/count push down", expected, actual);
+  }
 }
