@@ -18,11 +18,13 @@
  */
 package org.apache.iceberg.spark;
 
+import java.util.List;
 import java.util.Locale;
 import java.util.Map;
 import java.util.function.Function;
 import org.apache.iceberg.Table;
 import org.apache.iceberg.relocated.com.google.common.base.Preconditions;
+import org.apache.iceberg.relocated.com.google.common.collect.Lists;
 import org.apache.spark.sql.RuntimeConfig;
 import org.apache.spark.sql.SparkSession;
 
@@ -56,6 +58,7 @@ class SparkConfParser {
 
   class BooleanConfParser extends ConfParser<BooleanConfParser, Boolean> {
     private Boolean defaultValue;
+    private boolean negate = false;
 
     @Override
     protected BooleanConfParser self() {
@@ -72,9 +75,15 @@ class SparkConfParser {
       return self();
     }
 
+    public BooleanConfParser negate() {
+      this.negate = true;
+      return self();
+    }
+
     public boolean parse() {
       Preconditions.checkArgument(defaultValue != null, "Default value cannot be null");
-      return parse(Boolean::parseBoolean, defaultValue);
+      boolean value = parse(Boolean::parseBoolean, defaultValue);
+      return negate ? !value : value;
     }
   }
 
@@ -148,14 +157,14 @@ class SparkConfParser {
   }
 
   abstract class ConfParser<ThisT, T> {
-    private String optionName;
+    private final List<String> optionNames = Lists.newArrayList();
     private String sessionConfName;
     private String tablePropertyName;
 
     protected abstract ThisT self();
 
     public ThisT option(String name) {
-      this.optionName = name;
+      this.optionNames.add(name);
       return self();
     }
 
@@ -170,12 +179,14 @@ class SparkConfParser {
     }
 
     protected T parse(Function<String, T> conversion, T defaultValue) {
-      if (optionName != null) {
-        // use lower case comparison as DataSourceOptions.asMap() in Spark 2 returns a lower case
-        // map
-        String optionValue = options.get(optionName.toLowerCase(Locale.ROOT));
-        if (optionValue != null) {
-          return conversion.apply(optionValue);
+      if (!optionNames.isEmpty()) {
+        for (String optionName : optionNames) {
+          // use lower case comparison as DataSourceOptions.asMap() in Spark 2 returns a lower case
+          // map
+          String optionValue = options.get(optionName.toLowerCase(Locale.ROOT));
+          if (optionValue != null) {
+            return conversion.apply(optionValue);
+          }
         }
       }
 
