@@ -26,14 +26,14 @@ public class SparkSQLProperties {
   public static final String VECTORIZATION_ENABLED = "spark.sql.iceberg.vectorization.enabled";
 
   // Controls whether reading/writing timestamps without timezones is allowed
+  @Deprecated
   public static final String HANDLE_TIMESTAMP_WITHOUT_TIMEZONE =
       "spark.sql.iceberg.handle-timestamp-without-timezone";
-  public static final boolean HANDLE_TIMESTAMP_WITHOUT_TIMEZONE_DEFAULT = false;
 
   // Controls whether timestamp types for new tables should be stored with timezone info
+  @Deprecated
   public static final String USE_TIMESTAMP_WITHOUT_TIME_ZONE_IN_NEW_TABLES =
       "spark.sql.iceberg.use-timestamp-without-timezone-in-new-tables";
-  public static final boolean USE_TIMESTAMP_WITHOUT_TIME_ZONE_IN_NEW_TABLES_DEFAULT = false;
 
   // Controls whether to perform the nullability check during writes
   public static final String CHECK_NULLABILITY = "spark.sql.iceberg.check-nullability";
