@@ -19,9 +19,9 @@
 package org.apache.iceberg.spark.source;
 
 import static org.apache.iceberg.IsolationLevel.SERIALIZABLE;
-import static org.apache.spark.sql.connector.iceberg.write.RowLevelOperation.Command.DELETE;
-import static org.apache.spark.sql.connector.iceberg.write.RowLevelOperation.Command.MERGE;
-import static org.apache.spark.sql.connector.iceberg.write.RowLevelOperation.Command.UPDATE;
+import static org.apache.spark.sql.connector.write.RowLevelOperation.Command.DELETE;
+import static org.apache.spark.sql.connector.write.RowLevelOperation.Command.MERGE;
+import static org.apache.spark.sql.connector.write.RowLevelOperation.Command.UPDATE;
 
 import java.io.IOException;
 import java.io.Serializable;
@@ -51,7 +51,6 @@ import org.apache.iceberg.io.ClusteredDataWriter;
 import org.apache.iceberg.io.ClusteredPositionDeleteWriter;
 import org.apache.iceberg.io.DataWriteResult;
 import org.apache.iceberg.io.DeleteWriteResult;
-import org.apache.iceberg.io.FanoutDataWriter;
 import org.apache.iceberg.io.FileIO;
 import org.apache.iceberg.io.OutputFileFactory;
 import org.apache.iceberg.io.PartitioningWriter;
@@ -62,6 +61,7 @@ import org.apache.iceberg.relocated.com.google.common.collect.Maps;
 import org.apache.iceberg.spark.CommitMetadata;
 import org.apache.iceberg.spark.SparkSchemaUtil;
 import org.apache.iceberg.spark.SparkWriteConf;
+import org.apache.iceberg.spark.SparkWriteRequirements;
 import org.apache.iceberg.types.Types;
 import org.apache.iceberg.util.CharSequenceSet;
 import org.apache.iceberg.util.StructProjection;
@@ -71,14 +71,14 @@ import org.apache.spark.sql.SparkSession;
 import org.apache.spark.sql.catalyst.InternalRow;
 import org.apache.spark.sql.connector.distributions.Distribution;
 import org.apache.spark.sql.connector.expressions.SortOrder;
-import org.apache.spark.sql.connector.iceberg.write.DeltaBatchWrite;
-import org.apache.spark.sql.connector.iceberg.write.DeltaWrite;
-import org.apache.spark.sql.connector.iceberg.write.DeltaWriter;
-import org.apache.spark.sql.connector.iceberg.write.DeltaWriterFactory;
-import org.apache.spark.sql.connector.iceberg.write.ExtendedLogicalWriteInfo;
-import org.apache.spark.sql.connector.iceberg.write.RowLevelOperation.Command;
+import org.apache.spark.sql.connector.write.DeltaBatchWrite;
+import org.apache.spark.sql.connector.write.DeltaWrite;
+import org.apache.spark.sql.connector.write.DeltaWriter;
+import org.apache.spark.sql.connector.write.DeltaWriterFactory;
+import org.apache.spark.sql.connector.write.LogicalWriteInfo;
 import org.apache.spark.sql.connector.write.PhysicalWriteInfo;
 import org.apache.spark.sql.connector.write.RequiresDistributionAndOrdering;
+import org.apache.spark.sql.connector.write.RowLevelOperation.Command;
 import org.apache.spark.sql.connector.write.WriterCommitMessage;
 import org.apache.spark.sql.types.StructType;
 import org.slf4j.Logger;
@@ -97,9 +97,9 @@ class SparkPositionDeltaWrite implements DeltaWrite, RequiresDistributionAndOrde
   private final String applicationId;
   private final boolean wapEnabled;
   private final String wapId;
+  private final String branch;
   private final Map<String, String> extraSnapshotMetadata;
-  private final Distribution requiredDistribution;
-  private final SortOrder[] requiredOrdering;
+  private final SparkWriteRequirements writeRequirements;
 
   private boolean cleanupOnAbort = true;
 
@@ -110,10 +110,8 @@ class SparkPositionDeltaWrite implements DeltaWrite, RequiresDistributionAndOrde
       SparkBatchQueryScan scan,
       IsolationLevel isolationLevel,
       SparkWriteConf writeConf,
-      ExtendedLogicalWriteInfo info,
-      Schema dataSchema,
-      Distribution requiredDistribution,
-      SortOrder[] requiredOrdering) {
+      LogicalWriteInfo info,
+      Schema dataSchema) {
     this.sparkContext = JavaSparkContext.fromSparkContext(spark.sparkContext());
     this.table = table;
     this.command = command;
@@ -123,19 +121,24 @@ class SparkPositionDeltaWrite implements DeltaWrite, RequiresDistributionAndOrde
     this.applicationId = spark.sparkContext().applicationId();
     this.wapEnabled = writeConf.wapEnabled();
     this.wapId = writeConf.wapId();
+    this.branch = writeConf.branch();
     this.extraSnapshotMetadata = writeConf.extraSnapshotMetadata();
-    this.requiredDistribution = requiredDistribution;
-    this.requiredOrdering = requiredOrdering;
+    this.writeRequirements = writeConf.positionDeltaRequirements(command);
   }
 
   @Override
   public Distribution requiredDistribution() {
-    return requiredDistribution;
+    return writeRequirements.distribution();
+  }
+
+  @Override
+  public boolean distributionStrictlyRequired() {
+    return false;
   }
 
   @Override
   public SortOrder[] requiredOrdering() {
-    return requiredOrdering;
+    return writeRequirements.ordering();
   }
 
   @Override
@@ -178,10 +181,8 @@ class SparkPositionDeltaWrite implements DeltaWrite, RequiresDistributionAndOrde
         referencedDataFiles.addAll(Arrays.asList(taskCommit.referencedDataFiles()));
       }
 
-      // the scan may be null if the optimizer replaces it with an empty relation (e.g. the cond is
-      // false)
-      // no validation is needed in this case as the command does not depend on the scanned table
-      // state
+      // the scan may be null if the optimizer replaces it with an empty relation
+      // no validation is needed in this case as the command is independent of the table state
       if (scan != null) {
         Expression conflictDetectionFilter = conflictDetectionFilter(scan);
         rowDelta.conflictDetectionFilter(conflictDetectionFilter);
@@ -264,9 +265,7 @@ class SparkPositionDeltaWrite implements DeltaWrite, RequiresDistributionAndOrde
 
       extraSnapshotMetadata.forEach(operation::set);
 
-      if (!CommitMetadata.commitProperties().isEmpty()) {
-        CommitMetadata.commitProperties().forEach(operation::set);
-      }
+      CommitMetadata.commitProperties().forEach(operation::set);
 
       if (wapEnabled && wapId != null) {
         // write-audit-publish is enabled for this table and job
@@ -275,6 +274,10 @@ class SparkPositionDeltaWrite implements DeltaWrite, RequiresDistributionAndOrde
         operation.stageOnly();
       }
 
+      if (branch != null) {
+        operation.toBranch(branch);
+      }
+
       try {
         long start = System.currentTimeMillis();
         operation.commit(); // abort is automatically called if this fails
@@ -377,10 +380,13 @@ class SparkPositionDeltaWrite implements DeltaWrite, RequiresDistributionAndOrde
     protected Map<Integer, StructProjection> buildPartitionProjections(
         Types.StructType partitionType, Map<Integer, PartitionSpec> specs) {
       Map<Integer, StructProjection> partitionProjections = Maps.newHashMap();
-      specs.forEach(
-          (specID, spec) ->
-              partitionProjections.put(
-                  specID, StructProjection.create(partitionType, spec.partitionType())));
+
+      for (int specId : specs.keySet()) {
+        PartitionSpec spec = specs.get(specId);
+        StructProjection projection = StructProjection.create(partitionType, spec.partitionType());
+        partitionProjections.put(specId, projection);
+      }
+
       return partitionProjections;
     }
   }
@@ -416,12 +422,10 @@ class SparkPositionDeltaWrite implements DeltaWrite, RequiresDistributionAndOrde
       this.partitionRowWrapper = initPartitionRowWrapper(partitionType);
       this.partitionProjections = buildPartitionProjections(partitionType, specs);
 
-      this.specIdOrdinal = context.metadataSparkType().fieldIndex(MetadataColumns.SPEC_ID.name());
-      this.partitionOrdinal =
-          context.metadataSparkType().fieldIndex(MetadataColumns.PARTITION_COLUMN_NAME);
-      this.fileOrdinal = context.deleteSparkType().fieldIndex(MetadataColumns.FILE_PATH.name());
-      this.positionOrdinal =
-          context.deleteSparkType().fieldIndex(MetadataColumns.ROW_POSITION.name());
+      this.specIdOrdinal = context.specIdOrdinal();
+      this.partitionOrdinal = context.partitionOrdinal();
+      this.fileOrdinal = context.fileOrdinal();
+      this.positionOrdinal = context.positionOrdinal();
     }
 
     @Override
@@ -498,8 +502,7 @@ class SparkPositionDeltaWrite implements DeltaWrite, RequiresDistributionAndOrde
         Context context) {
       this.delegate =
           new BasePositionDeltaWriter<>(
-              newInsertWriter(table, writerFactory, dataFileFactory, context),
-              newUpdateWriter(table, writerFactory, dataFileFactory, context),
+              newDataWriter(table, writerFactory, dataFileFactory, context),
               newDeleteWriter(table, writerFactory, deleteFileFactory, context));
       this.io = table.io();
       this.specs = table.specs();
@@ -508,12 +511,10 @@ class SparkPositionDeltaWrite implements DeltaWrite, RequiresDistributionAndOrde
       this.deletePartitionRowWrapper = initPartitionRowWrapper(partitionType);
       this.deletePartitionProjections = buildPartitionProjections(partitionType, specs);
 
-      this.specIdOrdinal = context.metadataSparkType().fieldIndex(MetadataColumns.SPEC_ID.name());
-      this.partitionOrdinal =
-          context.metadataSparkType().fieldIndex(MetadataColumns.PARTITION_COLUMN_NAME);
-      this.fileOrdinal = context.deleteSparkType().fieldIndex(MetadataColumns.FILE_PATH.name());
-      this.positionOrdinal =
-          context.deleteSparkType().fieldIndex(MetadataColumns.ROW_POSITION.name());
+      this.specIdOrdinal = context.specIdOrdinal();
+      this.partitionOrdinal = context.partitionOrdinal();
+      this.fileOrdinal = context.fileOrdinal();
+      this.positionOrdinal = context.positionOrdinal();
     }
 
     @Override
@@ -561,43 +562,16 @@ class SparkPositionDeltaWrite implements DeltaWrite, RequiresDistributionAndOrde
       }
     }
 
-    private PartitioningWriter<InternalRow, DataWriteResult> newInsertWriter(
-        Table table,
-        SparkFileWriterFactory writerFactory,
-        OutputFileFactory fileFactory,
-        Context context) {
-      long targetFileSize = context.targetDataFileSize();
-
-      if (table.spec().isPartitioned() && context.fanoutWriterEnabled()) {
-        return new FanoutDataWriter<>(writerFactory, fileFactory, table.io(), targetFileSize);
-      } else {
-        return new ClusteredDataWriter<>(writerFactory, fileFactory, table.io(), targetFileSize);
-      }
-    }
-
-    private PartitioningWriter<InternalRow, DataWriteResult> newUpdateWriter(
-        Table table,
-        SparkFileWriterFactory writerFactory,
-        OutputFileFactory fileFactory,
-        Context context) {
-      long targetFileSize = context.targetDataFileSize();
-
-      if (table.spec().isPartitioned()) {
-        // use a fanout writer for partitioned tables to write updates as they may be out of order
-        return new FanoutDataWriter<>(writerFactory, fileFactory, table.io(), targetFileSize);
-      } else {
-        return new ClusteredDataWriter<>(writerFactory, fileFactory, table.io(), targetFileSize);
-      }
+    private PartitioningWriter<InternalRow, DataWriteResult> newDataWriter(
+        Table table, SparkFileWriterFactory writers, OutputFileFactory files, Context context) {
+      long fileSize = context.targetDataFileSize();
+      return new ClusteredDataWriter<>(writers, files, table.io(), fileSize);
     }
 
     private ClusteredPositionDeleteWriter<InternalRow> newDeleteWriter(
-        Table table,
-        SparkFileWriterFactory writerFactory,
-        OutputFileFactory fileFactory,
-        Context context) {
-      long targetFileSize = context.targetDeleteFileSize();
-      return new ClusteredPositionDeleteWriter<>(
-          writerFactory, fileFactory, table.io(), targetFileSize);
+        Table table, SparkFileWriterFactory writers, OutputFileFactory files, Context context) {
+      long fileSize = context.targetDeleteFileSize();
+      return new ClusteredPositionDeleteWriter<>(writers, files, table.io(), fileSize);
     }
   }
 
@@ -616,8 +590,7 @@ class SparkPositionDeltaWrite implements DeltaWrite, RequiresDistributionAndOrde
 
     @Override
     public void update(InternalRow meta, InternalRow id, InternalRow row) throws IOException {
-      delete(meta, id);
-      delegate.update(row, dataSpec, null);
+      throw new UnsupportedOperationException("Update must be represented as delete and insert");
     }
 
     @Override
@@ -646,9 +619,7 @@ class SparkPositionDeltaWrite implements DeltaWrite, RequiresDistributionAndOrde
 
     @Override
     public void update(InternalRow meta, InternalRow id, InternalRow row) throws IOException {
-      delete(meta, id);
-      dataPartitionKey.partition(internalRowDataWrapper.wrap(row));
-      delegate.update(row, dataSpec, dataPartitionKey);
+      throw new UnsupportedOperationException("Update must be represented as delete and insert");
     }
 
     @Override
@@ -668,19 +639,17 @@ class SparkPositionDeltaWrite implements DeltaWrite, RequiresDistributionAndOrde
     private final StructType metadataSparkType;
     private final FileFormat deleteFileFormat;
     private final long targetDeleteFileSize;
-    private final boolean fanoutWriterEnabled;
     private final String queryId;
 
-    Context(Schema dataSchema, SparkWriteConf writeConf, ExtendedLogicalWriteInfo info) {
+    Context(Schema dataSchema, SparkWriteConf writeConf, LogicalWriteInfo info) {
       this.dataSchema = dataSchema;
       this.dataSparkType = info.schema();
       this.dataFileFormat = writeConf.dataFileFormat();
       this.targetDataFileSize = writeConf.targetDataFileSize();
-      this.deleteSparkType = info.rowIdSchema();
+      this.deleteSparkType = info.rowIdSchema().get();
       this.deleteFileFormat = writeConf.deleteFileFormat();
       this.targetDeleteFileSize = writeConf.targetDeleteFileSize();
-      this.metadataSparkType = info.metadataSchema();
-      this.fanoutWriterEnabled = writeConf.fanoutWriterEnabled();
+      this.metadataSparkType = info.metadataSchema().get();
       this.queryId = info.queryId();
     }
 
@@ -704,10 +673,6 @@ class SparkPositionDeltaWrite implements DeltaWrite, RequiresDistributionAndOrde
       return deleteSparkType;
     }
 
-    StructType metadataSparkType() {
-      return metadataSparkType;
-    }
-
     FileFormat deleteFileFormat() {
       return deleteFileFormat;
     }
@@ -716,12 +681,24 @@ class SparkPositionDeltaWrite implements DeltaWrite, RequiresDistributionAndOrde
       return targetDeleteFileSize;
     }
 
-    boolean fanoutWriterEnabled() {
-      return fanoutWriterEnabled;
-    }
-
     String queryId() {
       return queryId;
     }
+
+    int specIdOrdinal() {
+      return metadataSparkType.fieldIndex(MetadataColumns.SPEC_ID.name());
+    }
+
+    int partitionOrdinal() {
+      return metadataSparkType.fieldIndex(MetadataColumns.PARTITION_COLUMN_NAME);
+    }
+
+    int fileOrdinal() {
+      return deleteSparkType.fieldIndex(MetadataColumns.FILE_PATH.name());
+    }
+
+    int positionOrdinal() {
+      return deleteSparkType.fieldIndex(MetadataColumns.ROW_POSITION.name());
+    }
   }
 }
