@@ -18,9 +18,11 @@
  */
 package org.apache.spark.sql.catalyst.analysis;
 
+import org.apache.spark.QueryContext;
 import org.apache.spark.sql.AnalysisException;
 import org.apache.spark.sql.connector.catalog.Identifier;
 import scala.Option;
+import scala.collection.immutable.Map$;
 
 public class NoSuchProcedureException extends AnalysisException {
   public NoSuchProcedureException(Identifier ident) {
@@ -29,6 +31,9 @@ public class NoSuchProcedureException extends AnalysisException {
         Option.empty(),
         Option.empty(),
         Option.empty(),
-        Option.empty());
+        Option.empty(),
+        Option.empty(),
+        Map$.MODULE$.<String, String>empty(),
+        new QueryContext[0]);
   }
 }
