@@ -50,6 +50,11 @@ public class TestIcebergSourceHadoopTables extends TestIcebergSourceTablesBase {
     return TABLES.create(schema, spec, tableLocation);
   }
 
+  @Override
+  public void dropTable(TableIdentifier ident) {
+    TABLES.dropTable(tableLocation);
+  }
+
   @Override
   public Table loadTable(TableIdentifier ident, String entriesSuffix) {
     return TABLES.load(loadLocation(ident, entriesSuffix));
